@@ -1,8 +1,8 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 #
 # This file is part of the GROMACS molecular simulation package.
 #
-# Copyright (c) 2013,2014,2015,2016,2018, by the GROMACS development team, led by
+# Copyright (c) 2013,2014,2015,2016,2018,2019,2020, by the GROMACS development team, led by
 # Mark Abraham, David van der Spoel, Berk Hess, and Erik Lindahl,
 # and including many others, as listed in the AUTHORS file in the
 # top-level source directory and at http://www.gromacs.org.
@@ -38,7 +38,7 @@
 It is used internally by several bash scripts to do copyright-relates tasks,
 but can also be invoked directly for some rare use cases.
 
-See docs/dev-manual/uncrustify.rst for more details.
+See docs/dev-manual/code-formatting.rst for more details.
 """
 
 import datetime
@@ -393,7 +393,7 @@ def main():
             contents = sys.stdin.read().splitlines()
             reporter = Reporter(sys.stderr, '<stdin>')
         else:
-            with open(filename, 'r') as inputfile:
+            with open(filename, 'r', encoding='utf-8') as inputfile:
                 contents = inputfile.read().splitlines()
             reporter = Reporter(sys.stdout, filename)
 
