@@ -50,9 +50,6 @@
 #include "system_error.h"
 #include "threads.h"
 
-#ifdef __cplusplus
-
-
 namespace tMPI
 {
 /*! \brief A lock guard class that allows for the simple management of
@@ -173,6 +170,4 @@ class TMPI_EXPORT mutex
 };
 }
 
-#endif /* __cplusplus */
-
 #endif /* TMPI_MUTEX_H_ */
