@@ -91,7 +91,7 @@
 #  endif
 #endif
 
-#if defined(__GNUC__) && __GNUC__>=7
+#if defined(__GNUC__) && !defined(__INTEL_COMPILER) && __GNUC__>=7
 #pragma GCC diagnostic ignored "-Wimplicit-fallthrough"
 #endif
 
