@@ -1,7 +1,7 @@
 /*
  * This file is part of the GROMACS molecular simulation package.
  *
- * Copyright (c) 2012,2013,2014, by the GROMACS development team, led by
+ * Copyright (c) 2012,2013,2014,2019, by the GROMACS development team, led by
  * Mark Abraham, David van der Spoel, Berk Hess, and Erik Lindahl,
  * and including many others, as listed in the AUTHORS file in the
  * top-level source directory and at http://www.gromacs.org.
@@ -65,100 +65,100 @@ namespace
 // Simple input data for gmx::AnalysisDataAverageModule tests.
 class SimpleInputData
 {
-    public:
-        static const AnalysisDataTestInput &get()
-        {
+public:
+    static const AnalysisDataTestInput& get()
+    {
 #ifndef STATIC_ANON_NAMESPACE_BUG
-            static SimpleInputData singleton;
-            return singleton.data_;
+        static SimpleInputData singleton;
+        return singleton.data_;
 #else
-            static SimpleInputData singleton_average;
-            return singleton_average.data_;
+        static SimpleInputData singleton_average;
+        return singleton_average.data_;
 #endif
-        }
+    }
 
-        SimpleInputData() : data_(1, false)
-        {
-            data_.setColumnCount(0, 3);
-            data_.addFrameWithValues(1.0,  0.0, 1.0, 2.0);
-            data_.addFrameWithValues(2.0,  1.0, 1.0, 1.0);
-            data_.addFrameWithValues(3.0,  2.0, 0.0, 0.0);
-        }
+    SimpleInputData() : data_(1, false)
+    {
+        data_.setColumnCount(0, 3);
+        data_.addFrameWithValues(1.0, 0.0, 1.0, 2.0);
+        data_.addFrameWithValues(2.0, 1.0, 1.0, 1.0);
+        data_.addFrameWithValues(3.0, 2.0, 0.0, 0.0);
+    }
 
-    private:
-        AnalysisDataTestInput  data_;
+private:
+    AnalysisDataTestInput data_;
 };
 
 // Multipoint input data for gmx::AnalysisDataAverageModule tests.
 class MultipointInputData
 {
-    public:
-        static const AnalysisDataTestInput &get()
-        {
+public:
+    static const AnalysisDataTestInput& get()
+    {
 #ifndef STATIC_ANON_NAMESPACE_BUG
-            static MultipointInputData singleton;
-            return singleton.data_;
+        static MultipointInputData singleton;
+        return singleton.data_;
 #else
-            static MultipointInputData singleton_average;
-            return singleton_average.data_;
+        static MultipointInputData singleton_average;
+        return singleton_average.data_;
 #endif
-        }
+    }
 
-        MultipointInputData() : data_(1, true)
-        {
-            using gmx::test::AnalysisDataTestInputFrame;
-            data_.setColumnCount(0, 3);
-            AnalysisDataTestInputFrame &frame1 = data_.addFrame(1.0);
-            frame1.addPointSetWithValues(0, 0, 0.0, 1.0, 2.0);
-            frame1.addPointSetWithValues(0, 0, 1.0, 0.0);
-            frame1.addPointSetWithValues(0, 0, 2.0);
-            AnalysisDataTestInputFrame &frame2 = data_.addFrame(2.0);
-            frame2.addPointSetWithValues(0, 0, 1.0, 1.0);
-            frame2.addPointSetWithValues(0, 0, 2.0);
-            AnalysisDataTestInputFrame &frame3 = data_.addFrame(3.0);
-            frame3.addPointSetWithValues(0, 0, 2.0, 0.0, 0.0);
-        }
+    MultipointInputData() : data_(1, true)
+    {
+        using gmx::test::AnalysisDataTestInputFrame;
+        data_.setColumnCount(0, 3);
+        AnalysisDataTestInputFrame& frame1 = data_.addFrame(1.0);
+        frame1.addPointSetWithValues(0, 0, 0.0, 1.0, 2.0);
+        frame1.addPointSetWithValues(0, 0, 1.0, 0.0);
+        frame1.addPointSetWithValues(0, 0, 2.0);
+        AnalysisDataTestInputFrame& frame2 = data_.addFrame(2.0);
+        frame2.addPointSetWithValues(0, 0, 1.0, 1.0);
+        frame2.addPointSetWithValues(0, 0, 2.0);
+        AnalysisDataTestInputFrame& frame3 = data_.addFrame(3.0);
+        frame3.addPointSetWithValues(0, 0, 2.0, 0.0, 0.0);
+    }
 
-    private:
-        AnalysisDataTestInput  data_;
+private:
+    AnalysisDataTestInput data_;
 };
 
 // Input data with multiple data sets for gmx::AnalysisDataAverageModule tests.
 class MultiDataSetInputData
 {
-    public:
-        static const AnalysisDataTestInput &get()
-        {
+public:
+    static const AnalysisDataTestInput& get()
+    {
 #ifndef STATIC_ANON_NAMESPACE_BUG
-            static MultiDataSetInputData singleton;
-            return singleton.data_;
+        static MultiDataSetInputData singleton;
+        return singleton.data_;
 #else
-            static MultiDataSetInputData singleton_average;
-            return singleton_average.data_;
+        static MultiDataSetInputData singleton_average;
+        return singleton_average.data_;
 #endif
-        }
+    }
 
-        MultiDataSetInputData() : data_(2, true)
-        {
-            using gmx::test::AnalysisDataTestInputFrame;
-            data_.setColumnCount(0, 3);
-            data_.setColumnCount(1, 2);
-            AnalysisDataTestInputFrame &frame1 = data_.addFrame(1.0);
-            frame1.addPointSetWithValues(0, 0, 0.0, 1.0, 2.0);
-            frame1.addPointSetWithValues(0, 0, 1.0, 0.0);
-            frame1.addPointSetWithValues(1, 0, 2.0, 1.0);
-            frame1.addPointSetWithValues(1, 1, 2.0);
-            AnalysisDataTestInputFrame &frame2 = data_.addFrame(2.0);
-            frame2.addPointSetWithValues(0, 0, 1.0, 1.0);
-            frame2.addPointSetWithValues(0, 2, 2.0);
-            frame2.addPointSetWithValues(1, 0, 1.0, 0.0);
-            AnalysisDataTestInputFrame &frame3 = data_.addFrame(3.0);
-            frame3.addPointSetWithValues(0, 0, 2.0, 0.0, 0.0);
-            frame3.addPointSetWithValues(1, 0, 0.0, 2.0);
-        }
+    MultiDataSetInputData() : data_(2, true)
+    {
+        using gmx::test::AnalysisDataTestInputFrame;
+        data_.setColumnCount(0, 3);
+        data_.setColumnCount(1, 2);
+        AnalysisDataTestInputFrame& frame1 = data_.addFrame(1.0);
+        frame1.addPointSetWithValues(0, 0, 0.0, 1.0, 2.0);
+        frame1.addPointSetWithValues(0, 0, 1.0, 0.0);
+        frame1.addPointSetWithValues(1, 0, 2.0, 1.0);
+        frame1.addPointSetWithValues(1, 1, 2.0);
+        AnalysisDataTestInputFrame& frame2 = data_.addFrame(2.0);
+        frame2.addPointSetWithValues(0, 0, 1.0, 1.0);
+        frame2.addPointSetWithValues(0, 2, 2.0);
+        frame2.addPointSetWithValues(1, 0, 1.0, 0.0);
+        AnalysisDataTestInputFrame& frame3 = data_.addFrame(3.0);
+        frame3.addPointSetWithValues(0, 0, 2.0, 0.0, 0.0);
+        frame3.addPointSetWithValues(1, 0, 0.0, 2.0);
+    }
 
-    private:
-        AnalysisDataTestInput  data_;
+private:
+    AnalysisDataTestInput data_;
 };
 
 
@@ -171,12 +171,11 @@ typedef gmx::test::AnalysisDataTestFixture AverageModuleTest;
 
 TEST_F(AverageModuleTest, BasicTest)
 {
-    const AnalysisDataTestInput &input = SimpleInputData::get();
+    const AnalysisDataTestInput& input = SimpleInputData::get();
     gmx::AnalysisData            data;
     ASSERT_NO_THROW_GMX(setupDataObject(input, &data));
 
-    gmx::AnalysisDataAverageModulePointer module(
-            new gmx::AnalysisDataAverageModule);
+    gmx::AnalysisDataAverageModulePointer module(new gmx::AnalysisDataAverageModule);
     data.addModule(module);
 
     ASSERT_NO_THROW_GMX(addStaticCheckerModule(input, &data));
@@ -187,12 +186,11 @@ TEST_F(AverageModuleTest, BasicTest)
 
 TEST_F(AverageModuleTest, HandlesMultipointData)
 {
-    const AnalysisDataTestInput &input = MultipointInputData::get();
+    const AnalysisDataTestInput& input = MultipointInputData::get();
     gmx::AnalysisData            data;
     ASSERT_NO_THROW_GMX(setupDataObject(input, &data));
 
-    gmx::AnalysisDataAverageModulePointer module(
-            new gmx::AnalysisDataAverageModule);
+    gmx::AnalysisDataAverageModulePointer module(new gmx::AnalysisDataAverageModule);
     data.addModule(module);
 
     ASSERT_NO_THROW_GMX(addStaticCheckerModule(input, &data));
@@ -203,12 +201,11 @@ TEST_F(AverageModuleTest, HandlesMultipointData)
 
 TEST_F(AverageModuleTest, HandlesMultipleDataSets)
 {
-    const AnalysisDataTestInput &input = MultiDataSetInputData::get();
+    const AnalysisDataTestInput& input = MultiDataSetInputData::get();
     gmx::AnalysisData            data;
     ASSERT_NO_THROW_GMX(setupDataObject(input, &data));
 
-    gmx::AnalysisDataAverageModulePointer module(
-            new gmx::AnalysisDataAverageModule);
+    gmx::AnalysisDataAverageModulePointer module(new gmx::AnalysisDataAverageModule);
     data.addModule(module);
 
     ASSERT_NO_THROW_GMX(addStaticCheckerModule(input, &data));
@@ -219,12 +216,11 @@ TEST_F(AverageModuleTest, HandlesMultipleDataSets)
 
 TEST_F(AverageModuleTest, HandlesDataSetAveraging)
 {
-    const AnalysisDataTestInput &input = MultiDataSetInputData::get();
+    const AnalysisDataTestInput& input = MultiDataSetInputData::get();
     gmx::AnalysisData            data;
     ASSERT_NO_THROW_GMX(setupDataObject(input, &data));
 
-    gmx::AnalysisDataAverageModulePointer module(
-            new gmx::AnalysisDataAverageModule);
+    gmx::AnalysisDataAverageModulePointer module(new gmx::AnalysisDataAverageModule);
     module->setAverageDataSets(true);
     data.addModule(module);
 
@@ -236,7 +232,7 @@ TEST_F(AverageModuleTest, HandlesDataSetAveraging)
 
 TEST_F(AverageModuleTest, CanCustomizeXAxis)
 {
-    const AnalysisDataTestInput &input = SimpleInputData::get();
+    const AnalysisDataTestInput& input = SimpleInputData::get();
     gmx::AnalysisData            data;
     ASSERT_NO_THROW_GMX(setupDataObject(input, &data));
 
@@ -252,7 +248,7 @@ TEST_F(AverageModuleTest, CanCustomizeXAxis)
 
 TEST_F(AverageModuleTest, CanCustomizeNonUniformXAxis)
 {
-    const AnalysisDataTestInput &input = SimpleInputData::get();
+    const AnalysisDataTestInput& input = SimpleInputData::get();
     gmx::AnalysisData            data;
     ASSERT_NO_THROW_GMX(setupDataObject(input, &data));
 
@@ -277,12 +273,11 @@ typedef gmx::test::AnalysisDataTestFixture FrameAverageModuleTest;
 
 TEST_F(FrameAverageModuleTest, BasicTest)
 {
-    const AnalysisDataTestInput &input = SimpleInputData::get();
+    const AnalysisDataTestInput& input = SimpleInputData::get();
     gmx::AnalysisData            data;
     ASSERT_NO_THROW_GMX(setupDataObject(input, &data));
 
-    gmx::AnalysisDataFrameAverageModulePointer module(
-            new gmx::AnalysisDataFrameAverageModule);
+    gmx::AnalysisDataFrameAverageModulePointer module(new gmx::AnalysisDataFrameAverageModule);
     data.addModule(module);
 
     ASSERT_NO_THROW_GMX(addStaticCheckerModule(input, &data));
@@ -293,12 +288,11 @@ TEST_F(FrameAverageModuleTest, BasicTest)
 
 TEST_F(FrameAverageModuleTest, HandlesMultipleDataSets)
 {
-    const AnalysisDataTestInput &input = MultiDataSetInputData::get();
+    const AnalysisDataTestInput& input = MultiDataSetInputData::get();
     gmx::AnalysisData            data;
     ASSERT_NO_THROW_GMX(setupDataObject(input, &data));
 
-    gmx::AnalysisDataFrameAverageModulePointer module(
-            new gmx::AnalysisDataFrameAverageModule);
+    gmx::AnalysisDataFrameAverageModulePointer module(new gmx::AnalysisDataFrameAverageModule);
     data.addModule(module);
 
     ASSERT_NO_THROW_GMX(addStaticCheckerModule(input, &data));
