@@ -1,7 +1,7 @@
 /*
  * This file is part of the GROMACS molecular simulation package.
  *
- * Copyright (c) 2013,2014, by the GROMACS development team, led by
+ * Copyright (c) 2013,2014,2019, by the GROMACS development team, led by
  * Mark Abraham, David van der Spoel, Berk Hess, and Erik Lindahl,
  * and including many others, as listed in the AUTHORS file in the
  * top-level source directory and at http://www.gromacs.org.
@@ -64,63 +64,63 @@ namespace
 // Simple input data for gmx::AnalysisDataLifetimeModule tests.
 class SimpleInputData
 {
-    public:
-        static const AnalysisDataTestInput &get()
-        {
+public:
+    static const AnalysisDataTestInput& get()
+    {
 #ifndef STATIC_ANON_NAMESPACE_BUG
-            static SimpleInputData singleton;
-            return singleton.data_;
+        static SimpleInputData singleton;
+        return singleton.data_;
 #else
-            static SimpleInputData singleton_lifetime;
-            return singleton_lifetime.data_;
+        static SimpleInputData singleton_lifetime;
+        return singleton_lifetime.data_;
 #endif
-        }
+    }
 
-        SimpleInputData() : data_(1, false)
-        {
-            data_.setColumnCount(0, 3);
-            data_.addFrameWithValues(1.0,  1.0, 1.0, 1.0);
-            data_.addFrameWithValues(2.0,  1.0, 0.0, 1.0);
-            data_.addFrameWithValues(3.0,  0.0, 1.0, 1.0);
-        }
+    SimpleInputData() : data_(1, false)
+    {
+        data_.setColumnCount(0, 3);
+        data_.addFrameWithValues(1.0, 1.0, 1.0, 1.0);
+        data_.addFrameWithValues(2.0, 1.0, 0.0, 1.0);
+        data_.addFrameWithValues(3.0, 0.0, 1.0, 1.0);
+    }
 
-    private:
-        AnalysisDataTestInput  data_;
+private:
+    AnalysisDataTestInput data_;
 };
 
 // Input data with multiple data sets for gmx::AnalysisDataLifetimeModule tests.
 class MultiDataSetInputData
 {
-    public:
-        static const AnalysisDataTestInput &get()
-        {
+public:
+    static const AnalysisDataTestInput& get()
+    {
 #ifndef STATIC_ANON_NAMESPACE_BUG
-            static MultiDataSetInputData singleton;
-            return singleton.data_;
+        static MultiDataSetInputData singleton;
+        return singleton.data_;
 #else
-            static MultiDataSetInputData singleton_lifetime;
-            return singleton_lifetime.data_;
+        static MultiDataSetInputData singleton_lifetime;
+        return singleton_lifetime.data_;
 #endif
-        }
+    }
 
-        MultiDataSetInputData() : data_(2, false)
-        {
-            using gmx::test::AnalysisDataTestInputFrame;
-            data_.setColumnCount(0, 2);
-            data_.setColumnCount(1, 2);
-            AnalysisDataTestInputFrame &frame1 = data_.addFrame(1.0);
-            frame1.addPointSetWithValues(0, 0, 1.0, 1.0);
-            frame1.addPointSetWithValues(1, 0, 0.0, 0.0);
-            AnalysisDataTestInputFrame &frame2 = data_.addFrame(2.0);
-            frame2.addPointSetWithValues(0, 0, 1.0, 0.0);
-            frame2.addPointSetWithValues(1, 0, 1.0, 0.0);
-            AnalysisDataTestInputFrame &frame3 = data_.addFrame(3.0);
-            frame3.addPointSetWithValues(0, 0, 1.0, 0.0);
-            frame3.addPointSetWithValues(1, 0, 1.0, 1.0);
-        }
+    MultiDataSetInputData() : data_(2, false)
+    {
+        using gmx::test::AnalysisDataTestInputFrame;
+        data_.setColumnCount(0, 2);
+        data_.setColumnCount(1, 2);
+        AnalysisDataTestInputFrame& frame1 = data_.addFrame(1.0);
+        frame1.addPointSetWithValues(0, 0, 1.0, 1.0);
+        frame1.addPointSetWithValues(1, 0, 0.0, 0.0);
+        AnalysisDataTestInputFrame& frame2 = data_.addFrame(2.0);
+        frame2.addPointSetWithValues(0, 0, 1.0, 0.0);
+        frame2.addPointSetWithValues(1, 0, 1.0, 0.0);
+        AnalysisDataTestInputFrame& frame3 = data_.addFrame(3.0);
+        frame3.addPointSetWithValues(0, 0, 1.0, 0.0);
+        frame3.addPointSetWithValues(1, 0, 1.0, 1.0);
+    }
 
-    private:
-        AnalysisDataTestInput  data_;
+private:
+    AnalysisDataTestInput data_;
 };
 
 
@@ -133,12 +133,11 @@ typedef gmx::test::AnalysisDataTestFixture LifetimeModuleTest;
 
 TEST_F(LifetimeModuleTest, BasicTest)
 {
-    const AnalysisDataTestInput &input = SimpleInputData::get();
+    const AnalysisDataTestInput& input = SimpleInputData::get();
     gmx::AnalysisData            data;
     ASSERT_NO_THROW_GMX(setupDataObject(input, &data));
 
-    gmx::AnalysisDataLifetimeModulePointer module(
-            new gmx::AnalysisDataLifetimeModule);
+    gmx::AnalysisDataLifetimeModulePointer module(new gmx::AnalysisDataLifetimeModule);
     module->setCumulative(false);
     data.addModule(module);
 
@@ -150,12 +149,11 @@ TEST_F(LifetimeModuleTest, BasicTest)
 
 TEST_F(LifetimeModuleTest, CumulativeTest)
 {
-    const AnalysisDataTestInput &input = SimpleInputData::get();
+    const AnalysisDataTestInput& input = SimpleInputData::get();
     gmx::AnalysisData            data;
     ASSERT_NO_THROW_GMX(setupDataObject(input, &data));
 
-    gmx::AnalysisDataLifetimeModulePointer module(
-            new gmx::AnalysisDataLifetimeModule);
+    gmx::AnalysisDataLifetimeModulePointer module(new gmx::AnalysisDataLifetimeModule);
     module->setCumulative(true);
     data.addModule(module);
 
@@ -167,12 +165,11 @@ TEST_F(LifetimeModuleTest, CumulativeTest)
 
 TEST_F(LifetimeModuleTest, HandlesMultipleDataSets)
 {
-    const AnalysisDataTestInput &input = MultiDataSetInputData::get();
+    const AnalysisDataTestInput& input = MultiDataSetInputData::get();
     gmx::AnalysisData            data;
     ASSERT_NO_THROW_GMX(setupDataObject(input, &data));
 
-    gmx::AnalysisDataLifetimeModulePointer module(
-            new gmx::AnalysisDataLifetimeModule);
+    gmx::AnalysisDataLifetimeModulePointer module(new gmx::AnalysisDataLifetimeModule);
     module->setCumulative(false);
     data.addModule(module);
 
