@@ -1,7 +1,7 @@
 /*
  * This file is part of the GROMACS molecular simulation package.
  *
- * Copyright (c) 2017,2018, by the GROMACS development team, led by
+ * Copyright (c) 2017,2018,2019, by the GROMACS development team, led by
  * Mark Abraham, David van der Spoel, Berk Hess, and Erik Lindahl,
  * and including many others, as listed in the AUTHORS file in the
  * top-level source directory and at http://www.gromacs.org.
@@ -48,7 +48,8 @@
 #include <vector>
 
 #include "gromacs/gmxlib/network.h"
-#include "gromacs/mdtypes/awh-params.h"
+#include "gromacs/mdrunutility/multisim.h"
+#include "gromacs/mdtypes/awh_params.h"
 #include "gromacs/mdtypes/commrec.h"
 #include "gromacs/utility/exceptions.h"
 #include "gromacs/utility/stringutil.h"
@@ -56,7 +57,7 @@
 namespace gmx
 {
 
-bool haveBiasSharingWithinSimulation(const AwhParams &awhParams)
+bool haveBiasSharingWithinSimulation(const AwhParams& awhParams)
 {
     bool haveSharing = false;
 
@@ -78,9 +79,9 @@ bool haveBiasSharingWithinSimulation(const AwhParams &awhParams)
     return haveSharing;
 }
 
-void biasesAreCompatibleForSharingBetweenSimulations(const AwhParams           &awhParams,
-                                                     const std::vector<size_t> &pointSize,
-                                                     const gmx_multisim_t      *multiSimComm)
+void biasesAreCompatibleForSharingBetweenSimulations(const AwhParams&           awhParams,
+                                                     const std::vector<size_t>& pointSize,
+                                                     const gmx_multisim_t*      multiSimComm)
 {
     const int numSim = multiSimComm->nsim;
 
@@ -97,7 +98,9 @@ void biasesAreCompatibleForSharingBetweenSimulations(const AwhParams           &
             numShare++;
             if (group != numShare)
             {
-                GMX_THROW(InvalidInputError("AWH biases that are shared should use consequetive share-group values starting at 1"));
+                GMX_THROW(
+                        InvalidInputError("AWH biases that are shared should use consequetive "
+                                          "share-group values starting at 1"));
             }
         }
     }
@@ -108,23 +111,26 @@ void biasesAreCompatibleForSharingBetweenSimulations(const AwhParams           &
     {
         if (numShareAll[sim] != numShareAll[0])
         {
-            GMX_THROW(InvalidInputError("Different simulations attempt to share different number of biases"));
+            GMX_THROW(InvalidInputError(
+                    "Different simulations attempt to share different number of biases"));
         }
     }
 
-    std::vector<int> intervals(numSim*2);
-    intervals[numSim*0 + multiSimComm->sim] = awhParams.nstSampleCoord;
-    intervals[numSim*1 + multiSimComm->sim] = awhParams.numSamplesUpdateFreeEnergy;
+    std::vector<int> intervals(numSim * 2);
+    intervals[numSim * 0 + multiSimComm->sim] = awhParams.nstSampleCoord;
+    intervals[numSim * 1 + multiSimComm->sim] = awhParams.numSamplesUpdateFreeEnergy;
     gmx_sumi_sim(intervals.size(), intervals.data(), multiSimComm);
     for (int sim = 1; sim < numSim; sim++)
     {
         if (intervals[sim] != intervals[0])
         {
-            GMX_THROW(InvalidInputError("All simulations should have the same AWH sample interval"));
+            GMX_THROW(
+                    InvalidInputError("All simulations should have the same AWH sample interval"));
         }
         if (intervals[numSim + sim] != intervals[numSim])
         {
-            GMX_THROW(InvalidInputError("All simulations should have the same AWH free-energy update interval"));
+            GMX_THROW(InvalidInputError(
+                    "All simulations should have the same AWH free-energy update interval"));
         }
     }
 
@@ -142,7 +148,10 @@ void biasesAreCompatibleForSharingBetweenSimulations(const AwhParams           &
             {
                 if (pointSizes[sim] != pointSizes[0])
                 {
-                    GMX_THROW(InvalidInputError(gmx::formatString("Shared AWH bias %d has different grid sizes in different simulations\n", b + 1)));
+                    GMX_THROW(InvalidInputError(
+                            gmx::formatString("Shared AWH bias %d has different grid sizes in "
+                                              "different simulations\n",
+                                              b + 1)));
                 }
             }
         }
