@@ -1,7 +1,7 @@
 /*
  * This file is part of the GROMACS molecular simulation package.
  *
- * Copyright (c) 2013,2014,2015,2017,2018, by the GROMACS development team, led by
+ * Copyright (c) 2013,2014,2015,2017,2018,2019, by the GROMACS development team, led by
  * Mark Abraham, David van der Spoel, Berk Hess, and Erik Lindahl,
  * and including many others, as listed in the AUTHORS file in the
  * top-level source directory and at http://www.gromacs.org.
@@ -51,7 +51,6 @@
 #include "gromacs/commandline/cmdlinemodulemanager.h"
 #include "gromacs/commandline/cmdlineoptionsmodule.h"
 #include "gromacs/commandline/cmdlineprogramcontext.h"
-#include "gromacs/compat/make_unique.h"
 #include "gromacs/utility/basenetwork.h"
 #include "gromacs/utility/datafilefinder.h"
 #include "gromacs/utility/exceptions.h"
@@ -74,7 +73,7 @@ namespace
 //! Global context instance initialized in initForCommandLine().
 std::unique_ptr<CommandLineProgramContext> g_commandLineContext;
 //! Global library data file finder that respects GMXLIB.
-std::unique_ptr<DataFileFinder>            g_libFileFinder;
+std::unique_ptr<DataFileFinder> g_libFileFinder;
 
 /*! \brief
  * Broadcasts command-line arguments to all ranks.
@@ -83,7 +82,7 @@ std::unique_ptr<DataFileFinder>            g_libFileFinder;
  * other rank than zero, but our code wants to parse them on each rank
  * separately.
  */
-void broadcastArguments(int *argc, char ***argv)
+void broadcastArguments(int* argc, char*** argv)
 {
     if (gmx_node_num() <= 1)
     {
@@ -94,14 +93,14 @@ void broadcastArguments(int *argc, char ***argv)
     const bool isMaster = (gmx_node_rank() == 0);
     if (!isMaster)
     {
-        snew(*argv, *argc+1);
+        snew(*argv, *argc + 1);
     }
     for (int i = 0; i < *argc; i++)
     {
         int len;
         if (isMaster)
         {
-            len = std::strlen((*argv)[i])+1;
+            len = std::strlen((*argv)[i]) + 1;
         }
         gmx_broadcast_world(sizeof(len), &len);
         if (!isMaster)
@@ -114,25 +113,24 @@ void broadcastArguments(int *argc, char ***argv)
 
 //! \}
 
-}   // namespace
+} // namespace
 
-CommandLineProgramContext &initForCommandLine(int *argc, char ***argv)
+CommandLineProgramContext& initForCommandLine(int* argc, char*** argv)
 {
     gmx::init(argc, argv);
-    GMX_RELEASE_ASSERT(!g_commandLineContext,
-                       "initForCommandLine() calls cannot be nested");
+    GMX_RELEASE_ASSERT(!g_commandLineContext, "initForCommandLine() calls cannot be nested");
     // TODO: Consider whether the argument broadcast would better be done
     // in CommandLineModuleManager.
     broadcastArguments(argc, argv);
     try
     {
-        g_commandLineContext = compat::make_unique<CommandLineProgramContext>(*argc, *argv);
+        g_commandLineContext = std::make_unique<CommandLineProgramContext>(*argc, *argv);
         setProgramContext(g_commandLineContext.get());
-        g_libFileFinder = compat::make_unique<DataFileFinder>();
+        g_libFileFinder = std::make_unique<DataFileFinder>();
         g_libFileFinder->setSearchPathFromEnv("GMXLIB");
         setLibraryFileFinder(g_libFileFinder.get());
     }
-    catch (const std::exception &ex)
+    catch (const std::exception& ex)
     {
         printFatalErrorMessage(stderr, ex);
         std::exit(processExceptionAtExit(ex));
@@ -149,30 +147,30 @@ void finalizeForCommandLine()
     g_commandLineContext.reset();
 }
 
-int processExceptionAtExitForCommandLine(const std::exception &ex)
+int processExceptionAtExitForCommandLine(const std::exception& ex)
 {
     int rc = processExceptionAtExit(ex); // Currently this aborts for real MPI
     finalizeForCommandLine();            // thus this MPI_Finalize doesn't matter.
     return rc;
 }
 
-int runCommandLineModule(int argc, char *argv[],
-                         ICommandLineModule *module)
+int runCommandLineModule(int argc, char* argv[], ICommandLineModule* module)
 {
     return CommandLineModuleManager::runAsMainSingleModule(argc, argv, module);
 }
 
-int runCommandLineModule(
-        int argc, char *argv[], const char *name, const char *description,
-        std::function<std::unique_ptr<ICommandLineOptionsModule>()> factory)
+int runCommandLineModule(int                                                         argc,
+                         char*                                                       argv[],
+                         const char*                                                 name,
+                         const char*                                                 description,
+                         std::function<std::unique_ptr<ICommandLineOptionsModule>()> factory)
 {
-    return ICommandLineOptionsModule::runAsMain(
-            argc, argv, name, description, std::move(factory));
+    return ICommandLineOptionsModule::runAsMain(argc, argv, name, description, std::move(factory));
 }
 
 } // namespace gmx
 
-int gmx_run_cmain(int argc, char *argv[], int (*mainFunction)(int, char *[]))
+int gmx_run_cmain(int argc, char* argv[], int (*mainFunction)(int, char*[]))
 {
     return gmx::CommandLineModuleManager::runAsMainCMain(argc, argv, mainFunction);
 }
