@@ -1,7 +1,7 @@
 /*
  * This file is part of the GROMACS molecular simulation package.
  *
- * Copyright (c) 2018, by the GROMACS development team, led by
+ * Copyright (c) 2018,2019, by the GROMACS development team, led by
  * Mark Abraham, David van der Spoel, Berk Hess, and Erik Lindahl,
  * and including many others, as listed in the AUTHORS file in the
  * top-level source directory and at http://www.gromacs.org.
@@ -50,14 +50,12 @@ struct gmx_domdec_t;
 class t_state;
 
 /*! \brief Gathers rvec arrays \p localVector to \p globalVector on the master rank */
-void dd_collect_vec(gmx_domdec_t                   *dd,
-                    const t_state                  *localState,
-                    gmx::ArrayRef<const gmx::RVec>  localVector,
-                    gmx::ArrayRef<gmx::RVec>        globalVector);
+void dd_collect_vec(gmx_domdec_t*                  dd,
+                    const t_state*                 localState,
+                    gmx::ArrayRef<const gmx::RVec> localVector,
+                    gmx::ArrayRef<gmx::RVec>       globalVector);
 
 /*! \brief Gathers state \p localState to \p globalState on the master rank */
-void dd_collect_state(gmx_domdec_t  *dd,
-                      const t_state *localState,
-                      t_state       *globalState);
+void dd_collect_state(gmx_domdec_t* dd, const t_state* localState, t_state* globalState);
 
 #endif
