@@ -1,7 +1,7 @@
 /*
  * This file is part of the GROMACS molecular simulation package.
  *
- * Copyright (c) 2008,2009,2010,2012,2013,2014,2015,2016,2018, by the GROMACS development team, led by
+ * Copyright (c) 2008-2019, by the GROMACS development team, led by
  * Mark Abraham, David van der Spoel, Berk Hess, and Erik Lindahl,
  * and including many others, as listed in the AUTHORS file in the
  * top-level source directory and at http://www.gromacs.org.
@@ -53,9 +53,11 @@
 #include "gromacs/domdec/domdec_struct.h"
 #include "gromacs/utility/gmxmpi.h"
 
+#include "domdec_internal.h"
+
 
 /*! \brief Returns the MPI rank of the domain decomposition master rank */
-#define DDMASTERRANK(dd)   ((dd)->masterrank)
+#define DDMASTERRANK(dd) ((dd)->masterrank)
 
 
 /*! \brief Move data of type \p T in the communication region one cell along
@@ -64,45 +66,37 @@
  * Moves in the dimension indexed by ddDimensionIndex, either forward
  * (direction=dddirFoward) or backward (direction=dddirBackward).
  */
-template <typename T>
-void
-ddSendrecv(const struct gmx_domdec_t *dd,
-           int                        ddDimensionIndex,
-           int                        direction,
-           T                         *sendBuffer,
-           int                        numElementsToSend,
-           T                         *receiveBuffer,
-           int                        numElementsToReceive)
+template<typename T>
+void ddSendrecv(const struct gmx_domdec_t* dd,
+                int                        ddDimensionIndex,
+                int                        direction,
+                T*                         sendBuffer,
+                int                        numElementsToSend,
+                T*                         receiveBuffer,
+                int                        numElementsToReceive)
 {
 #if GMX_MPI
-    int           sendRank    = dd->neighbor[ddDimensionIndex][direction == dddirForward ? 0 : 1];
-    int           receiveRank = dd->neighbor[ddDimensionIndex][direction == dddirForward ? 1 : 0];
+    int sendRank    = dd->neighbor[ddDimensionIndex][direction == dddirForward ? 0 : 1];
+    int receiveRank = dd->neighbor[ddDimensionIndex][direction == dddirForward ? 1 : 0];
 
-    constexpr int mpiTag      = 0;
+    constexpr int mpiTag = 0;
     MPI_Status    mpiStatus;
     if (numElementsToSend > 0 && numElementsToReceive > 0)
     {
-        MPI_Sendrecv(sendBuffer,    numElementsToSend*sizeof(T),    MPI_BYTE,
-                     sendRank,      mpiTag,
-                     receiveBuffer, numElementsToReceive*sizeof(T), MPI_BYTE,
-                     receiveRank,   mpiTag,
-                     dd->mpi_comm_all,
-                     &mpiStatus);
+        MPI_Sendrecv(sendBuffer, numElementsToSend * sizeof(T), MPI_BYTE, sendRank, mpiTag,
+                     receiveBuffer, numElementsToReceive * sizeof(T), MPI_BYTE, receiveRank, mpiTag,
+                     dd->mpi_comm_all, &mpiStatus);
     }
     else if (numElementsToSend > 0)
     {
-        MPI_Send(    sendBuffer,    numElementsToSend*sizeof(T),    MPI_BYTE,
-                     sendRank,      mpiTag,
-                     dd->mpi_comm_all);
+        MPI_Send(sendBuffer, numElementsToSend * sizeof(T), MPI_BYTE, sendRank, mpiTag, dd->mpi_comm_all);
     }
     else if (numElementsToReceive > 0)
     {
-        MPI_Recv(    receiveBuffer, numElementsToReceive*sizeof(T), MPI_BYTE,
-                     receiveRank,   mpiTag,
-                     dd->mpi_comm_all,
-                     &mpiStatus);
+        MPI_Recv(receiveBuffer, numElementsToReceive * sizeof(T), MPI_BYTE, receiveRank, mpiTag,
+                 dd->mpi_comm_all, &mpiStatus);
     }
-#else // GMX_MPI
+#else  // GMX_MPI
     GMX_UNUSED_VALUE(dd);
     GMX_UNUSED_VALUE(ddDimensionIndex);
     GMX_UNUSED_VALUE(direction);
@@ -114,44 +108,40 @@ ddSendrecv(const struct gmx_domdec_t *dd,
 }
 
 //! Specialization of extern template for int
-template void ddSendrecv(const gmx_domdec_t *, int, int,
-                         int *, int, int *, int);
+template void ddSendrecv(const gmx_domdec_t*, int, int, int*, int, int*, int);
 //! Specialization of extern template for real
-template void ddSendrecv(const gmx_domdec_t *, int, int,
-                         real *, int, real *, int);
+template void ddSendrecv(const gmx_domdec_t*, int, int, real*, int, real*, int);
 //! Specialization of extern template for gmx::RVec
-template void ddSendrecv(const gmx_domdec_t *, int, int,
-                         rvec *, int, rvec *, int);
+template void ddSendrecv(const gmx_domdec_t*, int, int, rvec*, int, rvec*, int);
 
-template <typename T>
-void
-ddSendrecv(const gmx_domdec_t *dd,
-           int                 ddDimensionIndex,
-           int                 direction,
-           gmx::ArrayRef<T>    sendBuffer,
-           gmx::ArrayRef<T>    receiveBuffer)
+template<typename T>
+void ddSendrecv(const gmx_domdec_t* dd,
+                int                 ddDimensionIndex,
+                int                 direction,
+                gmx::ArrayRef<T>    sendBuffer,
+                gmx::ArrayRef<T>    receiveBuffer)
 {
-    ddSendrecv(dd, ddDimensionIndex, direction,
-               sendBuffer.data(), sendBuffer.size(),
+    ddSendrecv(dd, ddDimensionIndex, direction, sendBuffer.data(), sendBuffer.size(),
                receiveBuffer.data(), receiveBuffer.size());
 }
 
 //! Specialization of extern template for int
-template void ddSendrecv(const gmx_domdec_t *, int, int,
-                         gmx::ArrayRef<int>, gmx::ArrayRef<int>);
+template void ddSendrecv(const gmx_domdec_t*, int, int, gmx::ArrayRef<int>, gmx::ArrayRef<int>);
 //! Specialization of extern template for real
-template void ddSendrecv(const gmx_domdec_t *, int, int,
-                         gmx::ArrayRef<real>, gmx::ArrayRef<real>);
+template void ddSendrecv(const gmx_domdec_t*, int, int, gmx::ArrayRef<real>, gmx::ArrayRef<real>);
 //! Specialization of extern template for gmx::RVec
-template void ddSendrecv(const gmx_domdec_t *, int, int,
-                         gmx::ArrayRef<gmx::RVec>, gmx::ArrayRef<gmx::RVec>);
+template void ddSendrecv(const gmx_domdec_t*, int, int, gmx::ArrayRef<gmx::RVec>, gmx::ArrayRef<gmx::RVec>);
 
-void dd_sendrecv2_rvec(const struct gmx_domdec_t gmx_unused *dd,
+void dd_sendrecv2_rvec(const struct gmx_domdec_t gmx_unused* dd,
                        int gmx_unused ddimind,
-                       rvec gmx_unused *buf_s_fw, int gmx_unused n_s_fw,
-                       rvec gmx_unused *buf_r_fw, int gmx_unused n_r_fw,
-                       rvec gmx_unused *buf_s_bw, int gmx_unused n_s_bw,
-                       rvec gmx_unused *buf_r_bw, int gmx_unused n_r_bw)
+                       rvec gmx_unused* buf_s_fw,
+                       int gmx_unused n_s_fw,
+                       rvec gmx_unused* buf_r_fw,
+                       int gmx_unused n_r_fw,
+                       rvec gmx_unused* buf_s_bw,
+                       int gmx_unused n_s_bw,
+                       rvec gmx_unused* buf_r_bw,
+                       int gmx_unused n_r_bw)
 {
 #if GMX_MPI
     int         rank_fw, rank_bw, nreq;
@@ -161,7 +151,7 @@ void dd_sendrecv2_rvec(const struct gmx_domdec_t gmx_unused *dd,
     rank_fw = dd->neighbor[ddimind][0];
     rank_bw = dd->neighbor[ddimind][1];
 
-    if (!dd->bSendRecv2)
+    if (!dd->comm->ddSettings.useSendRecv2)
     {
         /* Try to send and receive in two directions simultaneously.
          * Should be faster, especially on machines
@@ -174,23 +164,23 @@ void dd_sendrecv2_rvec(const struct gmx_domdec_t gmx_unused *dd,
         nreq = 0;
         if (n_r_fw)
         {
-            MPI_Irecv(buf_r_fw[0], n_r_fw*sizeof(rvec), MPI_BYTE,
-                      rank_bw, 0, dd->mpi_comm_all, &req[nreq++]);
+            MPI_Irecv(buf_r_fw[0], n_r_fw * sizeof(rvec), MPI_BYTE, rank_bw, 0, dd->mpi_comm_all,
+                      &req[nreq++]);
         }
         if (n_r_bw)
         {
-            MPI_Irecv(buf_r_bw[0], n_r_bw*sizeof(rvec), MPI_BYTE,
-                      rank_fw, 1, dd->mpi_comm_all, &req[nreq++]);
+            MPI_Irecv(buf_r_bw[0], n_r_bw * sizeof(rvec), MPI_BYTE, rank_fw, 1, dd->mpi_comm_all,
+                      &req[nreq++]);
         }
         if (n_s_fw)
         {
-            MPI_Isend(buf_s_fw[0], n_s_fw*sizeof(rvec), MPI_BYTE,
-                      rank_fw, 0, dd->mpi_comm_all, &req[nreq++]);
+            MPI_Isend(buf_s_fw[0], n_s_fw * sizeof(rvec), MPI_BYTE, rank_fw, 0, dd->mpi_comm_all,
+                      &req[nreq++]);
         }
         if (n_s_bw)
         {
-            MPI_Isend(buf_s_bw[0], n_s_bw*sizeof(rvec), MPI_BYTE,
-                      rank_bw, 1, dd->mpi_comm_all, &req[nreq++]);
+            MPI_Isend(buf_s_bw[0], n_s_bw * sizeof(rvec), MPI_BYTE, rank_bw, 1, dd->mpi_comm_all,
+                      &req[nreq++]);
         }
         if (nreq)
         {
@@ -204,29 +194,26 @@ void dd_sendrecv2_rvec(const struct gmx_domdec_t gmx_unused *dd,
          * with a single full-duplex network connection per machine.
          */
         /* Forward */
-        MPI_Sendrecv(buf_s_fw[0], n_s_fw*sizeof(rvec), MPI_BYTE, rank_fw, 0,
-                     buf_r_fw[0], n_r_fw*sizeof(rvec), MPI_BYTE, rank_bw, 0,
-                     dd->mpi_comm_all, &stat[0]);
+        MPI_Sendrecv(buf_s_fw[0], n_s_fw * sizeof(rvec), MPI_BYTE, rank_fw, 0, buf_r_fw[0],
+                     n_r_fw * sizeof(rvec), MPI_BYTE, rank_bw, 0, dd->mpi_comm_all, &stat[0]);
         /* Backward */
-        MPI_Sendrecv(buf_s_bw[0], n_s_bw*sizeof(rvec), MPI_BYTE, rank_bw, 0,
-                     buf_r_bw[0], n_r_bw*sizeof(rvec), MPI_BYTE, rank_fw, 0,
-                     dd->mpi_comm_all, &stat[0]);
+        MPI_Sendrecv(buf_s_bw[0], n_s_bw * sizeof(rvec), MPI_BYTE, rank_bw, 0, buf_r_bw[0],
+                     n_r_bw * sizeof(rvec), MPI_BYTE, rank_fw, 0, dd->mpi_comm_all, &stat[0]);
     }
 #endif
 }
 
-void dd_bcast(const gmx_domdec_t gmx_unused *dd, int gmx_unused nbytes, void gmx_unused *data)
+void dd_bcast(const gmx_domdec_t gmx_unused* dd, int gmx_unused nbytes, void gmx_unused* data)
 {
 #if GMX_MPI
     if (dd->nnodes > 1)
     {
-        MPI_Bcast(data, nbytes, MPI_BYTE,
-                  DDMASTERRANK(dd), dd->mpi_comm_all);
+        MPI_Bcast(data, nbytes, MPI_BYTE, DDMASTERRANK(dd), dd->mpi_comm_all);
     }
 #endif
 }
 
-void dd_bcastc(const gmx_domdec_t *dd, int nbytes, void *src, void *dest)
+void dd_bcastc(const gmx_domdec_t* dd, int nbytes, void* src, void* dest)
 {
     if (DDMASTER(dd) || dd->nnodes == 1)
     {
@@ -235,20 +222,18 @@ void dd_bcastc(const gmx_domdec_t *dd, int nbytes, void *src, void *dest)
 #if GMX_MPI
     if (dd->nnodes > 1)
     {
-        MPI_Bcast(dest, nbytes, MPI_BYTE,
-                  DDMASTERRANK(dd), dd->mpi_comm_all);
+        MPI_Bcast(dest, nbytes, MPI_BYTE, DDMASTERRANK(dd), dd->mpi_comm_all);
     }
 #endif
 }
 
-void dd_scatter(const gmx_domdec_t gmx_unused *dd, int gmx_unused nbytes, const void gmx_unused *src, void *dest)
+void dd_scatter(const gmx_domdec_t gmx_unused* dd, int gmx_unused nbytes, const void gmx_unused* src, void* dest)
 {
 #if GMX_MPI
     if (dd->nnodes > 1)
     {
         /* Some MPI implementions don't specify const */
-        MPI_Scatter(const_cast<void *>(src), nbytes, MPI_BYTE,
-                    dest, nbytes, MPI_BYTE,
+        MPI_Scatter(const_cast<void*>(src), nbytes, MPI_BYTE, dest, nbytes, MPI_BYTE,
                     DDMASTERRANK(dd), dd->mpi_comm_all);
     }
     else
@@ -262,19 +247,24 @@ void dd_scatter(const gmx_domdec_t gmx_unused *dd, int gmx_unused nbytes, const
     }
 }
 
-void dd_gather(const gmx_domdec_t gmx_unused *dd, int gmx_unused nbytes, const void gmx_unused *src, void gmx_unused *dest)
+void dd_gather(const gmx_domdec_t gmx_unused* dd,
+               int gmx_unused nbytes,
+               const void gmx_unused* src,
+               void gmx_unused* dest)
 {
 #if GMX_MPI
     /* Some MPI implementions don't specify const */
-    MPI_Gather(const_cast<void *>(src), nbytes, MPI_BYTE,
-               dest, nbytes, MPI_BYTE,
-               DDMASTERRANK(dd), dd->mpi_comm_all);
+    MPI_Gather(const_cast<void*>(src), nbytes, MPI_BYTE, dest, nbytes, MPI_BYTE, DDMASTERRANK(dd),
+               dd->mpi_comm_all);
 #endif
 }
 
-void dd_scatterv(const gmx_domdec_t gmx_unused *dd,
-                 int gmx_unused *scounts, int gmx_unused *disps, const void *sbuf,
-                 int rcount, void *rbuf)
+void dd_scatterv(const gmx_domdec_t gmx_unused* dd,
+                 int gmx_unused* scounts,
+                 int gmx_unused* disps,
+                 const void*     sbuf,
+                 int             rcount,
+                 void*           rbuf)
 {
 #if GMX_MPI
     int dum;
@@ -287,8 +277,7 @@ void dd_scatterv(const gmx_domdec_t gmx_unused *dd,
             rbuf = &dum;
         }
         /* Some MPI implementions don't specify const */
-        MPI_Scatterv(const_cast<void *>(sbuf), scounts, disps, MPI_BYTE,
-                     rbuf, rcount, MPI_BYTE,
+        MPI_Scatterv(const_cast<void*>(sbuf), scounts, disps, MPI_BYTE, rbuf, rcount, MPI_BYTE,
                      DDMASTERRANK(dd), dd->mpi_comm_all);
     }
     else
@@ -302,9 +291,12 @@ void dd_scatterv(const gmx_domdec_t gmx_unused *dd,
     }
 }
 
-void dd_gatherv(const gmx_domdec_t gmx_unused *dd,
-                int gmx_unused scount, const void gmx_unused *sbuf,
-                int gmx_unused *rcounts, int gmx_unused *disps, void gmx_unused *rbuf)
+void dd_gatherv(const gmx_domdec_t gmx_unused* dd,
+                int gmx_unused scount,
+                const void gmx_unused* sbuf,
+                int gmx_unused* rcounts,
+                int gmx_unused* disps,
+                void gmx_unused* rbuf)
 {
 #if GMX_MPI
     int dum;
@@ -315,8 +307,7 @@ void dd_gatherv(const gmx_domdec_t gmx_unused *dd,
         sbuf = &dum;
     }
     /* Some MPI implementions don't specify const */
-    MPI_Gatherv(const_cast<void *>(sbuf), scount, MPI_BYTE,
-                rbuf, rcounts, disps, MPI_BYTE,
+    MPI_Gatherv(const_cast<void*>(sbuf), scount, MPI_BYTE, rbuf, rcounts, disps, MPI_BYTE,
                 DDMASTERRANK(dd), dd->mpi_comm_all);
 #endif
 }
