@@ -47,6 +47,7 @@
 
 #include <cstddef>
 
+#include <array>
 #include <memory>
 #include <vector>
 
@@ -54,10 +55,11 @@
 #include "gromacs/topology/block.h"
 #include "gromacs/utility/basedefinitions.h"
 #include "gromacs/utility/gmxmpi.h"
+#include "gromacs/utility/range.h"
 #include "gromacs/utility/real.h"
 
 //! Max number of zones in domain decomposition
-#define DD_MAXZONE  8
+#define DD_MAXZONE 8
 //! Max number of izones in domain decomposition
 #define DD_MAXIZONE 4
 
@@ -68,59 +70,65 @@ struct gmx_domdec_specat_comm_t;
 class gmx_ga2la_t;
 struct gmx_pme_comm_n_box_t;
 struct gmx_reverse_top_t;
+struct t_inputrec;
 
 namespace gmx
 {
-template <typename T> class HashedMap;
+template<typename T>
+class HashedMap;
 class LocalAtomSetManager;
-}
+class GpuHaloExchange;
+} // namespace gmx
 
-typedef struct {
-    /* j-zone start               */
-    int  j0 = 0;
-    /* j-zone end                 */
-    int  j1 = 0;
-    /* i-charge-group end         */
-    int  cg1 = 0;
-    /* j-charge-group start       */
-    int  jcg0 = 0;
-    /* j-charge-group end         */
-    int  jcg1 = 0;
-    /* Minimum shifts to consider */
-    ivec shift0 = { };
-    /* Maximum shifts to consider */
-    ivec shift1 = { };
-} gmx_domdec_ns_ranges_t;
+/*! \internal
+ * \brief Pair interaction zone and atom range for an i-zone
+ */
+struct DDPairInteractionRanges
+{
+    //! The index of this i-zone in the i-zone list
+    int iZoneIndex = -1;
+    //! The range of j-zones
+    gmx::Range<int> jZoneRange;
+    //! The i-atom range
+    gmx::Range<int> iAtomRange;
+    //! The j-atom range
+    gmx::Range<int> jAtomRange;
+    //! Minimum shifts to consider
+    ivec shift0 = {};
+    //! Maximum shifts to consider
+    ivec shift1 = {};
+};
 
-typedef struct {
+typedef struct
+{
     /* Zone lower corner in triclinic coordinates         */
-    rvec x0 = { };
+    rvec x0 = {};
     /* Zone upper corner in triclinic coordinates         */
-    rvec x1 = { };
+    rvec x1 = {};
     /* Zone bounding box lower corner in Cartesian coords */
-    rvec bb_x0 = { };
+    rvec bb_x0 = {};
     /* Zone bounding box upper corner in Cartesian coords */
-    rvec bb_x1 = { };
+    rvec bb_x1 = {};
 } gmx_domdec_zone_size_t;
 
-struct gmx_domdec_zones_t {
+struct gmx_domdec_zones_t
+{
     /* The number of zones including the home zone */
-    int                    n = 0;
+    int n = 0;
     /* The shift of the zones with respect to the home zone */
-    ivec                   shift[DD_MAXZONE] = { };
+    ivec shift[DD_MAXZONE] = {};
     /* The charge group boundaries for the zones */
-    int                    cg_range[DD_MAXZONE+1] = { };
-    /* The number of neighbor search zones with i-particles */
-    int                    nizone = 0;
-    /* The neighbor search charge group ranges for each i-zone */
-    gmx_domdec_ns_ranges_t izone[DD_MAXIZONE];
+    int cg_range[DD_MAXZONE + 1] = {};
+    /* The pair interaction zone and atom ranges per each i-zone */
+    std::vector<DDPairInteractionRanges> iZones;
     /* Boundaries of the zones */
     gmx_domdec_zone_size_t size[DD_MAXZONE];
     /* The cg density of the home zone */
-    real                   dens_zone0 = 0;
+    real dens_zone0 = 0;
 };
 
-struct gmx_ddbox_t {
+struct gmx_ddbox_t
+{
     int  npbcdim;
     int  nboundeddim;
     rvec box0;
@@ -134,115 +142,111 @@ struct gmx_ddbox_t {
     rvec normal[DIM];
 };
 
+/*! \internal \brief Provides information about properties of the unit cell */
+struct UnitCellInfo
+{
+    //! Constructor
+    UnitCellInfo(const t_inputrec& ir);
+
+    //! We have PBC from dim 0 (X) up to npbcdim
+    int npbcdim;
+    //! The system is bounded from 0 (X) to numBoundedDimensions
+    int numBoundedDimensions;
+    //! Tells whether the box bounding the atoms is dynamic
+    bool ddBoxIsDynamic;
+    //! Screw PBC?
+    bool haveScrewPBC;
+};
+
+struct gmx_domdec_t
+{ //NOLINT(clang-analyzer-optin.performance.Padding)
+    //! Constructor, only partial for now
+    gmx_domdec_t(const t_inputrec& ir);
 
-struct gmx_domdec_t { //NOLINT(clang-analyzer-optin.performance.Padding)
     /* The DD particle-particle nodes only */
     /* The communication setup within the communicator all
      * defined in dd->comm in domdec.c
      */
-    int                    nnodes;
-    MPI_Comm               mpi_comm_all;
-    /* Use MPI_Sendrecv communication instead of non-blocking calls */
-    gmx_bool               bSendRecv2;
+    int      nnodes       = 0;
+    MPI_Comm mpi_comm_all = MPI_COMM_NULL;
     /* The local DD cell index and rank */
-    ivec                   ci;
-    int                    rank;
-    ivec                   master_ci;
-    int                    masterrank;
+    ivec ci         = { 0, 0, 0 };
+    int  rank       = 0;
+    ivec master_ci  = { 0, 0, 0 };
+    int  masterrank = 0;
     /* Communication with the PME only nodes */
-    int                    pme_nodeid;
-    gmx_bool               pme_receive_vir_ener;
-    gmx_pme_comm_n_box_t  *cnb      = nullptr;
-    int                    nreq_pme = 0;
-    MPI_Request            req_pme[8];
+    int                   pme_nodeid           = 0;
+    gmx_bool              pme_receive_vir_ener = false;
+    gmx_pme_comm_n_box_t* cnb                  = nullptr;
+    int                   nreq_pme             = 0;
+    MPI_Request           req_pme[8];
 
+    /* Properties of the unit cell */
+    UnitCellInfo unitCellInfo;
 
     /* The communication setup, identical for each cell, cartesian index */
-    ivec     nc;
-    int      ndim;
-    ivec     dim; /* indexed by 0 to ndim */
-
-    /* TODO: Move the next 4, and more from domdec_internal.h, to a simulation system */
-
-    /* PBC from dim 0 (X) to npbcdim */
-    int  npbcdim;
-    /* The system is bounded from 0 (X) to numBoundedDimensions */
-    int  numBoundedDimensions;
-    /* Does the box size change during the simulaton? */
-    bool haveDynamicBox;
-
-    /* Screw PBC? */
-    gmx_bool bScrewPBC;
+    ivec nc   = { 0, 0, 0 };
+    int  ndim = 0;
+    ivec dim  = { 0, 0, 0 }; /* indexed by 0 to ndim */
 
     /* Forward and backward neighboring cells, indexed by 0 to ndim */
-    int  neighbor[DIM][2];
+    int neighbor[DIM][2] = { { 0, 0 }, { 0, 0 }, { 0, 0 } };
 
     /* Only available on the master node */
     std::unique_ptr<AtomDistribution> ma;
 
-    /* Can atoms connected by constraints be assigned to different domains? */
-    bool splitConstraints;
-    /* Can atoms connected by settles be assigned to different domains? */
-    bool splitSettles;
-
     /* Global atom number to interaction list */
-    gmx_reverse_top_t  *reverse_top;
-    int                 nbonded_global;
-    int                 nbonded_local;
+    gmx_reverse_top_t* reverse_top    = nullptr;
+    int                nbonded_global = 0;
+    int                nbonded_local  = 0;
 
-    /* The number of inter charge-group exclusions */
-    int  n_intercg_excl;
+    /* Whether we have non-self exclusion */
+    bool haveExclusions = false;
 
     /* Vsite stuff */
-    gmx::HashedMap<int>       *ga2la_vsite = nullptr;
-    gmx_domdec_specat_comm_t  *vsite_comm  = nullptr;
-    std::vector<int>           vsite_requestedGlobalAtomIndices;
+    gmx::HashedMap<int>*      ga2la_vsite = nullptr;
+    gmx_domdec_specat_comm_t* vsite_comm  = nullptr;
+    std::vector<int>          vsite_requestedGlobalAtomIndices;
 
     /* Constraint stuff */
-    gmx_domdec_constraints_t *constraints     = nullptr;
-    gmx_domdec_specat_comm_t *constraint_comm = nullptr;
+    gmx_domdec_constraints_t* constraints     = nullptr;
+    gmx_domdec_specat_comm_t* constraint_comm = nullptr;
 
     /* The number of home atom groups */
-    int                           ncg_home = 0;
+    int ncg_home = 0;
     /* Global atom group indices for the home and all non-home groups */
-    std::vector<int>              globalAtomGroupIndices;
-    /* The atom groups for the home and all non-home groups, todo: make private */
-    gmx::RangePartitioning        atomGrouping_;
-    const gmx::RangePartitioning &atomGrouping() const
-    {
-        return atomGrouping_;
-    }
-    /* Local atom to local atom-group index, only used for checking bondeds */
-    std::vector<int> localAtomGroupFromAtom;
+    std::vector<int> globalAtomGroupIndices;
 
     /* Index from the local atoms to the global atoms, covers home and received zones */
     std::vector<int> globalAtomIndices;
 
     /* Global atom number to local atom number list */
-    gmx_ga2la_t  *ga2la = nullptr;
+    gmx_ga2la_t* ga2la = nullptr;
 
     /* Communication stuff */
-    gmx_domdec_comm_t *comm;
+    gmx_domdec_comm_t* comm = nullptr;
 
     /* The partioning count, to keep track of the state */
-    int64_t ddp_count;
+    int64_t ddp_count = 0;
 
     /* The managed atom sets that are updated in domain decomposition */
-    gmx::LocalAtomSetManager * atomSets;
+    gmx::LocalAtomSetManager* atomSets = nullptr;
 
     /* gmx_pme_recv_f buffer */
-    int   pme_recv_f_alloc = 0;
-    rvec *pme_recv_f_buf   = nullptr;
+    std::vector<gmx::RVec> pmeForceReceiveBuffer;
+
+    /* GPU halo exchange object */
+    std::unique_ptr<gmx::GpuHaloExchange> gpuHaloExchange;
 };
 
 //! Are we the master node for domain decomposition
-static inline bool DDMASTER(const gmx_domdec_t &dd)
+static inline bool DDMASTER(const gmx_domdec_t& dd)
 {
     return dd.rank == dd.masterrank;
 };
 
 //! Are we the master node for domain decomposition, deprecated
-static inline bool DDMASTER(const gmx_domdec_t *dd)
+static inline bool DDMASTER(const gmx_domdec_t* dd)
 {
     return dd->rank == dd->masterrank;
 };
