@@ -3,7 +3,7 @@
  *
  * Copyright (c) 1991-2000, University of Groningen, The Netherlands.
  * Copyright (c) 2001-2004, The GROMACS development team.
- * Copyright (c) 2013,2014,2015,2016,2017,2018, by the GROMACS development team, led by
+ * Copyright (c) 2013,2014,2015,2016,2017,2018,2019, by the GROMACS development team, led by
  * Mark Abraham, David van der Spoel, Berk Hess, and Erik Lindahl,
  * and including many others, as listed in the AUTHORS file in the
  * top-level source directory and at http://www.gromacs.org.
@@ -48,21 +48,34 @@ struct t_atoms;
 struct t_symtab;
 struct t_topology;
 
-void write_sto_conf_indexed(const char *outfile, const char *title,
-                            const t_atoms *atoms,
-                            const rvec x[], const rvec *v, int ePBC, const matrix box,
-                            int nindex, int index[]);
+void write_sto_conf_indexed(const char*    outfile,
+                            const char*    title,
+                            const t_atoms* atoms,
+                            const rvec     x[],
+                            const rvec*    v,
+                            int            ePBC,
+                            const matrix   box,
+                            int            nindex,
+                            int            index[]);
 /* like write_sto_conf, but indexed */
 
-void write_sto_conf(const char *outfile, const char *title,
-                    const t_atoms *atoms,
-                    const rvec x[], const rvec *v, int ePBC, const matrix box);
+void write_sto_conf(const char*    outfile,
+                    const char*    title,
+                    const t_atoms* atoms,
+                    const rvec     x[],
+                    const rvec*    v,
+                    int            ePBC,
+                    const matrix   box);
 /* write atoms, x, v (if .gro and not NULL) and box (if not NULL)
  * to an STO (.gro or .pdb) file */
 
-void write_sto_conf_mtop(const char *outfile, const char *title,
-                         struct gmx_mtop_t *mtop,
-                         const rvec x[], const rvec *v, int ePBC, const matrix box);
+void write_sto_conf_mtop(const char*       outfile,
+                         const char*       title,
+                         const gmx_mtop_t* mtop,
+                         const rvec        x[],
+                         const rvec*       v,
+                         int               ePBC,
+                         const matrix      box);
 /* As write_sto_conf, but uses a gmx_mtop_t struct */
 
 /*! \brief Read a configuration and, when available, a topology from a tpr or structure file.
@@ -78,10 +91,13 @@ void write_sto_conf_mtop(const char *outfile, const char *title,
  * \param[in,out] v             Velocities will be stored when *v!=NULL
  * \param[out]    box           Box dimensions
  */
-void readConfAndTopology(const char *infile,
-                         bool *haveTopology, gmx_mtop_t *mtop,
-                         int *ePBC,
-                         rvec **x, rvec **v, matrix box);
+void readConfAndTopology(const char* infile,
+                         bool*       haveTopology,
+                         gmx_mtop_t* mtop,
+                         int*        ePBC,
+                         rvec**      x,
+                         rvec**      v,
+                         matrix      box);
 
 /*! \brief Read a configuration from a structure file.
  *
@@ -96,10 +112,14 @@ void readConfAndTopology(const char *infile,
  * \param[in,out] v             Velocities will be stored when *v!=NULL
  * \param[out]    box           Box dimensions
  */
-void readConfAndAtoms(const char *infile,
-                      t_symtab *symtab, char **name, t_atoms *atoms,
-                      int *ePBC,
-                      rvec **x, rvec **v, matrix box);
+void readConfAndAtoms(const char* infile,
+                      t_symtab*   symtab,
+                      char**      name,
+                      t_atoms*    atoms,
+                      int*        ePBC,
+                      rvec**      x,
+                      rvec**      v,
+                      matrix      box);
 
 /*! \brief Read a configuration and, when available, a topology from a tpr or structure file.
  *
@@ -112,16 +132,20 @@ void readConfAndAtoms(const char *infile,
  * their presence is signaled with the \p haveMass flag in t_atoms of \p top.
  *
  * \param[in]     infile        Input file name
- * \param[out]    top           The topology, either complete or only atom data. Caller is responsible for calling done_top().
- * \param[out]    ePBC          Enum reporting the type of PBC
+ * \param[out]    top           The topology, either complete or only atom data. Caller is
+ * responsible for calling done_top(). \param[out]    ePBC          Enum reporting the type of PBC
  * \param[in,out] x             Coordinates will be stored when *x!=NULL
  * \param[in,out] v             Velocities will be stored when *v!=NULL
  * \param[out]    box           Box dimensions
- * \param[in]     requireMasses Require masses to be present, either from tpr or from the mass database
- * \returns if a topology is available
+ * \param[in]     requireMasses Require masses to be present, either from tpr or from the mass
+ * database \returns if a topology is available
  */
-gmx_bool read_tps_conf(const char *infile, struct t_topology *top,
-                       int *ePBC, rvec **x, rvec **v, matrix box,
-                       gmx_bool requireMasses);
+gmx_bool read_tps_conf(const char*        infile,
+                       struct t_topology* top,
+                       int*               ePBC,
+                       rvec**             x,
+                       rvec**             v,
+                       matrix             box,
+                       gmx_bool           requireMasses);
 
 #endif
