@@ -3,7 +3,7 @@
  *
  * Copyright (c) 1991-2000, University of Groningen, The Netherlands.
  * Copyright (c) 2001-2004, The GROMACS development team.
- * Copyright (c) 2013,2014,2015,2017,2018,2019, by the GROMACS development team, led by
+ * Copyright (c) 2013,2014,2015,2017,2018,2019,2020, by the GROMACS development team, led by
  * Mark Abraham, David van der Spoel, Berk Hess, and Erik Lindahl,
  * and including many others, as listed in the AUTHORS file in the
  * top-level source directory and at http://www.gromacs.org.
@@ -292,7 +292,7 @@ static t_matrix read_xpm_entry(FILE* in)
         findLabelInLine(lineString, "type"); // discard the returned string
     }
 
-    if (!line || strncmp(line, "static", 6) != 0)
+    if (!line_buf || strncmp(line_buf, "static", 6) != 0)
     {
         gmx_input("Invalid XPixMap");
     }
@@ -432,6 +432,7 @@ static t_matrix read_xpm_entry(FILE* in)
             line = line_buf;
         }
         bSetLine = TRUE;
+        GMX_RELEASE_ASSERT(line, "Need to have valid line to parse");
         if (strstr(line, "x-axis"))
         {
             line = std::strstr(line, "x-axis");
