@@ -3,7 +3,7 @@
  *
  * Copyright (c) 1991-2000, University of Groningen, The Netherlands.
  * Copyright (c) 2001-2004, The GROMACS development team.
- * Copyright (c) 2013,2014,2015,2016,2017,2018,2019, by the GROMACS development team, led by
+ * Copyright (c) 2013,2014,2015,2016,2017,2018,2019,2020, by the GROMACS development team, led by
  * Mark Abraham, David van der Spoel, Berk Hess, and Erik Lindahl,
  * and including many others, as listed in the AUTHORS file in the
  * top-level source directory and at http://www.gromacs.org.
@@ -85,8 +85,8 @@ static const real  timefactors[]     = { real(0),    real(1e3),  real(1),     re
                                     real(1e-6), real(1e-9), real(1e-12), real(0) };
 static const real  timeinvfactors[]  = { real(0),   real(1e-3), real(1),    real(1e3),
                                        real(1e6), real(1e9),  real(1e12), real(0) };
-static const char* time_units_str[]  = { nullptr, "fs", "ps", "ns", "us", "\\mus", "ms", "s" };
-static const char* time_units_xvgr[] = { nullptr, "fs", "ps", "ns", "ms", "s", nullptr };
+static const char* time_units_str[]  = { nullptr, "fs", "ps", "ns", "us", "ms", "s" };
+static const char* time_units_xvgr[] = { nullptr, "fs", "ps", "ns", "\\mus", "ms", "s", nullptr };
 
 
 /***** OUTPUT_ENV MEMBER FUNCTIONS ******/
