@@ -1,7 +1,8 @@
 /*
  * This file is part of the GROMACS molecular simulation package.
  *
- * Copyright (c) 2009,2010,2012,2013,2014,2015,2016,2017,2018, by the GROMACS development team, led by
+ * Copyright (c) 2009-2018, The GROMACS development team.
+ * Copyright (c) 2019, by the GROMACS development team, led by
  * Mark Abraham, David van der Spoel, Berk Hess, and Erik Lindahl,
  * and including many others, as listed in the AUTHORS file in the
  * top-level source directory and at http://www.gromacs.org.
@@ -38,6 +39,9 @@
 
 #include "config.h"
 
+#include "gromacs/utility/path.h"
+#include "gromacs/utility/stringutil.h"
+
 /* Derived from PluginMgr.C and catdcd.c */
 
 /* PluginMgr.C: Copyright: */
@@ -97,13 +101,13 @@
 #include "external/vmd_molfile/molfile_plugin.h"
 #include "external/vmd_molfile/vmddlopen.h"
 #if !GMX_NATIVE_WINDOWS
-#include <glob.h>
+#    include <glob.h>
 #else
-#ifndef _WIN32_IE
-#define _WIN32_IE 0x0500 /* SHGetFolderPath is available since WinXP/IE5 */
-#endif
-#include <shlobj.h>
-#include <windows.h>
+#    ifndef _WIN32_IE
+#        define _WIN32_IE 0x0500 /* SHGetFolderPath is available since WinXP/IE5 */
+#    endif
+#    include <shlobj.h>
+#    include <windows.h>
 #endif
 
 #include "gromacs/fileio/gmxfio.h"
@@ -117,24 +121,23 @@
 
 
 typedef int (*initfunc)();
-typedef int (*regfunc)(void *, vmdplugin_register_cb);
+typedef int (*regfunc)(void*, vmdplugin_register_cb);
 typedef int (*finifunc)();
 
 
-
-static int register_cb(void *v, vmdplugin_t *p)
+static int register_cb(void* v, vmdplugin_t* p)
 {
-    const char      *key       = p->name;
-    gmx_vmdplugin_t *vmdplugin = static_cast<gmx_vmdplugin_t *>(v);
+    const char*      key       = p->name;
+    gmx_vmdplugin_t* vmdplugin = static_cast<gmx_vmdplugin_t*>(v);
 
     if (strcmp(key, vmdplugin->filetype) == 0)
     {
-        vmdplugin->api = reinterpret_cast<molfile_plugin_t *>(p);
+        vmdplugin->api = reinterpret_cast<molfile_plugin_t*>(p);
     }
     return VMDPLUGIN_SUCCESS;
 }
 
-static int load_sharedlibrary_plugins(const char *fullpath, gmx_vmdplugin_t *vmdplugin)
+static int load_sharedlibrary_plugins(const char* fullpath, gmx_vmdplugin_t* vmdplugin)
 {
     /* Open the dll; try to execute the init function. */
     void *handle, *ifunc, *registerfunc;
@@ -143,7 +146,8 @@ static int load_sharedlibrary_plugins(const char *fullpath, gmx_vmdplugin_t *vmd
     {
         if (debug)
         {
-            fprintf(debug, "\nUnable to open dynamic library %s.\n%s\n",  fullpath, vmddlerror());         /*only to debug because of stdc++ erros */
+            fprintf(debug, "\nUnable to open dynamic library %s.\n%s\n", fullpath,
+                    vmddlerror()); /*only to debug because of stdc++ erros */
         }
         return 0;
     }
@@ -179,7 +183,7 @@ static int load_sharedlibrary_plugins(const char *fullpath, gmx_vmdplugin_t *vmd
 }
 
 /*return: 1: success, 0: last frame, -1: error*/
-gmx_bool read_next_vmd_frame(gmx_vmdplugin_t *vmdplugin, t_trxframe *fr)
+gmx_bool read_next_vmd_frame(gmx_vmdplugin_t* vmdplugin, t_trxframe* fr)
 {
     int                rc, i;
     rvec               vec, angle;
@@ -189,10 +193,10 @@ gmx_bool read_next_vmd_frame(gmx_vmdplugin_t *vmdplugin, t_trxframe *fr)
     fr->bV = vmdplugin->bV;
 
 #if GMX_DOUBLE
-    snew(ts.coords, fr->natoms*3);
+    snew(ts.coords, fr->natoms * 3);
     if (fr->bV)
     {
-        snew(ts.velocities, fr->natoms*3);
+        snew(ts.velocities, fr->natoms * 3);
     }
 #else
     ts.coords = reinterpret_cast<float*>(fr->x);
@@ -217,14 +221,14 @@ gmx_bool read_next_vmd_frame(gmx_vmdplugin_t *vmdplugin, t_trxframe *fr)
 #if GMX_DOUBLE
     for (i = 0; i < fr->natoms; i++)
     {
-        fr->x[i][0] = .1*ts.coords[i*3];
-        fr->x[i][1] = .1*ts.coords[i*3+1];
-        fr->x[i][2] = .1*ts.coords[i*3+2];
+        fr->x[i][0] = .1 * ts.coords[i * 3];
+        fr->x[i][1] = .1 * ts.coords[i * 3 + 1];
+        fr->x[i][2] = .1 * ts.coords[i * 3 + 2];
         if (fr->bV)
         {
-            fr->v[i][0] = .1*ts.velocities[i*3];
-            fr->v[i][1] = .1*ts.velocities[i*3+1];
-            fr->v[i][2] = .1*ts.velocities[i*3+2];
+            fr->v[i][0] = .1 * ts.velocities[i * 3];
+            fr->v[i][1] = .1 * ts.velocities[i * 3 + 1];
+            fr->v[i][2] = .1 * ts.velocities[i * 3 + 2];
         }
     }
     sfree(ts.coords);
@@ -245,8 +249,12 @@ gmx_bool read_next_vmd_frame(gmx_vmdplugin_t *vmdplugin, t_trxframe *fr)
 
     fr->bX   = true;
     fr->bBox = true;
-    vec[0]   = .1*ts.A; vec[1] = .1*ts.B; vec[2] = .1*ts.C;
-    angle[0] = ts.alpha; angle[1] = ts.beta; angle[2] = ts.gamma;
+    vec[0]   = .1 * ts.A;
+    vec[1]   = .1 * ts.B;
+    vec[2]   = .1 * ts.C;
+    angle[0] = ts.alpha;
+    angle[1] = ts.beta;
+    angle[2] = ts.gamma;
     matrix_convert(fr->box, vec, angle);
     if (vmdplugin->api->abiversion > 10)
     {
@@ -262,25 +270,22 @@ gmx_bool read_next_vmd_frame(gmx_vmdplugin_t *vmdplugin, t_trxframe *fr)
     return true;
 }
 
-static int load_vmd_library(const char *fn, gmx_vmdplugin_t *vmdplugin)
+static int load_vmd_library(const char* fn, gmx_vmdplugin_t* vmdplugin)
 {
-    char            pathname[GMX_PATH_MAX];
-    const char     *pathenv;
-    const char     *err;
-    int             ret = 0;
-    char            pathenv_buffer[GMX_PATH_MAX];
+    const char* err;
+    int         ret = 0;
 #if !GMX_NATIVE_WINDOWS
-    glob_t          globbuf;
-    const char     *defpath_suffix = "/plugins/*/molfile";
-    const char     *defpathenv     = GMX_VMD_PLUGIN_PATH;
+    glob_t            globbuf;
+    const std::string defpath_suffix = "/plugins/*/molfile";
+    const std::string defpathenv     = GMX_VMD_PLUGIN_PATH;
 #else
     WIN32_FIND_DATA ffd;
     HANDLE          hFind = INVALID_HANDLE_VALUE;
     char            progfolder[GMX_PATH_MAX];
-    char            defpathenv[GMX_PATH_MAX];
-    const char     *defpath_suffix = "\\plugins\\WIN32\\molfile";
+    std::string     defpath_suffix = "\\plugins\\WIN32\\molfile";
     SHGetFolderPath(NULL, CSIDL_PROGRAM_FILES, NULL, SHGFP_TYPE_CURRENT, progfolder);
-    sprintf(defpathenv, "%s\\University of Illinois\\VMD\\plugins\\WIN32\\molfile", progfolder);
+    std::string defpathenv =
+            gmx::formatString("%s\\University of Illinois\\VMD\\plugins\\WIN32\\molfile", progfolder);
 #endif
 
     vmdplugin->api      = nullptr;
@@ -295,32 +300,26 @@ static int load_vmd_library(const char *fn, gmx_vmdplugin_t *vmdplugin)
      * plugins, then an implicit run-time path, and finally for one
      * given at configure time. This last might be hard-coded to the
      * default for VMD installs. */
-    pathenv = getenv("VMD_PLUGIN_PATH");
-    if (pathenv == nullptr)
+    std::string pathenv = getenv("VMD_PLUGIN_PATH");
+    if (pathenv.empty())
     {
         pathenv = getenv("VMDDIR");
-        if (nullptr == pathenv)
+        if (pathenv.empty())
         {
             printf("\nNeither VMD_PLUGIN_PATH or VMDDIR set. ");
-            printf("Using default location:\n%s\n", defpathenv);
+            printf("Using default location:\n%s\n", defpathenv.c_str());
             pathenv = defpathenv;
         }
         else
         {
             printf("\nVMD_PLUGIN_PATH no set, but VMDDIR is set. ");
-#ifdef _MSC_VER
-            _snprintf_s(pathenv_buffer, sizeof(pathenv_buffer), _TRUNCATE, "%s%s", pathenv, defpath_suffix);
-#else
-            snprintf(pathenv_buffer, sizeof(pathenv_buffer), "%s%s", pathenv, defpath_suffix);
-#endif
-            printf("Using semi-default location:\n%s\n", pathenv_buffer);
-            pathenv = pathenv_buffer;
+            pathenv = gmx::Path::join(pathenv, defpath_suffix);
+            printf("Using semi-default location:\n%s\n", pathenv.c_str());
         }
     }
-    strncpy(pathname, pathenv, sizeof(pathname));
 #if !GMX_NATIVE_WINDOWS
-    strcat(pathname, "/*.so");
-    glob(pathname, 0, nullptr, &globbuf);
+    std::string pathname = gmx::Path::join(pathenv, "/*.so");
+    glob(pathname.c_str(), 0, nullptr, &globbuf);
     if (globbuf.gl_pathc == 0)
     {
         printf("\nNo VMD Plugins found\n"
@@ -340,8 +339,8 @@ static int load_vmd_library(const char *fn, gmx_vmdplugin_t *vmdplugin)
     }
     globfree(&globbuf);
 #else
-    strcat(pathname, "\\*.so");
-    hFind = FindFirstFile(pathname, &ffd);
+    std::string pathname = gmx::Path::join(pathenv, "\\*.so");
+    hFind                = FindFirstFile(pathname.c_str(), &ffd);
     if (INVALID_HANDLE_VALUE == hFind)
     {
         printf("\nNo VMD Plugins found\n");
@@ -349,11 +348,9 @@ static int load_vmd_library(const char *fn, gmx_vmdplugin_t *vmdplugin)
     }
     do
     {
-        char filename[GMX_PATH_MAX];
-        sprintf(filename, "%s\\%s", pathenv, ffd.cFileName);
-        ret |= load_sharedlibrary_plugins(filename, vmdplugin);
-    }
-    while (FindNextFile(hFind, &ffd )  != 0 && vmdplugin->api == NULL);
+        std::string filename = gmx::Path::join(pathenv, ffd.cFileName);
+        ret |= load_sharedlibrary_plugins(filename.c_str(), vmdplugin);
+    } while (FindNextFile(hFind, &ffd) != 0 && vmdplugin->api == NULL);
     FindClose(hFind);
 #endif
 
@@ -387,13 +384,12 @@ static int load_vmd_library(const char *fn, gmx_vmdplugin_t *vmdplugin)
     printf("\nUsing VMD plugin: %s (%s)\n", vmdplugin->api->name, vmdplugin->api->prettyname);
 
     return 1;
-
 }
 
-int read_first_vmd_frame(const char *fn, gmx_vmdplugin_t **vmdpluginp, t_trxframe *fr)
+int read_first_vmd_frame(const char* fn, gmx_vmdplugin_t** vmdpluginp, t_trxframe* fr)
 {
-    molfile_timestep_metadata_t *metadata = nullptr;
-    gmx_vmdplugin_t             *vmdplugin;
+    molfile_timestep_metadata_t* metadata = nullptr;
+    gmx_vmdplugin_t*             vmdplugin;
 
     snew(vmdplugin, 1);
     *vmdpluginp = vmdplugin;
@@ -406,8 +402,7 @@ int read_first_vmd_frame(const char *fn, gmx_vmdplugin_t **vmdpluginp, t_trxfram
 
     if (!vmdplugin->handle)
     {
-        fprintf(stderr, "\nError: could not open file '%s' for reading.\n",
-                fn);
+        fprintf(stderr, "\nError: could not open file '%s' for reading.\n", fn);
         return 0;
     }
 
@@ -418,13 +413,12 @@ int read_first_vmd_frame(const char *fn, gmx_vmdplugin_t **vmdpluginp, t_trxfram
     }
     else if (fr->natoms == MOLFILE_NUMATOMS_NONE)
     {
-        fprintf(stderr, "\nNo atoms found by VMD plugin in file %s.\n", fn );
+        fprintf(stderr, "\nNo atoms found by VMD plugin in file %s.\n", fn);
         return 0;
     }
-    else if (fr->natoms < 1)     /*should not be reached*/
+    else if (fr->natoms < 1) /*should not be reached*/
     {
-        fprintf(stderr, "\nUnknown number of atoms %d for VMD plugin opening file %s.\n",
-                fr->natoms, fn );
+        fprintf(stderr, "\nUnknown number of atoms %d for VMD plugin opening file %s.\n", fr->natoms, fn);
         return 0;
     }
 
@@ -449,5 +443,4 @@ int read_first_vmd_frame(const char *fn, gmx_vmdplugin_t **vmdpluginp, t_trxfram
                 "\nEither way, GROMACS cannot tell whether the trajectory has velocities.\n");
     }
     return 1;
-
 }
