@@ -3,7 +3,7 @@
  *
  * Copyright (c) 1991-2000, University of Groningen, The Netherlands.
  * Copyright (c) 2001-2004, The GROMACS development team.
- * Copyright (c) 2013,2014,2015,2016,2017,2018, by the GROMACS development team, led by
+ * Copyright (c) 2013,2014,2015,2016,2017,2018,2019, by the GROMACS development team, led by
  * Mark Abraham, David van der Spoel, Berk Hess, and Erik Lindahl,
  * and including many others, as listed in the AUTHORS file in the
  * top-level source directory and at http://www.gromacs.org.
@@ -46,7 +46,8 @@
 #include "gromacs/utility/fatalerror.h"
 #include "gromacs/utility/smalloc.h"
 
-typedef struct warninp {
+typedef struct warninp
+{
     gmx_bool    bAllowWarnings;
     int         nwarn_note;
     int         nwarn_warn;
@@ -63,20 +64,20 @@ warninp_t init_warning(gmx_bool bAllowWarnings, int maxwarning)
     wi->bAllowWarnings = bAllowWarnings;
     wi->maxwarn        = maxwarning;
     warning_reset(wi);
-    wi->filenm         = "unknown";
-    wi->lineno         = 0;
+    wi->filenm = "unknown";
+    wi->lineno = 0;
 
     return wi;
 }
 
 void warning_reset(warninp_t wi)
 {
-    wi->nwarn_note     = 0;
-    wi->nwarn_warn     = 0;
-    wi->nwarn_error    = 0;
+    wi->nwarn_note  = 0;
+    wi->nwarn_warn  = 0;
+    wi->nwarn_error = 0;
 }
 
-void set_warning_line(warninp_t wi, const char *s, int line)
+void set_warning_line(warninp_t wi, const char* s, int line)
 {
     if (s != nullptr)
     {
@@ -90,12 +91,12 @@ int get_warning_line(warninp_t wi)
     return wi->lineno;
 }
 
-const char *get_warning_file(warninp_t wi)
+const char* get_warning_file(warninp_t wi)
 {
     return wi->filenm.c_str();
 }
 
-static void low_warning(warninp_t wi, const char *wtype, int n, const char *s)
+static void low_warning(warninp_t wi, const char* wtype, int n, const char* s)
 {
 #define indent 2
     char *temp, *temp2;
@@ -105,25 +106,24 @@ static void low_warning(warninp_t wi, const char *wtype, int n, const char *s)
     {
         s = "Empty error message.";
     }
-    snew(temp, std::strlen(s)+indent+1);
+    snew(temp, std::strlen(s) + indent + 1);
     for (i = 0; i < indent; i++)
     {
         temp[i] = ' ';
     }
     temp[indent] = '\0';
     std::strcat(temp, s);
-    temp2 = wrap_lines(temp, 78-indent, indent, FALSE);
+    temp2 = wrap_lines(temp, 78 - indent, indent, FALSE);
     if (!wi->filenm.empty())
     {
         if (wi->lineno != -1)
         {
-            fprintf(stderr, "\n%s %d [file %s, line %d]:\n%s\n\n",
-                    wtype, n, wi->filenm.c_str(), wi->lineno, temp2);
+            fprintf(stderr, "\n%s %d [file %s, line %d]:\n%s\n\n", wtype, n, wi->filenm.c_str(),
+                    wi->lineno, temp2);
         }
         else
         {
-            fprintf(stderr, "\n%s %d [file %s]:\n%s\n\n",
-                    wtype, n, wi->filenm.c_str(), temp2);
+            fprintf(stderr, "\n%s %d [file %s]:\n%s\n\n", wtype, n, wi->filenm.c_str(), temp2);
         }
     }
     else
@@ -134,7 +134,7 @@ static void low_warning(warninp_t wi, const char *wtype, int n, const char *s)
     sfree(temp2);
 }
 
-void warning(warninp_t wi, const char *s)
+void warning(warninp_t wi, const char* s)
 {
     if (wi->bAllowWarnings)
     {
@@ -147,54 +147,52 @@ void warning(warninp_t wi, const char *s)
     }
 }
 
-void warning(warninp_t wi, const std::string &s)
+void warning(warninp_t wi, const std::string& s)
 {
     warning(wi, s.c_str());
 }
 
-void warning_note(warninp_t wi, const char *s)
+void warning_note(warninp_t wi, const char* s)
 {
     wi->nwarn_note++;
     low_warning(wi, "NOTE", wi->nwarn_note, s);
 }
 
-void warning_note(warninp_t wi, const std::string &s)
+void warning_note(warninp_t wi, const std::string& s)
 {
     warning_note(wi, s.c_str());
 }
 
-void warning_error(warninp_t wi, const char *s)
+void warning_error(warninp_t wi, const char* s)
 {
     wi->nwarn_error++;
     low_warning(wi, "ERROR", wi->nwarn_error, s);
 }
 
-void warning_error(warninp_t wi, const std::string &s)
+void warning_error(warninp_t wi, const std::string& s)
 {
     warning_error(wi, s.c_str());
 }
 
-static void print_warn_count(const char *type, int n)
+static void print_warn_count(const char* type, int n)
 {
     if (n > 0)
     {
-        fprintf(stderr, "\nThere %s %d %s%s\n",
-                (n == 1) ? "was" : "were", n, type, (n == 1) ? "" : "s");
+        fprintf(stderr, "\nThere %s %d %s%s\n", (n == 1) ? "was" : "were", n, type, (n == 1) ? "" : "s");
     }
 }
 
 // Note it is the caller's responsibility to ensure that exiting is correct behaviour
-[[noreturn]] static void check_warning_error_impl(warninp_t wi, int f_errno, const char *file, int line)
+[[noreturn]] static void check_warning_error_impl(warninp_t wi, int f_errno, const char* file, int line)
 {
     print_warn_count("note", wi->nwarn_note);
     print_warn_count("warning", wi->nwarn_warn);
 
     gmx_fatal(f_errno, file, line, "There %s %d error%s in input file(s)",
-              (wi->nwarn_error == 1) ? "was" : "were", wi->nwarn_error,
-              (wi->nwarn_error == 1) ? ""    : "s");
+              (wi->nwarn_error == 1) ? "was" : "were", wi->nwarn_error, (wi->nwarn_error == 1) ? "" : "s");
 }
 
-void check_warning_error(warninp_t wi, int f_errno, const char *file, int line)
+void check_warning_error(warninp_t wi, int f_errno, const char* file, int line)
 {
     if (wi->nwarn_error > 0)
     {
@@ -202,13 +200,13 @@ void check_warning_error(warninp_t wi, int f_errno, const char *file, int line)
     }
 }
 
-void warning_error_and_exit(warninp_t wi, const char *s, int f_errno, const char *file, int line)
+void warning_error_and_exit(warninp_t wi, const char* s, int f_errno, const char* file, int line)
 {
     warning_error(wi, s);
     check_warning_error_impl(wi, f_errno, file, line);
 }
 
-void warning_error_and_exit(warninp_t wi, const std::string &s, int f_errno, const char *file, int line)
+void warning_error_and_exit(warninp_t wi, const std::string& s, int f_errno, const char* file, int line)
 {
     warning_error_and_exit(wi, s.c_str(), f_errno, file, line);
 }
@@ -218,7 +216,7 @@ gmx_bool warning_errors_exist(warninp_t wi)
     return (wi->nwarn_error > 0);
 }
 
-void done_warning(warninp_t wi, int f_errno, const char *file, int line)
+void done_warning(warninp_t wi, int f_errno, const char* file, int line)
 {
     // If we've had an error, then this will report the number of
     // notes and warnings, and then exit.
@@ -244,22 +242,18 @@ void free_warning(warninp_t wi)
     delete wi;
 }
 
-void _too_few(warninp_t wi, const char *fn, int line)
+void _too_few(warninp_t wi, const char* fn, int line)
 {
     char buf[STRLEN];
 
-    sprintf(buf,
-            "Too few parameters on line (source file %s, line %d)",
-            fn, line);
+    sprintf(buf, "Too few parameters on line (source file %s, line %d)", fn, line);
     warning(wi, buf);
 }
 
-void _incorrect_n_param(warninp_t wi, const char *fn, int line)
+void _incorrect_n_param(warninp_t wi, const char* fn, int line)
 {
     char buf[STRLEN];
 
-    sprintf(buf,
-            "Incorrect number of parameters on line (source file %s, line %d)",
-            fn, line);
+    sprintf(buf, "Incorrect number of parameters on line (source file %s, line %d)", fn, line);
     warning(wi, buf);
 }
