@@ -1,7 +1,8 @@
 /*
  * This file is part of the GROMACS molecular simulation package.
  *
- * Copyright (c) 2010,2011,2012,2013,2014,2015,2016,2017,2018, by the GROMACS development team, led by
+ * Copyright (c) 2010-2018, The GROMACS development team.
+ * Copyright (c) 2019, by the GROMACS development team, led by
  * Mark Abraham, David van der Spoel, Berk Hess, and Erik Lindahl,
  * and including many others, as listed in the AUTHORS file in the
  * top-level source directory and at http://www.gromacs.org.
@@ -65,11 +66,15 @@
 #include "gromacs/utility/smalloc.h"
 
 
-enum {
-    methSEL, methBISECT, methFUNCFIT, methNR
+enum
+{
+    methSEL,
+    methBISECT,
+    methFUNCFIT,
+    methNR
 };
 
-static void center_coords(const t_atoms *atoms, matrix box, rvec x0[], int axis)
+static void center_coords(const t_atoms* atoms, matrix box, rvec x0[], int axis)
 {
     int  i, m;
     real tmass, mm;
@@ -79,11 +84,11 @@ static void center_coords(const t_atoms *atoms, matrix box, rvec x0[], int axis)
     clear_rvec(com);
     for (i = 0; (i < atoms->nr); i++)
     {
-        mm     = atoms->atom[i].m;
+        mm = atoms->atom[i].m;
         tmass += mm;
         for (m = 0; (m < DIM); m++)
         {
-            com[m] += mm*x0[i][m];
+            com[m] += mm * x0[i][m];
         }
     }
     for (m = 0; (m < DIM); m++)
@@ -101,30 +106,45 @@ static void center_coords(const t_atoms *atoms, matrix box, rvec x0[], int axis)
 }
 
 
-static void density_in_time (const char *fn, int **index, const int gnx[], real bw, real bwz, int nsttblock, real *****Densdevel, int *xslices, int *yslices, int *zslices, int *tblock, const t_topology *top, int ePBC, int axis, gmx_bool bCenter, gmx_bool bps1d, const gmx_output_env_t *oenv)
+static void density_in_time(const char*             fn,
+                            int**                   index,
+                            const int               gnx[],
+                            real                    bw,
+                            real                    bwz,
+                            int                     nsttblock,
+                            real*****               Densdevel,
+                            int*                    xslices,
+                            int*                    yslices,
+                            int*                    zslices,
+                            int*                    tblock,
+                            const t_topology*       top,
+                            int                     ePBC,
+                            int                     axis,
+                            gmx_bool                bCenter,
+                            gmx_bool                bps1d,
+                            const gmx_output_env_t* oenv)
 
 {
-/*
- * *****Densdevel pointer to array of density values in slices and frame-blocks Densdevel[*nsttblock][*xslices][*yslices][*zslices]
- * Densslice[x][y][z]
- * nsttblock - nr of frames in each time-block
- * bw  widths of normal slices
- *
- * axis	 - axis direction (normal to slices)
- * nndx - number ot atoms in **index
- * grpn	 - group number in index
- */
-    t_trxstatus *status;
+    /*
+     * *****Densdevel pointer to array of density values in slices and frame-blocks
+     * Densdevel[*nsttblock][*xslices][*yslices][*zslices] Densslice[x][y][z] nsttblock - nr of
+     * frames in each time-block bw  widths of normal slices
+     *
+     * axis	 - axis direction (normal to slices)
+     * nndx - number ot atoms in **index
+     * grpn	 - group number in index
+     */
+    t_trxstatus* status;
     gmx_rmpbc_t  gpbc = nullptr;
-    matrix       box;                    /* Box - 3x3 -each step*/
-    rvec        *x0;                     /* List of Coord without PBC*/
-    int          i, j,                   /* loop indices, checks etc*/
-                 ax1     = 0, ax2 = 0,   /* tangent directions */
-                 framenr = 0,            /* frame number in trajectory*/
-                 slicex, slicey, slicez; /*slice # of x y z position */
-    real ***Densslice = nullptr;         /* Density-slice in one frame*/
-    real    dscale;                      /*physical scaling factor*/
-    real    t, x, y, z;                  /* time and coordinates*/
+    matrix       box;               /* Box - 3x3 -each step*/
+    rvec*        x0;                /* List of Coord without PBC*/
+    int          i, j,              /* loop indices, checks etc*/
+            ax1 = 0, ax2 = 0,       /* tangent directions */
+            framenr = 0,            /* frame number in trajectory*/
+            slicex, slicey, slicez; /*slice # of x y z position */
+    real*** Densslice = nullptr;    /* Density-slice in one frame*/
+    real    dscale;                 /*physical scaling factor*/
+    real    t, x, y, z;             /* time and coordinates*/
     rvec    bbww;
 
     *tblock = 0; /* blocknr in block average - initialise to 0*/
@@ -132,27 +152,27 @@ static void density_in_time (const char *fn, int **index, const int gnx[], real
     switch (axis)
     {
         case 0:
-            ax1 = YY; ax2 = ZZ; /*Surface: YZ*/
+            ax1 = YY;
+            ax2 = ZZ; /*Surface: YZ*/
             break;
         case 1:
-            ax1 = ZZ; ax2 = XX; /* Surface : XZ*/
+            ax1 = ZZ;
+            ax2 = XX; /* Surface : XZ*/
             break;
         case 2:
-            ax1 = XX; ax2 = YY; /* Surface XY*/
+            ax1 = XX;
+            ax2 = YY; /* Surface XY*/
             break;
-        default:
-            gmx_fatal(FARGS, "Invalid axes. Terminating\n");
+        default: gmx_fatal(FARGS, "Invalid axes. Terminating\n");
     }
 
     if (read_first_x(oenv, &status, fn, &t, &x0, box) == 0)
     {
         gmx_fatal(FARGS, "Could not read coordinates from file"); /* Open trajectory for read*/
-
-
     }
-    *zslices = 1+static_cast<int>(std::floor(box[axis][axis]/bwz));
-    *yslices = 1+static_cast<int>(std::floor(box[ax2][ax2]/bw));
-    *xslices = 1+static_cast<int>(std::floor(box[ax1][ax1]/bw));
+    *zslices = 1 + static_cast<int>(std::floor(box[axis][axis] / bwz));
+    *yslices = 1 + static_cast<int>(std::floor(box[ax2][ax2] / bw));
+    *xslices = 1 + static_cast<int>(std::floor(box[ax1][ax1] / bw));
     if (bps1d)
     {
         if (*xslices < *yslices)
@@ -164,8 +184,8 @@ static void density_in_time (const char *fn, int **index, const int gnx[], real
             *yslices = 1;
         }
     }
-    fprintf(stderr,
-            "\nDividing the box in %5d x %5d x %5d slices with binw %f along axis %d\n", *xslices, *yslices, *zslices, bw, axis );
+    fprintf(stderr, "\nDividing the box in %5d x %5d x %5d slices with binw %f along axis %d\n",
+            *xslices, *yslices, *zslices, bw, axis);
 
 
     /****Start trajectory processing***/
@@ -177,9 +197,9 @@ static void density_in_time (const char *fn, int **index, const int gnx[], real
 
     do
     {
-        bbww[XX] = box[ax1][ax1]/ *xslices;
-        bbww[YY] = box[ax2][ax2]/ *yslices;
-        bbww[ZZ] = box[axis][axis]/ *zslices;
+        bbww[XX] = box[ax1][ax1] / *xslices;
+        bbww[YY] = box[ax2][ax2] / *yslices;
+        bbww[ZZ] = box[axis][axis] / *zslices;
         gmx_rmpbc(gpbc, top->atoms.nr, box, x0);
         /*Reset Densslice every nsttblock steps*/
         /* The first conditional is for clang to understand that this branch is
@@ -199,11 +219,12 @@ static void density_in_time (const char *fn, int **index, const int gnx[], real
             /* Allocate Memory to  extra frame in Densdevel -  rather stupid approach:
              * A single frame each time, although only every nsttblock steps.
              */
-            srenew(*Densdevel, *tblock+1);
+            srenew(*Densdevel, *tblock + 1);
             (*Densdevel)[*tblock] = Densslice;
         }
 
-        dscale = (*xslices)*(*yslices)*(*zslices)*AMU/ (box[ax1][ax1]*box[ax2][ax2]*box[axis][axis]*nsttblock*(NANO*NANO*NANO));
+        dscale = (*xslices) * (*yslices) * (*zslices) * AMU
+                 / (box[ax1][ax1] * box[ax2][ax2] * box[axis][axis] * nsttblock * (NANO * NANO * NANO));
 
         if (bCenter)
         {
@@ -212,7 +233,7 @@ static void density_in_time (const char *fn, int **index, const int gnx[], real
 
 
         for (j = 0; j < gnx[0]; j++)
-        {   /*Loop over all atoms in selected index*/
+        { /*Loop over all atoms in selected index*/
             x = x0[index[0][j]][ax1];
             y = x0[index[0][j]][ax2];
             z = x0[index[0][j]][axis];
@@ -243,10 +264,10 @@ static void density_in_time (const char *fn, int **index, const int gnx[], real
                 z -= box[axis][axis];
             }
 
-            slicex = static_cast<int>(x/bbww[XX]) % *xslices;
-            slicey = static_cast<int>(y/bbww[YY]) % *yslices;
-            slicez = static_cast<int>(z/bbww[ZZ]) % *zslices;
-            Densslice[slicex][slicey][slicez] += (top->atoms.atom[index[0][j]].m*dscale);
+            slicex = static_cast<int>(x / bbww[XX]) % *xslices;
+            slicey = static_cast<int>(y / bbww[YY]) % *yslices;
+            slicez = static_cast<int>(z / bbww[ZZ]) % *zslices;
+            Densslice[slicex][slicey][slicez] += (top->atoms.atom[index[0][j]].m * dscale);
         }
 
         framenr++;
@@ -258,8 +279,7 @@ static void density_in_time (const char *fn, int **index, const int gnx[], real
             (*tblock)++;
         }
 
-    }
-    while (read_next_x(oenv, status, &t, x0, box));
+    } while (read_next_x(oenv, status, &t, x0, box));
 
 
     /*Free memory we no longer need and exit.*/
@@ -268,7 +288,7 @@ static void density_in_time (const char *fn, int **index, const int gnx[], real
 
     if (/* DISABLES CODE */ (false))
     {
-        FILE *fp;
+        FILE* fp;
         fp = fopen("koko.xvg", "w");
         for (j = 0; (j < *zslices); j++)
         {
@@ -281,14 +301,12 @@ static void density_in_time (const char *fn, int **index, const int gnx[], real
         }
         fclose(fp);
     }
-
 }
 
-static void outputfield(const char *fldfn, real ****Densmap,
-                        int xslices, int yslices, int zslices, int tdim)
+static void outputfield(const char* fldfn, real**** Densmap, int xslices, int yslices, int zslices, int tdim)
 {
-/*Debug-filename and filehandle*/
-    FILE *fldH;
+    /*Debug-filename and filehandle*/
+    FILE* fldH;
     int   n, i, j, k;
     int   dim[4];
     real  totdens = 0;
@@ -314,19 +332,19 @@ static void outputfield(const char *fldfn, real ****Densmap,
             }
         }
     }
-    totdens /= (xslices*yslices*zslices*tdim);
+    totdens /= (xslices * yslices * zslices * tdim);
     fprintf(stderr, "Total density [kg/m^3]  %8f", totdens);
     gmx_ffclose(fldH);
 }
 
-static void filterdensmap(real ****Densmap, int xslices, int yslices, int zslices, int tblocks, int ftsize)
+static void filterdensmap(real**** Densmap, int xslices, int yslices, int zslices, int tblocks, int ftsize)
 {
-    real *kernel;
+    real* kernel;
     real  std, var;
     int   i, j, n, order;
-    order = ftsize/2;
-    std   = order/2.0;
-    var   = std*std;
+    order = ftsize / 2;
+    std   = order / 2.0;
+    var   = std * std;
     snew(kernel, ftsize);
     gausskernel(kernel, ftsize, var);
     for (n = 0; n < tblocks; n++)
@@ -342,31 +360,38 @@ static void filterdensmap(real ****Densmap, int xslices, int yslices, int zslice
 }
 
 
-
-
-static void interfaces_txy (real ****Densmap, int xslices, int yslices, int zslices,
-                            int tblocks, real binwidth, int method,
-                            real dens1, real dens2, t_interf ****intf1,
-                            t_interf ****intf2, const gmx_output_env_t *oenv)
+static void interfaces_txy(real****                Densmap,
+                           int                     xslices,
+                           int                     yslices,
+                           int                     zslices,
+                           int                     tblocks,
+                           real                    binwidth,
+                           int                     method,
+                           real                    dens1,
+                           real                    dens2,
+                           t_interf****            intf1,
+                           t_interf****            intf2,
+                           const gmx_output_env_t* oenv)
 {
     /*Returns two pointers to 3D arrays of t_interf structs containing (position,thickness) of the interface(s)*/
-    FILE         *xvg;
-    real         *zDensavg; /* zDensavg[z]*/
+    FILE*         xvg;
+    real*         zDensavg; /* zDensavg[z]*/
     int           i, j, k, n;
     int           xysize;
     int           ndx1, ndx2, *zperm;
     real          densmid;
     real          splitpoint, startpoint, endpoint;
-    real         *sigma1, *sigma2;
+    real *        sigma1, *sigma2;
     double        beginfit1[4];
     double        beginfit2[4];
-    double       *fit1 = nullptr, *fit2 = nullptr;
-    const double *avgfit1;
-    const double *avgfit2;
-    const real    onehalf = 1.00/2.00;
-    t_interf   ***int1    = nullptr, ***int2 = nullptr; /*Interface matrices [t][x,y] - last index in row-major order*/
+    double *      fit1 = nullptr, *fit2 = nullptr;
+    const double* avgfit1;
+    const double* avgfit2;
+    const real    onehalf = 1.00 / 2.00;
+    t_interf ***  int1    = nullptr,
+             ***int2      = nullptr; /*Interface matrices [t][x,y] - last index in row-major order*/
     /*Create int1(t,xy) and int2(t,xy) arrays with correct number of interf_t elements*/
-    xysize = xslices*yslices;
+    xysize = xslices * yslices;
     snew(int1, tblocks);
     snew(int2, tblocks);
     for (i = 0; i < tblocks; i++)
@@ -384,7 +409,7 @@ static void interfaces_txy (real ****Densmap, int xslices, int yslices, int zsli
 
     if (method == methBISECT)
     {
-        densmid = onehalf*(dens1+dens2);
+        densmid = onehalf * (dens1 + dens2);
         snew(zperm, zslices);
         for (n = 0; n < tblocks; n++)
         {
@@ -394,8 +419,8 @@ static void interfaces_txy (real ****Densmap, int xslices, int yslices, int zsli
                 {
                     rangeArray(zperm, zslices); /*reset permutation array to identity*/
                     /*Binsearch returns slice-nr where the order param is  <= setpoint sgmid*/
-                    ndx1 = start_binsearch(Densmap[n][i][j], zperm, 0, zslices/2-1, densmid, 1);
-                    ndx2 = start_binsearch(Densmap[n][i][j], zperm, zslices/2, zslices-1, densmid, -1);
+                    ndx1 = start_binsearch(Densmap[n][i][j], zperm, 0, zslices / 2 - 1, densmid, 1);
+                    ndx2 = start_binsearch(Densmap[n][i][j], zperm, zslices / 2, zslices - 1, densmid, -1);
 
                     /* Linear interpolation (for use later if time allows)
                      * rho_1s= Densmap[n][i][j][zperm[ndx1]]
@@ -425,10 +450,10 @@ static void interfaces_txy (real ****Densmap, int xslices, int yslices, int zsli
                      * pos=zperm[ndx2]+alpha*deltandx;   */
 
                     /*After filtering we use the direct approach	*/
-                    int1[n][j+(i*yslices)]->Z = (zperm[ndx1]+onehalf)*binwidth;
-                    int1[n][j+(i*yslices)]->t = binwidth;
-                    int2[n][j+(i*yslices)]->Z = (zperm[ndx2]+onehalf)*binwidth;
-                    int2[n][j+(i*yslices)]->t = binwidth;
+                    int1[n][j + (i * yslices)]->Z = (zperm[ndx1] + onehalf) * binwidth;
+                    int1[n][j + (i * yslices)]->t = binwidth;
+                    int2[n][j + (i * yslices)]->Z = (zperm[ndx2] + onehalf) * binwidth;
+                    int2[n][j + (i * yslices)]->t = binwidth;
                 }
             }
         }
@@ -438,17 +463,17 @@ static void interfaces_txy (real ****Densmap, int xslices, int yslices, int zsli
     {
         /*Assume a box divided in 2 along midpoint of z for starters*/
         startpoint = 0.0;
-        endpoint   = binwidth*zslices;
-        splitpoint = (startpoint+endpoint)/2.0;
+        endpoint   = binwidth * zslices;
+        splitpoint = (startpoint + endpoint) / 2.0;
         /*Initial fit proposals*/
         beginfit1[0] = dens1;
         beginfit1[1] = dens2;
-        beginfit1[2] = (splitpoint/2);
+        beginfit1[2] = (splitpoint / 2);
         beginfit1[3] = 0.5;
 
         beginfit2[0] = dens2;
         beginfit2[1] = dens1;
-        beginfit2[2] = (3*splitpoint/2);
+        beginfit2[2] = (3 * splitpoint / 2);
         beginfit2[3] = 0.5;
 
         snew(zDensavg, zslices);
@@ -468,7 +493,7 @@ static void interfaces_txy (real ****Densmap, int xslices, int yslices, int zsli
                 {
                     for (j = 0; j < yslices; j++)
                     {
-                        zDensavg[k] += (Densmap[n][i][j][k]/(xslices*yslices*tblocks));
+                        zDensavg[k] += (Densmap[n][i][j][k] / (xslices * yslices * tblocks));
                     }
                 }
             }
@@ -476,10 +501,11 @@ static void interfaces_txy (real ****Densmap, int xslices, int yslices, int zsli
 
         if (debug)
         {
-            xvg = xvgropen("DensprofileonZ.xvg", "Averaged Densityprofile on Z", "z[nm]", "Density[kg/m^3]", oenv);
+            xvg = xvgropen("DensprofileonZ.xvg", "Averaged Densityprofile on Z", "z[nm]",
+                           "Density[kg/m^3]", oenv);
             for (k = 0; k < zslices; k++)
             {
-                fprintf(xvg, "%4f.3   %8f.4\n", k*binwidth, zDensavg[k]);
+                fprintf(xvg, "%4f.3   %8f.4\n", k * binwidth, zDensavg[k]);
             }
             xvgrclose(xvg);
         }
@@ -487,16 +513,17 @@ static void interfaces_txy (real ****Densmap, int xslices, int yslices, int zsli
         /*Fit average density in z over whole trajectory to obtain tentative fit-parameters in fit1 and fit2*/
 
         /*Fit 1st half of box*/
-        do_lmfit(zslices, zDensavg, sigma1, binwidth, nullptr, startpoint, splitpoint, oenv, FALSE, effnERF, beginfit1, 8, nullptr);
+        do_lmfit(zslices, zDensavg, sigma1, binwidth, nullptr, startpoint, splitpoint, oenv, FALSE,
+                 effnERF, beginfit1, 8, nullptr);
         /*Fit 2nd half of box*/
-        do_lmfit(zslices, zDensavg, sigma2, binwidth, nullptr, splitpoint, endpoint, oenv, FALSE, effnERF, beginfit2, 8, nullptr);
+        do_lmfit(zslices, zDensavg, sigma2, binwidth, nullptr, splitpoint, endpoint, oenv, FALSE,
+                 effnERF, beginfit2, 8, nullptr);
 
         /*Initialise the const arrays for storing the average fit parameters*/
         avgfit1 = beginfit1;
         avgfit2 = beginfit2;
 
 
-
         /*Now do fit over each x  y and t slice to get Zint(x,y,t) - loop is very large, we potentially should average over time directly*/
         for (n = 0; n < tblocks; n++)
         {
@@ -513,12 +540,14 @@ static void interfaces_txy (real ****Densmap, int xslices, int yslices, int zsli
                         fit2[k] = avgfit2[k];
                     }
                     /*Now fit and store in structures in row-major order int[n][i][j]*/
-                    do_lmfit(zslices, Densmap[n][i][j], sigma1, binwidth, nullptr, startpoint, splitpoint, oenv, FALSE, effnERF, fit1, 0, nullptr);
-                    int1[n][j+(yslices*i)]->Z = fit1[2];
-                    int1[n][j+(yslices*i)]->t = fit1[3];
-                    do_lmfit(zslices, Densmap[n][i][j], sigma2, binwidth, nullptr, splitpoint, endpoint, oenv, FALSE, effnERF, fit2, 0, nullptr);
-                    int2[n][j+(yslices*i)]->Z = fit2[2];
-                    int2[n][j+(yslices*i)]->t = fit2[3];
+                    do_lmfit(zslices, Densmap[n][i][j], sigma1, binwidth, nullptr, startpoint,
+                             splitpoint, oenv, FALSE, effnERF, fit1, 0, nullptr);
+                    int1[n][j + (yslices * i)]->Z = fit1[2];
+                    int1[n][j + (yslices * i)]->t = fit1[3];
+                    do_lmfit(zslices, Densmap[n][i][j], sigma2, binwidth, nullptr, splitpoint,
+                             endpoint, oenv, FALSE, effnERF, fit2, 0, nullptr);
+                    int2[n][j + (yslices * i)]->Z = fit2[2];
+                    int2[n][j + (yslices * i)]->t = fit2[3];
                 }
             }
         }
@@ -527,33 +556,41 @@ static void interfaces_txy (real ****Densmap, int xslices, int yslices, int zsli
 
     *intf1 = int1;
     *intf2 = int2;
-
 }
 
-static void writesurftoxpms(t_interf ***surf1, t_interf ***surf2, int tblocks, int xbins, int ybins, int zbins, real bw, real bwz, gmx::ArrayRef<const std::string> outfiles, int maplevels )
+static void writesurftoxpms(t_interf***                      surf1,
+                            t_interf***                      surf2,
+                            int                              tblocks,
+                            int                              xbins,
+                            int                              ybins,
+                            int                              zbins,
+                            real                             bw,
+                            real                             bwz,
+                            gmx::ArrayRef<const std::string> outfiles,
+                            int                              maplevels)
 {
     char   numbuf[STRLEN];
     int    n, i, j;
     real **profile1, **profile2;
     real   max1, max2, min1, min2, *xticks, *yticks;
-    t_rgb  lo = {0, 0, 0};
-    t_rgb  hi = {1, 1, 1};
-    FILE  *xpmfile1, *xpmfile2;
+    t_rgb  lo = { 0, 0, 0 };
+    t_rgb  hi = { 1, 1, 1 };
+    FILE * xpmfile1, *xpmfile2;
 
-/*Prepare xpm structures for output*/
+    /*Prepare xpm structures for output*/
 
-/*Allocate memory to tick's and matrices*/
-    snew (xticks, xbins+1);
-    snew (yticks, ybins+1);
+    /*Allocate memory to tick's and matrices*/
+    snew(xticks, xbins + 1);
+    snew(yticks, ybins + 1);
 
     profile1 = mk_matrix(xbins, ybins, FALSE);
     profile2 = mk_matrix(xbins, ybins, FALSE);
 
-    for (i = 0; i < xbins+1; i++)
+    for (i = 0; i < xbins + 1; i++)
     {
         xticks[i] += bw;
     }
-    for (j = 0; j < ybins+1; j++)
+    for (j = 0; j < ybins + 1; j++)
     {
         yticks[j] += bw;
     }
@@ -562,18 +599,18 @@ static void writesurftoxpms(t_interf ***surf1, t_interf ***surf2, int tblocks, i
     xpmfile2 = gmx_ffopen(outfiles[1], "w");
 
     max1 = max2 = 0.0;
-    min1 = min2 = zbins*bwz;
+    min1 = min2 = zbins * bwz;
 
     for (n = 0; n < tblocks; n++)
     {
         sprintf(numbuf, "tblock: %4i", n);
-/*Filling matrices for inclusion in xpm-files*/
+        /*Filling matrices for inclusion in xpm-files*/
         for (i = 0; i < xbins; i++)
         {
             for (j = 0; j < ybins; j++)
             {
-                profile1[i][j] = (surf1[n][j+ybins*i])->Z;
-                profile2[i][j] = (surf2[n][j+ybins*i])->Z;
+                profile1[i][j] = (surf1[n][j + ybins * i])->Z;
+                profile2[i][j] = (surf2[n][j + ybins * i])->Z;
                 /*Finding max and min values*/
                 if (profile1[i][j] > max1)
                 {
@@ -594,8 +631,10 @@ static void writesurftoxpms(t_interf ***surf1, t_interf ***surf2, int tblocks, i
             }
         }
 
-        write_xpm(xpmfile1, 3, numbuf, "Height", "x[nm]", "y[nm]", xbins, ybins, xticks, yticks, profile1, min1, max1, lo, hi, &maplevels);
-        write_xpm(xpmfile2, 3, numbuf, "Height", "x[nm]", "y[nm]", xbins, ybins, xticks, yticks, profile2, min2, max2, lo, hi, &maplevels);
+        write_xpm(xpmfile1, 3, numbuf, "Height", "x[nm]", "y[nm]", xbins, ybins, xticks, yticks,
+                  profile1, min1, max1, lo, hi, &maplevels);
+        write_xpm(xpmfile2, 3, numbuf, "Height", "x[nm]", "y[nm]", xbins, ybins, xticks, yticks,
+                  profile2, min2, max2, lo, hi, &maplevels);
     }
 
     gmx_ffclose(xpmfile1);
@@ -608,9 +647,13 @@ static void writesurftoxpms(t_interf ***surf1, t_interf ***surf2, int tblocks, i
     sfree(yticks);
 }
 
-static void writeraw(t_interf ***int1, t_interf ***int2, int tblocks,
-                     int xbins, int ybins, gmx::ArrayRef<const std::string> fnms,
-                     const gmx_output_env_t *oenv)
+static void writeraw(t_interf***                      int1,
+                     t_interf***                      int2,
+                     int                              tblocks,
+                     int                              xbins,
+                     int                              ybins,
+                     gmx::ArrayRef<const std::string> fnms,
+                     const gmx_output_env_t*          oenv)
 {
     FILE *raw1, *raw2;
     int   i, j, n;
@@ -622,12 +665,10 @@ static void writeraw(t_interf ***int1, t_interf ***int2, int tblocks,
         gmx::BinaryInformationSettings settings;
         settings.generatedByHeader(true);
         settings.linePrefix("# ");
-        gmx::printBinaryInformation(raw1, output_env_get_program_context(oenv),
-                                    settings);
-        gmx::printBinaryInformation(raw2, output_env_get_program_context(oenv),
-                                    settings);
+        gmx::printBinaryInformation(raw1, output_env_get_program_context(oenv), settings);
+        gmx::printBinaryInformation(raw2, output_env_get_program_context(oenv), settings);
     }
-    GMX_CATCH_ALL_AND_EXIT_WITH_FATAL_ERROR;
+    GMX_CATCH_ALL_AND_EXIT_WITH_FATAL_ERROR
     fprintf(raw1, "# Legend: nt nx ny\n# Xbin Ybin Z t\n");
     fprintf(raw2, "# Legend: nt nx ny\n# Xbin Ybin Z t\n");
     fprintf(raw1, "%i %i %i\n", tblocks, xbins, ybins);
@@ -638,8 +679,10 @@ static void writeraw(t_interf ***int1, t_interf ***int2, int tblocks,
         {
             for (j = 0; j < ybins; j++)
             {
-                fprintf(raw1, "%i  %i  %8.5f  %6.4f\n", i, j, (int1[n][j+ybins*i])->Z, (int1[n][j+ybins*i])->t);
-                fprintf(raw2, "%i  %i  %8.5f  %6.4f\n", i, j, (int2[n][j+ybins*i])->Z, (int2[n][j+ybins*i])->t);
+                fprintf(raw1, "%i  %i  %8.5f  %6.4f\n", i, j, (int1[n][j + ybins * i])->Z,
+                        (int1[n][j + ybins * i])->t);
+                fprintf(raw2, "%i  %i  %8.5f  %6.4f\n", i, j, (int2[n][j + ybins * i])->Z,
+                        (int2[n][j + ybins * i])->t);
             }
         }
     }
@@ -649,25 +692,22 @@ static void writeraw(t_interf ***int1, t_interf ***int2, int tblocks,
 }
 
 
-
-int gmx_densorder(int argc, char *argv[])
+int gmx_densorder(int argc, char* argv[])
 {
-    static const char *desc[] = {
-        "[THISMODULE] reduces a two-phase density distribution",
-        "along an axis, computed over a MD trajectory,",
-        "to 2D surfaces fluctuating in time, by a fit to",
-        "a functional profile for interfacial densities.",
-        "A time-averaged spatial representation of the",
-        "interfaces can be output with the option [TT]-tavg[tt]."
-    };
+    static const char* desc[] = { "[THISMODULE] reduces a two-phase density distribution",
+                                  "along an axis, computed over a MD trajectory,",
+                                  "to 2D surfaces fluctuating in time, by a fit to",
+                                  "a functional profile for interfacial densities.",
+                                  "A time-averaged spatial representation of the",
+                                  "interfaces can be output with the option [TT]-tavg[tt]." };
 
     /* Extra arguments - but note how you always get the begin/end
      * options when running the program, without mentioning them here!
      */
 
-    gmx_output_env_t  *oenv;
-    t_topology        *top;
-    char             **grpname;
+    gmx_output_env_t*  oenv;
+    t_topology*        top;
+    char**             grpname;
     int                ePBC, *ngx;
     static real        binw      = 0.2;
     static real        binwz     = 0.05;
@@ -676,8 +716,8 @@ int gmx_densorder(int argc, char *argv[])
     static int         ftorder   = 0;
     static int         nsttblock = 100;
     static int         axis      = 2;
-    static const char *axtitle   = "Z";
-    int              **index; /* Index list for single group*/
+    static const char* axtitle   = "Z";
+    int**              index; /* Index list for single group*/
     int                xslices, yslices, zslices, tblock;
     static gmx_bool    bGraph   = FALSE;
     static gmx_bool    bCenter  = FALSE;
@@ -687,53 +727,58 @@ int gmx_densorder(int argc, char *argv[])
     static gmx_bool    b1d      = FALSE;
     static int         nlevels  = 100;
     /*Densitymap - Densmap[t][x][y][z]*/
-    real           ****Densmap = nullptr;
+    real**** Densmap = nullptr;
     /* Surfaces surf[t][surf_x,surf_y]*/
-    t_interf        ***surf1, ***surf2;
+    t_interf ***surf1, ***surf2;
 
-    static const char *meth[] = {nullptr, "bisect", "functional", nullptr};
+    static const char* meth[] = { nullptr, "bisect", "functional", nullptr };
     int                eMeth;
 
-    t_pargs            pa[] = {
-        { "-1d", FALSE, etBOOL, {&b1d},
-          "Pseudo-1d interface geometry"},
-        { "-bw", FALSE, etREAL, {&binw},
-          "Binwidth of density distribution tangential to interface"},
-        { "-bwn", FALSE, etREAL, {&binwz},
-          "Binwidth of density distribution normal to interface"},
-        { "-order", FALSE, etINT, {&ftorder},
-          "Order of Gaussian filter, order 0 equates to NO filtering"},
-        {"-axis", FALSE, etSTR, {&axtitle},
-         "Axis Direction - X, Y or Z"},
-        {"-method", FALSE, etENUM, {meth},
-         "Interface location method"},
-        {"-d1", FALSE, etREAL, {&dens1},
-         "Bulk density phase 1 (at small z)"},
-        {"-d2", FALSE, etREAL, {&dens2},
-         "Bulk density phase 2 (at large z)"},
-        { "-tblock", FALSE, etINT, {&nsttblock},
-          "Number of frames in one time-block average"},
-        { "-nlevel", FALSE, etINT, {&nlevels},
-          "Number of Height levels in 2D - XPixMaps"}
+    t_pargs pa[] = {
+        { "-1d", FALSE, etBOOL, { &b1d }, "Pseudo-1d interface geometry" },
+        { "-bw",
+          FALSE,
+          etREAL,
+          { &binw },
+          "Binwidth of density distribution tangential to interface" },
+        { "-bwn",
+          FALSE,
+          etREAL,
+          { &binwz },
+          "Binwidth of density distribution normal to interface" },
+        { "-order",
+          FALSE,
+          etINT,
+          { &ftorder },
+          "Order of Gaussian filter, order 0 equates to NO filtering" },
+        { "-axis", FALSE, etSTR, { &axtitle }, "Axis Direction - X, Y or Z" },
+        { "-method", FALSE, etENUM, { meth }, "Interface location method" },
+        { "-d1", FALSE, etREAL, { &dens1 }, "Bulk density phase 1 (at small z)" },
+        { "-d2", FALSE, etREAL, { &dens2 }, "Bulk density phase 2 (at large z)" },
+        { "-tblock", FALSE, etINT, { &nsttblock }, "Number of frames in one time-block average" },
+        { "-nlevel", FALSE, etINT, { &nlevels }, "Number of Height levels in 2D - XPixMaps" }
     };
 
 
     t_filenm fnm[] = {
-        { efTPR, "-s",  nullptr, ffREAD },            /* this is for the topology */
-        { efTRX, "-f", nullptr, ffREAD },             /* and this for the trajectory */
-        { efNDX, "-n", nullptr, ffREAD},              /* this is to select groups */
-        { efDAT, "-o", "Density4D", ffOPTWR},         /* This is for outputting the entire 4D densityfield in binary format */
-        { efOUT, "-or", nullptr, ffOPTWRMULT},        /* This is for writing out the entire information in the t_interf arrays */
-        { efXPM, "-og", "interface", ffOPTWRMULT},    /* This is for writing out the interface meshes - one xpm-file per tblock*/
-        { efOUT, "-Spect", "intfspect", ffOPTWRMULT}, /* This is for the trajectory averaged Fourier-spectra*/
+        { efTPR, "-s", nullptr, ffREAD }, /* this is for the topology */
+        { efTRX, "-f", nullptr, ffREAD }, /* and this for the trajectory */
+        { efNDX, "-n", nullptr, ffREAD }, /* this is to select groups */
+        { efDAT, "-o", "Density4D",
+          ffOPTWR }, /* This is for outputting the entire 4D densityfield in binary format */
+        { efOUT, "-or", nullptr,
+          ffOPTWRMULT }, /* This is for writing out the entire information in the t_interf arrays */
+        { efXPM, "-og", "interface",
+          ffOPTWRMULT }, /* This is for writing out the interface meshes - one xpm-file per tblock*/
+        { efOUT, "-Spect", "intfspect", ffOPTWRMULT }, /* This is for the trajectory averaged Fourier-spectra*/
     };
 
 #define NFILE asize(fnm)
 
     /* This is the routine responsible for adding default options,
      * calling the X/motif interface, etc. */
-    if (!parse_common_args(&argc, argv, PCA_CAN_TIME | PCA_CAN_VIEW,
-                           NFILE, fnm, asize(pa), pa, asize(desc), desc, 0, nullptr, &oenv))
+    if (!parse_common_args(&argc, argv, PCA_CAN_TIME | PCA_CAN_VIEW, NFILE, fnm, asize(pa), pa,
+                           asize(desc), desc, 0, nullptr, &oenv))
     {
         return 0;
     }
@@ -749,16 +794,17 @@ int gmx_densorder(int argc, char *argv[])
     snew(index, 1);
     snew(ngx, 1);
 
-/* Calculate axis */
+    /* Calculate axis */
     axis = toupper(axtitle[0]) - 'X';
 
     get_index(&top->atoms, ftp2fn_null(efNDX, NFILE, fnm), 1, ngx, index, grpname);
 
-    density_in_time(ftp2fn(efTRX, NFILE, fnm), index, ngx, binw, binwz, nsttblock, &Densmap, &xslices, &yslices, &zslices, &tblock, top, ePBC, axis, bCenter, b1d, oenv);
+    density_in_time(ftp2fn(efTRX, NFILE, fnm), index, ngx, binw, binwz, nsttblock, &Densmap,
+                    &xslices, &yslices, &zslices, &tblock, top, ePBC, axis, bCenter, b1d, oenv);
 
     if (ftorder > 0)
     {
-        filterdensmap(Densmap, xslices, yslices, zslices, tblock, 2*ftorder+1);
+        filterdensmap(Densmap, xslices, yslices, zslices, tblock, 2 * ftorder + 1);
     }
 
     if (bOut)
@@ -766,7 +812,8 @@ int gmx_densorder(int argc, char *argv[])
         outputfield(opt2fn("-o", NFILE, fnm), Densmap, xslices, yslices, zslices, tblock);
     }
 
-    interfaces_txy(Densmap, xslices, yslices, zslices, tblock, binwz, eMeth, dens1, dens2, &surf1, &surf2, oenv);
+    interfaces_txy(Densmap, xslices, yslices, zslices, tblock, binwz, eMeth, dens1, dens2, &surf1,
+                   &surf2, oenv);
 
     if (bGraph)
     {
@@ -775,35 +822,30 @@ int gmx_densorder(int argc, char *argv[])
         gmx::ArrayRef<const std::string> graphFiles = opt2fns("-og", NFILE, fnm);
         if (graphFiles.size() != 2)
         {
-            gmx_fatal(FARGS, "No or not correct number (2) of output-files: %td", graphFiles.size());
+            gmx_fatal(FARGS, "No or not correct number (2) of output-files: %td", graphFiles.ssize());
         }
         writesurftoxpms(surf1, surf2, tblock, xslices, yslices, zslices, binw, binwz, graphFiles, zslices);
     }
 
 
-
-
-
-/*Output raw-data*/
+    /*Output raw-data*/
     if (bRawOut)
     {
         gmx::ArrayRef<const std::string> rawFiles = opt2fns("-or", NFILE, fnm);
         if (rawFiles.size() != 2)
         {
-            gmx_fatal(FARGS, "No or not correct number (2) of output-files: %td", rawFiles.size());
+            gmx_fatal(FARGS, "No or not correct number (2) of output-files: %td", rawFiles.ssize());
         }
         writeraw(surf1, surf2, tblock, xslices, yslices, rawFiles, oenv);
     }
 
 
-
     if (bFourier)
     {
         gmx::ArrayRef<const std::string> spectra = opt2fns("-Spect", NFILE, fnm);
         if (spectra.size() != 2)
         {
-            gmx_fatal(FARGS, "No or not correct number (2) of output-file-series: %td",
-                      spectra.size());
+            gmx_fatal(FARGS, "No or not correct number (2) of output-file-series: %td", spectra.ssize());
         }
         powerspectavg_intf(surf1, surf2, tblock, xslices, yslices, spectra);
     }
