@@ -1,7 +1,8 @@
 /*
  * This file is part of the GROMACS molecular simulation package.
  *
- * Copyright (c) 2010,2011,2012,2013,2014,2015,2017,2018, by the GROMACS development team, led by
+ * Copyright (c) 2010-2018, The GROMACS development team.
+ * Copyright (c) 2019, by the GROMACS development team, led by
  * Mark Abraham, David van der Spoel, Berk Hess, and Erik Lindahl,
  * and including many others, as listed in the AUTHORS file in the
  * top-level source directory and at http://www.gromacs.org.
@@ -59,20 +60,28 @@
 #include "gromacs/utility/gmxassert.h"
 #include "gromacs/utility/smalloc.h"
 
-static void find_tetra_order_grid(t_topology top, int ePBC,
-                                  int natoms, matrix box,
-                                  rvec x[], int maxidx, const int index[],
-                                  real *sgmean, real *skmean,
-                                  int nslicex, int nslicey, int nslicez,
-                                  real ***sggrid, real ***skgrid)
+static void find_tetra_order_grid(t_topology top,
+                                  int        ePBC,
+                                  int        natoms,
+                                  matrix     box,
+                                  rvec       x[],
+                                  int        maxidx,
+                                  const int  index[],
+                                  real*      sgmean,
+                                  real*      skmean,
+                                  int        nslicex,
+                                  int        nslicey,
+                                  int        nslicez,
+                                  real***    sggrid,
+                                  real***    skgrid)
 {
     int         ix, jx, i, j, k, l, n, *nn[4];
     rvec        dx, rj, rk, urk, urj;
     real        cost, cost2, *sgmol, *skmol, rmean, rmean2, r2, box2, *r_nn[4];
     t_pbc       pbc;
     int         slindex_x, slindex_y, slindex_z;
-    int      ***sl_count;
-    real        onethird = 1.0/3.0;
+    int***      sl_count;
+    real        onethird = 1.0 / 3.0;
     gmx_rmpbc_t gpbc;
 
     /*  dmat = init_mat(maxidx, FALSE); */
@@ -114,7 +123,7 @@ static void find_tetra_order_grid(t_topology top, int ePBC,
     *skmean = 0.0;
     l       = 0;
     for (i = 0; (i < maxidx); i++)
-    {   /* loop over index file */
+    { /* loop over index file */
         ix = index[i];
         for (j = 0; (j < maxidx); j++)
         {
@@ -134,25 +143,35 @@ static void find_tetra_order_grid(t_topology top, int ePBC,
             /* determine the nearest neighbours */
             if (r2 < r_nn[0][i])
             {
-                r_nn[3][i] = r_nn[2][i]; nn[3][i] = nn[2][i];
-                r_nn[2][i] = r_nn[1][i]; nn[2][i] = nn[1][i];
-                r_nn[1][i] = r_nn[0][i]; nn[1][i] = nn[0][i];
-                r_nn[0][i] = r2;         nn[0][i] = j;
+                r_nn[3][i] = r_nn[2][i];
+                nn[3][i]   = nn[2][i];
+                r_nn[2][i] = r_nn[1][i];
+                nn[2][i]   = nn[1][i];
+                r_nn[1][i] = r_nn[0][i];
+                nn[1][i]   = nn[0][i];
+                r_nn[0][i] = r2;
+                nn[0][i]   = j;
             }
             else if (r2 < r_nn[1][i])
             {
-                r_nn[3][i] = r_nn[2][i]; nn[3][i] = nn[2][i];
-                r_nn[2][i] = r_nn[1][i]; nn[2][i] = nn[1][i];
-                r_nn[1][i] = r2;         nn[1][i] = j;
+                r_nn[3][i] = r_nn[2][i];
+                nn[3][i]   = nn[2][i];
+                r_nn[2][i] = r_nn[1][i];
+                nn[2][i]   = nn[1][i];
+                r_nn[1][i] = r2;
+                nn[1][i]   = j;
             }
             else if (r2 < r_nn[2][i])
             {
-                r_nn[3][i] = r_nn[2][i]; nn[3][i] = nn[2][i];
-                r_nn[2][i] = r2;         nn[2][i] = j;
+                r_nn[3][i] = r_nn[2][i];
+                nn[3][i]   = nn[2][i];
+                r_nn[2][i] = r2;
+                nn[2][i]   = j;
             }
             else if (r2 < r_nn[3][i])
             {
-                r_nn[3][i] = r2;         nn[3][i] = j;
+                r_nn[3][i] = r2;
+                nn[3][i]   = j;
             }
         }
 
@@ -162,7 +181,7 @@ static void find_tetra_order_grid(t_topology top, int ePBC,
         for (j = 0; (j < 4); j++)
         {
             r_nn[j][i] = std::sqrt(r_nn[j][i]);
-            rmean     += r_nn[j][i];
+            rmean += r_nn[j][i];
         }
         rmean /= 4;
 
@@ -174,7 +193,7 @@ static void find_tetra_order_grid(t_topology top, int ePBC,
         /* angular part tetrahedrality order parameter per atom */
         for (j = 0; (j < 3); j++)
         {
-            for (k = j+1; (k < 4); k++)
+            for (k = j + 1; (k < 4); k++)
             {
                 pbc_dx(&pbc, x[ix], x[index[nn[k][i]]], rk);
                 pbc_dx(&pbc, x[ix], x[index[nn[j][i]]], rj);
@@ -191,7 +210,7 @@ static void find_tetra_order_grid(t_topology top, int ePBC,
             }
         }
         /* normalize sgmol between 0.0 and 1.0 */
-        sgmol[i] = 3*sgmol[i]/32;
+        sgmol[i] = 3 * sgmol[i] / 32;
         *sgmean += sgmol[i];
 
         /* distance part tetrahedrality order parameter per atom */
@@ -207,9 +226,9 @@ static void find_tetra_order_grid(t_topology top, int ePBC,
         *skmean += skmol[i];
 
         /* Compute sliced stuff in x y z*/
-        slindex_x = static_cast<int>(std::round((1+x[i][XX]/box[XX][XX])*nslicex)) % nslicex;
-        slindex_y = static_cast<int>(std::round((1+x[i][YY]/box[YY][YY])*nslicey)) % nslicey;
-        slindex_z = static_cast<int>(std::round((1+x[i][ZZ]/box[ZZ][ZZ])*nslicez)) % nslicez;
+        slindex_x = static_cast<int>(std::round((1 + x[i][XX] / box[XX][XX]) * nslicex)) % nslicex;
+        slindex_y = static_cast<int>(std::round((1 + x[i][YY] / box[YY][YY]) * nslicey)) % nslicey;
+        slindex_z = static_cast<int>(std::round((1 + x[i][ZZ] / box[ZZ][ZZ]) * nslicez)) % nslicez;
         sggrid[slindex_x][slindex_y][slindex_z] += sgmol[i];
         skgrid[slindex_x][slindex_y][slindex_z] += skmol[i];
         (sl_count[slindex_x][slindex_y][slindex_z])++;
@@ -246,43 +265,52 @@ static void find_tetra_order_grid(t_topology top, int ePBC,
 /*Determines interface from tetrahedral order parameter in box with specified binwidth.  */
 /*Outputs interface positions(bins), the number of timeframes, and the number of surface-mesh points in xy*/
 
-static void calc_tetra_order_interface(const char *fnNDX, const char *fnTPS, const char *fnTRX, real binw, int tblock,
-                                       int *nframes,  int *nslicex, int *nslicey,
-                                       real sgang1, real sgang2, real ****intfpos,
-                                       gmx_output_env_t *oenv)
+static void calc_tetra_order_interface(const char*       fnNDX,
+                                       const char*       fnTPS,
+                                       const char*       fnTRX,
+                                       real              binw,
+                                       int               tblock,
+                                       int*              nframes,
+                                       int*              nslicex,
+                                       int*              nslicey,
+                                       real              sgang1,
+                                       real              sgang2,
+                                       real****          intfpos,
+                                       gmx_output_env_t* oenv)
 {
-    FILE         *fpsg   = nullptr, *fpsk = nullptr;
-    t_topology    top;
-    int           ePBC;
-    t_trxstatus  *status;
-    int           natoms;
-    real          t;
-    rvec         *xtop, *x;
-    matrix        box;
-    real          sg, sk, sgintf;
-    int         **index   = nullptr;
-    char        **grpname = nullptr;
-    int           i, j, k, n, *isize, ng, nslicez, framenr;
-    real       ***sg_grid = nullptr, ***sk_grid = nullptr, ***sg_fravg = nullptr, ***sk_fravg = nullptr, ****sk_4d = nullptr, ****sg_4d = nullptr;
-    int          *perm;
-    int           ndx1, ndx2;
-    int           bins;
-    const real    onehalf = 1.0/2.0;
+    FILE *       fpsg = nullptr, *fpsk = nullptr;
+    t_topology   top;
+    int          ePBC;
+    t_trxstatus* status;
+    int          natoms;
+    real         t;
+    rvec *       xtop, *x;
+    matrix       box;
+    real         sg, sk, sgintf;
+    int**        index   = nullptr;
+    char**       grpname = nullptr;
+    int          i, j, k, n, *isize, ng, nslicez, framenr;
+    real ***sg_grid = nullptr, ***sk_grid = nullptr, ***sg_fravg = nullptr, ***sk_fravg = nullptr,
+         ****sk_4d = nullptr, ****sg_4d = nullptr;
+    int*       perm;
+    int        ndx1, ndx2;
+    int        bins;
+    const real onehalf = 1.0 / 2.0;
     /* real   ***intfpos[2]; pointers to arrays of two interface positions zcoord(framenr,xbin,ybin): intfpos[interface_index][t][nslicey*x+y]
      * i.e 1D Row-major order in (t,x,y) */
 
 
     read_tps_conf(fnTPS, &top, &ePBC, &xtop, nullptr, box, FALSE);
 
-    *nslicex = static_cast<int>(box[XX][XX]/binw + onehalf); /*Calculate slicenr from binwidth*/
-    *nslicey = static_cast<int>(box[YY][YY]/binw + onehalf);
-    nslicez  = static_cast<int>(box[ZZ][ZZ]/binw +  onehalf);
-
+    *nslicex = static_cast<int>(box[XX][XX] / binw + onehalf); /*Calculate slicenr from binwidth*/
+    *nslicey = static_cast<int>(box[YY][YY] / binw + onehalf);
+    nslicez  = static_cast<int>(box[ZZ][ZZ] / binw + onehalf);
 
 
     ng = 1;
     /* get index groups */
-    printf("Select the group that contains the atoms you want to use for the tetrahedrality order parameter calculation:\n");
+    printf("Select the group that contains the atoms you want to use for the tetrahedrality order "
+           "parameter calculation:\n");
     snew(grpname, ng);
     snew(index, ng);
     snew(isize, ng);
@@ -292,8 +320,7 @@ static void calc_tetra_order_interface(const char *fnNDX, const char *fnTPS, con
     natoms = read_first_x(oenv, &status, fnTRX, &t, &x, box);
     if (natoms > top.atoms.nr)
     {
-        gmx_fatal(FARGS, "Topology (%d atoms) does not match trajectory (%d atoms)",
-                  top.atoms.nr, natoms);
+        gmx_fatal(FARGS, "Topology (%d atoms) does not match trajectory (%d atoms)", top.atoms.nr, natoms);
     }
     check_index(nullptr, ng, index[0], nullptr, natoms);
 
@@ -317,14 +344,14 @@ static void calc_tetra_order_interface(const char *fnNDX, const char *fnTPS, con
     *nframes = 0;
     framenr  = 0;
 
-/* Loop over frames*/
+    /* Loop over frames*/
     do
     {
         /*Initialize box meshes (temporary storage for each tblock frame -reinitialise every tblock steps */
-        if (framenr%tblock == 0)
+        if (framenr % tblock == 0)
         {
-            srenew(sk_4d, *nframes+1);
-            srenew(sg_4d, *nframes+1);
+            srenew(sk_4d, *nframes + 1);
+            srenew(sg_4d, *nframes + 1);
             snew(sg_fravg, *nslicex);
             snew(sk_fravg, *nslicex);
             for (i = 0; i < *nslicex; i++)
@@ -339,8 +366,8 @@ static void calc_tetra_order_interface(const char *fnNDX, const char *fnTPS, con
             }
         }
 
-        find_tetra_order_grid(top, ePBC, natoms, box, x, isize[0], index[0],
-                              &sg, &sk, *nslicex, *nslicey, nslicez, sg_grid, sk_grid);
+        find_tetra_order_grid(top, ePBC, natoms, box, x, isize[0], index[0], &sg, &sk, *nslicex,
+                              *nslicey, nslicez, sg_grid, sk_grid);
         GMX_RELEASE_ASSERT(sk_fravg != nullptr, "Trying to dereference NULL sk_fravg pointer");
         for (i = 0; i < *nslicex; i++)
         {
@@ -348,15 +375,15 @@ static void calc_tetra_order_interface(const char *fnNDX, const char *fnTPS, con
             {
                 for (k = 0; k < nslicez; k++)
                 {
-                    sk_fravg[i][j][k] += sk_grid[i][j][k]/tblock;
-                    sg_fravg[i][j][k] += sg_grid[i][j][k]/tblock;
+                    sk_fravg[i][j][k] += sk_grid[i][j][k] / tblock;
+                    sg_fravg[i][j][k] += sg_grid[i][j][k] / tblock;
                 }
             }
         }
 
         framenr++;
 
-        if (framenr%tblock == 0)
+        if (framenr % tblock == 0)
         {
             GMX_RELEASE_ASSERT(sk_4d != nullptr, "Trying to dereference NULL sk_4d pointer");
             sk_4d[*nframes] = sk_fravg;
@@ -364,8 +391,7 @@ static void calc_tetra_order_interface(const char *fnNDX, const char *fnTPS, con
             (*nframes)++;
         }
 
-    }
-    while (read_next_x(oenv, status, &t, x, box));
+    } while (read_next_x(oenv, status, &t, x, box));
     close_trx(status);
 
     sfree(grpname);
@@ -375,8 +401,10 @@ static void calc_tetra_order_interface(const char *fnNDX, const char *fnTPS, con
     /*Debugging for printing out the entire order parameter meshes.*/
     if (debug)
     {
-        fpsg = xvgropen("sg_ang_mesh", "S\\sg\\N Angle Order Parameter / Meshpoint", "(nm)", "S\\sg\\N", oenv);
-        fpsk = xvgropen("sk_dist_mesh", "S\\sk\\N Distance Order Parameter / Meshpoint", "(nm)", "S\\sk\\N", oenv);
+        fpsg = xvgropen("sg_ang_mesh", "S\\sg\\N Angle Order Parameter / Meshpoint", "(nm)",
+                        "S\\sg\\N", oenv);
+        fpsk = xvgropen("sk_dist_mesh", "S\\sk\\N Distance Order Parameter / Meshpoint", "(nm)",
+                        "S\\sk\\N", oenv);
         for (n = 0; n < (*nframes); n++)
         {
             fprintf(fpsg, "%i\n", n);
@@ -387,8 +415,12 @@ static void calc_tetra_order_interface(const char *fnNDX, const char *fnTPS, con
                 {
                     for (k = 0; k < nslicez; k++)
                     {
-                        fprintf(fpsg, "%4f  %4f  %4f  %8f\n", (i+0.5)*box[XX][XX]/(*nslicex), (j+0.5)*box[YY][YY]/(*nslicey), (k+0.5)*box[ZZ][ZZ]/nslicez, sg_4d[n][i][j][k]);
-                        fprintf(fpsk, "%4f  %4f  %4f  %8f\n", (i+0.5)*box[XX][XX]/(*nslicex), (j+0.5)*box[YY][YY]/(*nslicey), (k+0.5)*box[ZZ][ZZ]/nslicez, sk_4d[n][i][j][k]);
+                        fprintf(fpsg, "%4f  %4f  %4f  %8f\n", (i + 0.5) * box[XX][XX] / (*nslicex),
+                                (j + 0.5) * box[YY][YY] / (*nslicey),
+                                (k + 0.5) * box[ZZ][ZZ] / nslicez, sg_4d[n][i][j][k]);
+                        fprintf(fpsk, "%4f  %4f  %4f  %8f\n", (i + 0.5) * box[XX][XX] / (*nslicex),
+                                (j + 0.5) * box[YY][YY] / (*nslicey),
+                                (k + 0.5) * box[ZZ][ZZ] / nslicez, sk_4d[n][i][j][k]);
                     }
                 }
             }
@@ -401,7 +433,7 @@ static void calc_tetra_order_interface(const char *fnNDX, const char *fnTPS, con
     /* Find positions of interface z by scanning orderparam for each frame and for each xy-mesh cylinder along z*/
 
     /*Simple trial: assume interface is in the middle of -sgang1 and sgang2*/
-    sgintf = 0.5*(sgang1+sgang2);
+    sgintf = 0.5 * (sgang1 + sgang2);
 
 
     /*Allocate memory for interface arrays; */
@@ -409,10 +441,10 @@ static void calc_tetra_order_interface(const char *fnNDX, const char *fnTPS, con
     snew((*intfpos)[0], *nframes);
     snew((*intfpos)[1], *nframes);
 
-    bins = (*nslicex)*(*nslicey);
+    bins = (*nslicex) * (*nslicey);
 
 
-    snew(perm, nslicez);  /*permutation array for sorting along normal coordinate*/
+    snew(perm, nslicez); /*permutation array for sorting along normal coordinate*/
 
 
     for (n = 0; n < *nframes; n++)
@@ -425,18 +457,18 @@ static void calc_tetra_order_interface(const char *fnNDX, const char *fnTPS, con
             {
                 rangeArray(perm, nslicez); /*reset permutation array to identity*/
                 /*Binsearch returns 2 bin-numbers where the order param is  <= setpoint sgintf*/
-                ndx1 = start_binsearch(sg_4d[n][i][j], perm, 0, nslicez/2-1, sgintf, 1);
-                ndx2 = start_binsearch(sg_4d[n][i][j], perm, nslicez/2, nslicez-1, sgintf, -1);
+                ndx1 = start_binsearch(sg_4d[n][i][j], perm, 0, nslicez / 2 - 1, sgintf, 1);
+                ndx2 = start_binsearch(sg_4d[n][i][j], perm, nslicez / 2, nslicez - 1, sgintf, -1);
                 /*Use linear interpolation to smooth out the interface position*/
 
                 /*left interface (0)*/
                 /*if((sg_4d[n][i][j][perm[ndx1+1]]-sg_4d[n][i][j][perm[ndx1]])/sg_4d[n][i][j][perm[ndx1]] > 0.01){
                    pos=( (sgintf-sg_4d[n][i][j][perm[ndx1]])*perm[ndx1+1]+(sg_4d[n][i][j][perm[ndx1+1]]-sgintf)*perm[ndx1 ])*/
-                (*intfpos)[0][n][j+*nslicey*i] = (perm[ndx1]+onehalf)*binw;
+                (*intfpos)[0][n][j + *nslicey * i] = (perm[ndx1] + onehalf) * binw;
                 /*right interface (1)*/
                 /*alpha=(sgintf-sg_4d[n][i][j][perm[ndx2]])/(sg_4d[n][i][j][perm[ndx2]+1]-sg_4d[n][i][j][perm[ndx2]]);*/
                 /*(*intfpos)[1][n][j+*nslicey*i]=((1-alpha)*perm[ndx2]+alpha*(perm[ndx2]+1)+onehalf)*box[ZZ][ZZ]/nslicez;*/
-                (*intfpos)[1][n][j+*nslicey*i] = (perm[ndx2]+onehalf)*binw;
+                (*intfpos)[1][n][j + *nslicey * i] = (perm[ndx2] + onehalf) * binw;
             }
         }
     }
@@ -446,31 +478,37 @@ static void calc_tetra_order_interface(const char *fnNDX, const char *fnTPS, con
     sfree(sg_4d);
 }
 
-static void writesurftoxpms(real ***surf, int tblocks, int xbins, int ybins, real bw, gmx::ArrayRef<const std::string> outfiles, int maplevels )
+static void writesurftoxpms(real***                          surf,
+                            int                              tblocks,
+                            int                              xbins,
+                            int                              ybins,
+                            real                             bw,
+                            gmx::ArrayRef<const std::string> outfiles,
+                            int                              maplevels)
 {
 
     char   numbuf[STRLEN];
     int    n, i, j;
     real **profile1, **profile2;
     real   max1, max2, min1, min2, *xticks, *yticks;
-    t_rgb  lo = {1, 1, 1};
-    t_rgb  hi = {0, 0, 0};
-    FILE  *xpmfile1, *xpmfile2;
+    t_rgb  lo = { 1, 1, 1 };
+    t_rgb  hi = { 0, 0, 0 };
+    FILE * xpmfile1, *xpmfile2;
 
-/*Prepare xpm structures for output*/
+    /*Prepare xpm structures for output*/
 
-/*Allocate memory to tick's and matrices*/
-    snew (xticks, xbins+1);
-    snew (yticks, ybins+1);
+    /*Allocate memory to tick's and matrices*/
+    snew(xticks, xbins + 1);
+    snew(yticks, ybins + 1);
 
     profile1 = mk_matrix(xbins, ybins, FALSE);
     profile2 = mk_matrix(xbins, ybins, FALSE);
 
-    for (i = 0; i < xbins+1; i++)
+    for (i = 0; i < xbins + 1; i++)
     {
         xticks[i] += bw;
     }
-    for (j = 0; j < ybins+1; j++)
+    for (j = 0; j < ybins + 1; j++)
     {
         yticks[j] += bw;
     }
@@ -489,8 +527,8 @@ static void writesurftoxpms(real ***surf, int tblocks, int xbins, int ybins, rea
         {
             for (j = 0; j < ybins; j++)
             {
-                profile1[i][j] = (surf[0][n][j+ybins*i]);
-                profile2[i][j] = (surf[1][n][j+ybins*i]);
+                profile1[i][j] = (surf[0][n][j + ybins * i]);
+                profile2[i][j] = (surf[1][n][j + ybins * i]);
                 /*Finding max and min values*/
                 if (profile1[i][j] > max1)
                 {
@@ -511,15 +549,16 @@ static void writesurftoxpms(real ***surf, int tblocks, int xbins, int ybins, rea
             }
         }
 
-        write_xpm(xpmfile1, 3, numbuf, "Height", "x[nm]", "y[nm]", xbins, ybins, xticks, yticks, profile1, min1, max1, lo, hi, &maplevels);
-        write_xpm(xpmfile2, 3, numbuf, "Height", "x[nm]", "y[nm]", xbins, ybins, xticks, yticks, profile2, min2, max2, lo, hi, &maplevels);
+        write_xpm(xpmfile1, 3, numbuf, "Height", "x[nm]", "y[nm]", xbins, ybins, xticks, yticks,
+                  profile1, min1, max1, lo, hi, &maplevels);
+        write_xpm(xpmfile2, 3, numbuf, "Height", "x[nm]", "y[nm]", xbins, ybins, xticks, yticks,
+                  profile2, min2, max2, lo, hi, &maplevels);
     }
 
     gmx_ffclose(xpmfile1);
     gmx_ffclose(xpmfile2);
 
 
-
     sfree(profile1);
     sfree(profile2);
     sfree(xticks);
@@ -527,8 +566,7 @@ static void writesurftoxpms(real ***surf, int tblocks, int xbins, int ybins, rea
 }
 
 
-static void writeraw(real ***surf, int tblocks, int xbins, int ybins,
-                     gmx::ArrayRef<const std::string> fnms)
+static void writeraw(real*** surf, int tblocks, int xbins, int ybins, gmx::ArrayRef<const std::string> fnms)
 {
     FILE *raw1, *raw2;
     int   i, j, n;
@@ -545,8 +583,8 @@ static void writeraw(real ***surf, int tblocks, int xbins, int ybins,
         {
             for (j = 0; j < ybins; j++)
             {
-                fprintf(raw1, "%i  %i  %8.5f\n", i, j, (surf[0][n][j+ybins*i]));
-                fprintf(raw2, "%i  %i  %8.5f\n", i, j, (surf[1][n][j+ybins*i]));
+                fprintf(raw1, "%i  %i  %8.5f\n", i, j, (surf[0][n][j + ybins * i]));
+                fprintf(raw2, "%i  %i  %8.5f\n", i, j, (surf[1][n][j + ybins * i]));
             }
         }
     }
@@ -556,10 +594,9 @@ static void writeraw(real ***surf, int tblocks, int xbins, int ybins,
 }
 
 
-
-int gmx_hydorder(int argc, char *argv[])
+int gmx_hydorder(int argc, char* argv[])
 {
-    static const char *desc[] = {
+    static const char* desc[] = {
         "[THISMODULE] computes the tetrahedrality order parameters around a ",
         "given atom. Both angle an distance order parameters are calculated. See",
         "P.-L. Chau and A.J. Hardwick, Mol. Phys., 93, (1998), 511-518.",
@@ -575,44 +612,39 @@ int gmx_hydorder(int argc, char *argv[])
     static int         nlevels   = 100;
     static real        binwidth  = 1.0; /* binwidth in mesh           */
     static real        sg1       = 1;
-    static real        sg2       = 1;   /* order parameters for bulk phases */
+    static real        sg2       = 1; /* order parameters for bulk phases */
     static gmx_bool    bFourier  = FALSE;
     static gmx_bool    bRawOut   = FALSE;
     int                frames, xslices, yslices; /* Dimensions of interface arrays*/
-    real            ***intfpos;                  /* Interface arrays (intfnr,t,xy) -potentially large */
-    static const char *normal_axis[] = { nullptr, "z", "x", "y", nullptr };
+    real***            intfpos; /* Interface arrays (intfnr,t,xy) -potentially large */
+    static const char* normal_axis[] = { nullptr, "z", "x", "y", nullptr };
 
-    t_pargs            pa[] = {
-        { "-d",   FALSE, etENUM, {normal_axis},
-          "Direction of the normal on the membrane" },
-        { "-bw",  FALSE, etREAL, {&binwidth},
-          "Binwidth of box mesh" },
-        { "-sgang1", FALSE, etREAL, {&sg1},
-          "tetrahedral angle parameter in Phase 1 (bulk)" },
-        { "-sgang2", FALSE, etREAL, {&sg2},
-          "tetrahedral angle parameter in Phase 2 (bulk)" },
-        { "-tblock", FALSE, etINT, {&nsttblock},
-          "Number of frames in one time-block average"},
-        { "-nlevel", FALSE, etINT, {&nlevels},
-          "Number of Height levels in 2D - XPixMaps"}
+    t_pargs pa[] = {
+        { "-d", FALSE, etENUM, { normal_axis }, "Direction of the normal on the membrane" },
+        { "-bw", FALSE, etREAL, { &binwidth }, "Binwidth of box mesh" },
+        { "-sgang1", FALSE, etREAL, { &sg1 }, "tetrahedral angle parameter in Phase 1 (bulk)" },
+        { "-sgang2", FALSE, etREAL, { &sg2 }, "tetrahedral angle parameter in Phase 2 (bulk)" },
+        { "-tblock", FALSE, etINT, { &nsttblock }, "Number of frames in one time-block average" },
+        { "-nlevel", FALSE, etINT, { &nlevels }, "Number of Height levels in 2D - XPixMaps" }
     };
 
-    t_filenm           fnm[] = {                      /* files for g_order    */
-        { efTRX, "-f", nullptr,  ffREAD },            /* trajectory file              */
-        { efNDX, "-n", nullptr,  ffREAD },            /* index file           */
-        { efTPR, "-s", nullptr,  ffREAD },            /* topology file                */
-        { efXPM, "-o", "intf",  ffWRMULT},            /* XPM- surface maps	*/
-        { efOUT, "-or", "raw", ffOPTWRMULT },         /* xvgr output file           */
-        { efOUT, "-Spect", "intfspect", ffOPTWRMULT}, /* Fourier spectrum interfaces */
+    t_filenm fnm[] = {
+        /* files for g_order    */
+        { efTRX, "-f", nullptr, ffREAD },              /* trajectory file              */
+        { efNDX, "-n", nullptr, ffREAD },              /* index file           */
+        { efTPR, "-s", nullptr, ffREAD },              /* topology file                */
+        { efXPM, "-o", "intf", ffWRMULT },             /* XPM- surface maps	*/
+        { efOUT, "-or", "raw", ffOPTWRMULT },          /* xvgr output file           */
+        { efOUT, "-Spect", "intfspect", ffOPTWRMULT }, /* Fourier spectrum interfaces */
     };
 #define NFILE asize(fnm)
 
     /*Filenames*/
-    const char       *ndxfnm, *tpsfnm, *trxfnm;
-    gmx_output_env_t *oenv;
+    const char *      ndxfnm, *tpsfnm, *trxfnm;
+    gmx_output_env_t* oenv;
 
-    if (!parse_common_args(&argc, argv, PCA_CAN_VIEW | PCA_CAN_TIME,
-                           NFILE, fnm, asize(pa), pa, asize(desc), desc, 0, nullptr, &oenv))
+    if (!parse_common_args(&argc, argv, PCA_CAN_VIEW | PCA_CAN_TIME, NFILE, fnm, asize(pa), pa,
+                           asize(desc), desc, 0, nullptr, &oenv))
     {
         return 0;
     }
@@ -629,7 +661,8 @@ int gmx_hydorder(int argc, char *argv[])
     trxfnm = ftp2fn(efTRX, NFILE, fnm);
 
     /* Calculate axis */
-    GMX_RELEASE_ASSERT(normal_axis[0] != nullptr, "Option setting inconsistency; normal_axis[0] is NULL");
+    GMX_RELEASE_ASSERT(normal_axis[0] != nullptr,
+                       "Option setting inconsistency; normal_axis[0] is NULL");
     if (std::strcmp(normal_axis[0], "x") == 0)
     {
         axis = XX;
@@ -649,15 +682,9 @@ int gmx_hydorder(int argc, char *argv[])
 
     switch (axis)
     {
-        case 0:
-            fprintf(stderr, "Taking x axis as normal to the membrane\n");
-            break;
-        case 1:
-            fprintf(stderr, "Taking y axis as normal to the membrane\n");
-            break;
-        case 2:
-            fprintf(stderr, "Taking z axis as normal to the membrane\n");
-            break;
+        case 0: fprintf(stderr, "Taking x axis as normal to the membrane\n"); break;
+        case 1: fprintf(stderr, "Taking y axis as normal to the membrane\n"); break;
+        case 2: fprintf(stderr, "Taking z axis as normal to the membrane\n"); break;
     }
 
     /* tetraheder order parameter */
@@ -665,9 +692,10 @@ int gmx_hydorder(int argc, char *argv[])
     gmx::ArrayRef<const std::string> intfn = opt2fns("-o", NFILE, fnm);
     if (intfn.size() != 2)
     {
-        gmx_fatal(FARGS, "No or not correct number (2) of output-files: %td", intfn.size());
+        gmx_fatal(FARGS, "No or not correct number (2) of output-files: %td", intfn.ssize());
     }
-    calc_tetra_order_interface(ndxfnm, tpsfnm, trxfnm, binwidth, nsttblock, &frames, &xslices, &yslices, sg1, sg2, &intfpos, oenv);
+    calc_tetra_order_interface(ndxfnm, tpsfnm, trxfnm, binwidth, nsttblock, &frames, &xslices,
+                               &yslices, sg1, sg2, &intfpos, oenv);
     writesurftoxpms(intfpos, frames, xslices, yslices, binwidth, intfn, nlevels);
 
     if (bFourier)
@@ -675,7 +703,7 @@ int gmx_hydorder(int argc, char *argv[])
         gmx::ArrayRef<const std::string> spectra = opt2fns("-Spect", NFILE, fnm);
         if (spectra.size() != 2)
         {
-            gmx_fatal(FARGS, "No or not correct number (2) of output-files: %td", spectra.size());
+            gmx_fatal(FARGS, "No or not correct number (2) of output-files: %td", spectra.ssize());
         }
         powerspectavg(intfpos, frames, xslices, yslices, spectra);
     }
@@ -685,7 +713,7 @@ int gmx_hydorder(int argc, char *argv[])
         gmx::ArrayRef<const std::string> raw = opt2fns("-or", NFILE, fnm);
         if (raw.size() != 2)
         {
-            gmx_fatal(FARGS, "No or not correct number (2) of output-files: %td", raw.size());
+            gmx_fatal(FARGS, "No or not correct number (2) of output-files: %td", raw.ssize());
         }
         writeraw(intfpos, frames, xslices, yslices, raw);
     }
