@@ -3,7 +3,7 @@
  *
  * Copyright (c) 1991-2000, University of Groningen, The Netherlands.
  * Copyright (c) 2001-2004, The GROMACS development team.
- * Copyright (c) 2013,2014,2015,2016,2017, by the GROMACS development team, led by
+ * Copyright (c) 2013,2014,2015,2016,2017,2019, by the GROMACS development team, led by
  * Mark Abraham, David van der Spoel, Berk Hess, and Erik Lindahl,
  * and including many others, as listed in the AUTHORS file in the
  * top-level source directory and at http://www.gromacs.org.
@@ -59,9 +59,9 @@
 #include "gromacs/utility/smalloc.h"
 
 
-int gmx_nmens(int argc, char *argv[])
+int gmx_nmens(int argc, char* argv[])
 {
-    const char *desc[] = {
+    const char* desc[] = {
         "[THISMODULE] generates an ensemble around an average structure",
         "in a subspace that is defined by a set of normal modes (eigenvectors).",
         "The eigenvectors are assumed to be mass-weighted.",
@@ -71,64 +71,56 @@ int gmx_nmens(int argc, char *argv[])
         "normal modes are the translational and rotational degrees of freedom."
     };
     static int  nstruct = 100, first = 7, last = -1, seed = 0;
-    static real temp    = 300.0;
-    t_pargs     pa[]    = {
-        { "-temp",  FALSE, etREAL, {&temp},
-          "Temperature in Kelvin" },
-        { "-seed", FALSE, etINT, {&seed},
-          "Random seed (0 means generate)" },
-        { "-num", FALSE, etINT, {&nstruct},
-          "Number of structures to generate" },
-        { "-first", FALSE, etINT, {&first},
-          "First eigenvector to use (-1 is select)" },
-        { "-last",  FALSE, etINT, {&last},
-          "Last eigenvector to use (-1 is till the last)" }
+    static real temp = 300.0;
+    t_pargs     pa[] = {
+        { "-temp", FALSE, etREAL, { &temp }, "Temperature in Kelvin" },
+        { "-seed", FALSE, etINT, { &seed }, "Random seed (0 means generate)" },
+        { "-num", FALSE, etINT, { &nstruct }, "Number of structures to generate" },
+        { "-first", FALSE, etINT, { &first }, "First eigenvector to use (-1 is select)" },
+        { "-last", FALSE, etINT, { &last }, "Last eigenvector to use (-1 is till the last)" }
     };
 #define NPA asize(pa)
 
-    t_trxstatus        *out;
+    t_trxstatus*        out;
     t_topology          top;
     int                 ePBC;
-    t_atoms            *atoms;
-    rvec               *xtop, *xref, *xav, *xout1, *xout2;
+    t_atoms*            atoms;
+    rvec *              xtop, *xref, *xav, *xout1, *xout2;
     gmx_bool            bDMR, bDMA, bFit;
     int                 nvec, *eignr = nullptr;
-    rvec              **eigvec = nullptr;
+    rvec**              eigvec = nullptr;
     matrix              box;
-    real               *eigval, *invsqrtm, t, disp;
+    real *              eigval, *invsqrtm, t, disp;
     int                 natoms;
-    char               *grpname;
-    const char         *indexfile;
+    char*               grpname;
+    const char*         indexfile;
     int                 i, j, d, s, v;
     int                 nout, *iout, noutvec, *outvec;
-    int                *index;
+    int*                index;
     real                rfac, rhalf, jr;
-    gmx_output_env_t   *oenv;
+    gmx_output_env_t*   oenv;
     int                 jran;
     const unsigned long im = 0xffff;
     const unsigned long ia = 1093;
     const unsigned long ic = 18257;
 
 
-    t_filenm fnm[] = {
-        { efTRN, "-v",    "eigenvec",    ffREAD  },
-        { efXVG, "-e",    "eigenval",    ffREAD  },
-        { efTPS, nullptr,    nullptr,          ffREAD },
-        { efNDX, nullptr,    nullptr,          ffOPTRD },
-        { efTRO, "-o",    "ensemble",    ffWRITE }
-    };
+    t_filenm fnm[] = { { efTRN, "-v", "eigenvec", ffREAD },
+                       { efXVG, "-e", "eigenval", ffREAD },
+                       { efTPS, nullptr, nullptr, ffREAD },
+                       { efNDX, nullptr, nullptr, ffOPTRD },
+                       { efTRO, "-o", "ensemble", ffWRITE } };
 #define NFILE asize(fnm)
 
-    if (!parse_common_args(&argc, argv, 0,
-                           NFILE, fnm, NPA, pa, asize(desc), desc, 0, nullptr, &oenv))
+    if (!parse_common_args(&argc, argv, 0, NFILE, fnm, NPA, pa, asize(desc), desc, 0, nullptr, &oenv))
     {
         return 0;
     }
 
     indexfile = ftp2fn_null(efNDX, NFILE, fnm);
 
-    read_eigenvectors(opt2fn("-v", NFILE, fnm), &natoms, &bFit,
-                      &xref, &bDMR, &xav, &bDMA, &nvec, &eignr, &eigvec, &eigval);
+    read_eigenvectors(opt2fn("-v", NFILE, fnm), &natoms, &bFit, &xref, &bDMR, &xav, &bDMA, &nvec,
+                      &eignr, &eigvec, &eigval);
 
     read_tps_conf(ftp2fn(efTPS, NFILE, fnm), &top, &ePBC, &xtop, nullptr, box, bDMA);
     atoms = &top.atoms;
@@ -137,8 +129,7 @@ int gmx_nmens(int argc, char *argv[])
     get_index(atoms, indexfile, 1, &i, &index, &grpname);
     if (i != natoms)
     {
-        gmx_fatal(FARGS, "you selected a group with %d elements instead of %d",
-                  i, natoms);
+        gmx_fatal(FARGS, "you selected a group with %d elements instead of %d", i, natoms);
     }
     printf("\n");
 
@@ -160,16 +151,16 @@ int gmx_nmens(int argc, char *argv[])
 
     if (last == -1)
     {
-        last = natoms*DIM;
+        last = natoms * DIM;
     }
     if (first > -1)
     {
         /* make an index from first to last */
-        nout = last-first+1;
+        nout = last - first + 1;
         snew(iout, nout);
         for (i = 0; i < nout; i++)
         {
-            iout[i] = first-1+i;
+            iout[i] = first - 1 + i;
         }
     }
     else
@@ -180,14 +171,13 @@ int gmx_nmens(int argc, char *argv[])
         do
         {
             nout++;
-            srenew(iout, nout+1);
+            srenew(iout, nout + 1);
             if (1 != scanf("%d", &iout[nout]))
             {
                 gmx_fatal(FARGS, "Error reading user input");
             }
             iout[nout]--;
-        }
-        while (iout[nout] >= 0);
+        } while (iout[nout] >= 0);
         printf("\n");
     }
 
@@ -222,12 +212,12 @@ int gmx_nmens(int argc, char *argv[])
 
     fprintf(stderr, "Using random seed %d and a temperature of %g K.\n", seed, temp);
 
-    gmx::UniformIntDistribution<int> dist(0, im-1);
+    gmx::UniformIntDistribution<int> dist(0, im - 1);
     jran = dist(rng);
 
     snew(xout1, natoms);
     snew(xout2, atoms->nr);
-    out  = open_trx(ftp2fn(efTRO, NFILE, fnm), "w");
+    out = open_trx(ftp2fn(efTRO, NFILE, fnm), "w");
 
     for (s = 0; s < nstruct; s++)
     {
@@ -241,25 +231,25 @@ int gmx_nmens(int argc, char *argv[])
             /* (r-0.5) n times:  var_n = n * var_1 = n/12
                n=4:  var_n = 1/3, so multiply with 3 */
 
-            rfac  = std::sqrt(3.0 * BOLTZ*temp/eigval[iout[j]]);
-            rhalf = 2.0*rfac;
-            rfac  = rfac/im;
+            rfac  = std::sqrt(3.0 * BOLTZ * temp / eigval[iout[j]]);
+            rhalf = 2.0 * rfac;
+            rfac  = rfac / im;
 
-            jran = (jran*ia+ic) & im;
+            jran = (jran * ia + ic) & im;
             jr   = jran;
-            jran = (jran*ia+ic) & im;
-            jr  += jran;
-            jran = (jran*ia+ic) & im;
-            jr  += jran;
-            jran = (jran*ia+ic) & im;
-            jr  += jran;
+            jran = (jran * ia + ic) & im;
+            jr += jran;
+            jran = (jran * ia + ic) & im;
+            jr += jran;
+            jran = (jran * ia + ic) & im;
+            jr += jran;
             disp = rfac * jr - rhalf;
 
             for (i = 0; i < natoms; i++)
             {
                 for (d = 0; d < DIM; d++)
                 {
-                    xout1[i][d] += disp*eigvec[v][i][d]*invsqrtm[i];
+                    xout1[i][d] += disp * eigvec[v][i][d] * invsqrtm[i];
                 }
             }
         }
@@ -267,9 +257,9 @@ int gmx_nmens(int argc, char *argv[])
         {
             copy_rvec(xout1[i], xout2[index[i]]);
         }
-        t = s+1;
+        t = s + 1;
         write_trx(out, natoms, index, atoms, 0, t, box, xout2, nullptr, nullptr);
-        fprintf(stderr, "\rGenerated %d structures", s+1);
+        fprintf(stderr, "\rGenerated %d structures", s + 1);
         fflush(stderr);
     }
     fprintf(stderr, "\n");
