@@ -3,7 +3,7 @@
  *
  * Copyright (c) 1991-2000, University of Groningen, The Netherlands.
  * Copyright (c) 2001-2004, The GROMACS development team.
- * Copyright (c) 2013,2014,2015,2018, by the GROMACS development team, led by
+ * Copyright (c) 2013,2014,2015,2018,2019, by the GROMACS development team, led by
  * Mark Abraham, David van der Spoel, Berk Hess, and Erik Lindahl,
  * and including many others, as listed in the AUTHORS file in the
  * top-level source directory and at http://www.gromacs.org.
@@ -44,38 +44,40 @@
 
 struct gmx_output_env_t;
 
-typedef struct {
+typedef struct
+{
     gmx_bool bShow;
-    char    *label;
+    char*    label;
     int      iphi, ipsi; /* point in the dih array of xr... */
 } t_phipsi;
 
-typedef struct {
-    int     ai[4];
-    int     mult;
-    real    phi0;
-    real    ang;
+typedef struct
+{
+    int  ai[4];
+    int  mult;
+    real phi0;
+    real ang;
 } t_dih;
 
-typedef struct {
+typedef struct
+{
     int               ndih;
-    t_dih            *dih;
+    t_dih*            dih;
     int               npp;
-    t_phipsi         *pp;
-    t_trxstatus      *traj;
+    t_phipsi*         pp;
+    t_trxstatus*      traj;
     int               natoms;
     int               amin, amax;
     real              t;
-    rvec             *x;
+    rvec*             x;
     matrix            box;
-    t_idef           *idef;
+    t_idef*           idef;
     int               ePBC;
-    gmx_output_env_t *oenv;
+    gmx_output_env_t* oenv;
 } t_xrama;
 
-t_topology *init_rama(gmx_output_env_t *oenv, const char *infile,
-                      const char *topfile, t_xrama *xr, int mult);
+t_topology* init_rama(gmx_output_env_t* oenv, const char* infile, const char* topfile, t_xrama* xr, int mult);
 
-gmx_bool new_data(t_xrama *xr);
+gmx_bool new_data(t_xrama* xr);
 
-#endif  /* GMX_GMXANA_NRAMA_H */
+#endif /* GMX_GMXANA_NRAMA_H */
