@@ -52,6 +52,7 @@
 #include "gromacs/utility/cstringutil.h"
 #include "gromacs/utility/fatalerror.h"
 #include "gromacs/utility/futil.h"
+#include "gromacs/utility/gmxassert.h"
 #include "gromacs/utility/gmxmpi.h"
 #include "gromacs/utility/mpiinplacebuffers.h"
 #include "gromacs/utility/real.h"
@@ -241,7 +242,7 @@ void gmx_setup_nodecomm(FILE gmx_unused* fplog, t_commrec* cr)
 void gmx_barrier(const t_commrec gmx_unused* cr)
 {
 #if !GMX_MPI
-    gmx_call("gmx_barrier");
+    GMX_RELEASE_ASSERT(false, "Invalid call to gmx_barrier");
 #else
     MPI_Barrier(cr->mpi_comm_mygroup);
 #endif
@@ -250,7 +251,7 @@ void gmx_barrier(const t_commrec gmx_unused* cr)
 void gmx_bcast(int gmx_unused nbytes, void gmx_unused* b, const t_commrec gmx_unused* cr)
 {
 #if !GMX_MPI
-    gmx_call("gmx_bast");
+    GMX_RELEASE_ASSERT(false, "Invalid call to gmx_bcast");
 #else
     MPI_Bcast(b, nbytes, MPI_BYTE, MASTERRANK(cr), cr->mpi_comm_mygroup);
 #endif
@@ -259,7 +260,7 @@ void gmx_bcast(int gmx_unused nbytes, void gmx_unused* b, const t_commrec gmx_un
 void gmx_bcast_sim(int gmx_unused nbytes, void gmx_unused* b, const t_commrec gmx_unused* cr)
 {
 #if !GMX_MPI
-    gmx_call("gmx_bast");
+    GMX_RELEASE_ASSERT(false, "Invalid call to gmx_bcast_sim");
 #else
     MPI_Bcast(b, nbytes, MPI_BYTE, MASTERRANK(cr), cr->mpi_comm_mysim);
 #endif
@@ -268,7 +269,7 @@ void gmx_bcast_sim(int gmx_unused nbytes, void gmx_unused* b, const t_commrec gm
 void gmx_sumd(int gmx_unused nr, double gmx_unused r[], const t_commrec gmx_unused* cr)
 {
 #if !GMX_MPI
-    gmx_call("gmx_sumd");
+    GMX_RELEASE_ASSERT(false, "Invalid call to gmx_sumd");
 #else
 #    if MPI_IN_PLACE_EXISTS
     if (cr->nc.bUse)
@@ -326,7 +327,7 @@ void gmx_sumd(int gmx_unused nr, double gmx_unused r[], const t_commrec gmx_unus
 void gmx_sumf(int gmx_unused nr, float gmx_unused r[], const t_commrec gmx_unused* cr)
 {
 #if !GMX_MPI
-    gmx_call("gmx_sumf");
+    GMX_RELEASE_ASSERT(false, "Invalid call to gmx_sumf");
 #else
 #    if MPI_IN_PLACE_EXISTS
     if (cr->nc.bUse)
@@ -384,7 +385,7 @@ void gmx_sumf(int gmx_unused nr, float gmx_unused r[], const t_commrec gmx_unuse
 void gmx_sumi(int gmx_unused nr, int gmx_unused r[], const t_commrec gmx_unused* cr)
 {
 #if !GMX_MPI
-    gmx_call("gmx_sumi");
+    GMX_RELEASE_ASSERT(false, "Invalid call to gmx_sumi");
 #else
 #    if MPI_IN_PLACE_EXISTS
     if (cr->nc.bUse)
@@ -442,7 +443,7 @@ void gmx_sumi(int gmx_unused nr, int gmx_unused r[], const t_commrec gmx_unused*
 void gmx_sumli(int gmx_unused nr, int64_t gmx_unused r[], const t_commrec gmx_unused* cr)
 {
 #if !GMX_MPI
-    gmx_call("gmx_sumli");
+    GMX_RELEASE_ASSERT(false, "Invalid call to gmx_sumli");
 #else
 #    if MPI_IN_PLACE_EXISTS
     if (cr->nc.bUse)
