@@ -40,42 +40,49 @@
 
 #include <string>
 
-typedef struct gmx_cpp *gmx_cpp_t;
+typedef struct gmx_cpp* gmx_cpp_t;
 
 /* The possible return codes for these functions */
-enum {
-    eCPP_OK, eCPP_FILE_NOT_FOUND, eCPP_EOF, eCPP_SYNTAX, eCPP_INTERRUPT,
-    eCPP_INVALID_HANDLE, eCPP_INVALID_INCLUDE_DELIMITER,
-    eCPP_FILE_NOT_OPEN, eCPP_UNKNOWN, eCPP_NR
+enum
+{
+    eCPP_OK,
+    eCPP_FILE_NOT_FOUND,
+    eCPP_EOF,
+    eCPP_SYNTAX,
+    eCPP_INTERRUPT,
+    eCPP_INVALID_HANDLE,
+    eCPP_INVALID_INCLUDE_DELIMITER,
+    eCPP_FILE_NOT_OPEN,
+    eCPP_UNKNOWN,
+    eCPP_NR
 };
 
 /* Open the file to be processed. The handle variable holds internal
    info for the cpp emulator. The cppopt variable (null terminated)
    can hold cpp options like -IXXX and -DXXX. Return integer status.
  */
-int cpp_open_file(const char *filenm, gmx_cpp_t *handlep, char **cppopts);
+int cpp_open_file(const char* filenm, gmx_cpp_t* handlep, char** cppopts);
 
 /* Return one whole line from the file into buf which holds at most n
    characters, for subsequent processing. Returns integer status.
  */
-int cpp_read_line(gmx_cpp_t *handlep, int n, char buf[]);
+int cpp_read_line(gmx_cpp_t* handlep, int n, char buf[]);
 
 /* Return the file currently being read.
  */
-const char *cpp_cur_file(const gmx_cpp_t *handlep);
+const char* cpp_cur_file(const gmx_cpp_t* handlep);
 
 /* Return the current line number.
  */
-int cpp_cur_linenr(const gmx_cpp_t *handlep);
+int cpp_cur_linenr(const gmx_cpp_t* handlep);
 
 /* Close the file! Return integer status.
  */
-int cpp_close_file(gmx_cpp_t *handlep);
+int cpp_close_file(gmx_cpp_t* handlep);
 
 /* Return a pointer to the value of defineName, when present, nullptr othwerwise.
  */
-const std::string *cpp_find_define(const gmx_cpp_t   *handlep,
-                                   const std::string &defineName);
+const std::string* cpp_find_define(const gmx_cpp_t* handlep, const std::string& defineName);
 
 /* Clean up normal and file static data structures
  */
@@ -84,6 +91,10 @@ void cpp_done(gmx_cpp_t handle);
 /* Return a string containing the error message coresponding to status
    variable.
  */
-char *cpp_error(gmx_cpp_t *handlep, int status);
+char* cpp_error(gmx_cpp_t* handlep, int status);
+
+/* Returns warning message if strings defined in mdp define section (e.g. -DFLEXIBLE)
+ * were not not found when processing the topology */
+std::string checkAndWarnForUnusedDefines(const gmx_cpp& handle);
 
 #endif
