@@ -3,7 +3,7 @@
  *
  * Copyright (c) 1991-2000, University of Groningen, The Netherlands.
  * Copyright (c) 2001-2004, The GROMACS development team.
- * Copyright (c) 2013,2014,2015,2017,2018, by the GROMACS development team, led by
+ * Copyright (c) 2013,2014,2015,2017,2018,2019, by the GROMACS development team, led by
  * Mark Abraham, David van der Spoel, Berk Hess, and Erik Lindahl,
  * and including many others, as listed in the AUTHORS file in the
  * top-level source directory and at http://www.gromacs.org.
@@ -41,14 +41,16 @@
 #include <cctype>
 #include <cstring>
 
+#include <algorithm>
 #include <string>
 #include <vector>
 
 #include "gromacs/fileio/gmxfio.h"
 #include "gromacs/gmxpreprocess/fflibutil.h"
+#include "gromacs/gmxpreprocess/gpp_atomtype.h"
+#include "gromacs/gmxpreprocess/grompp_impl.h"
 #include "gromacs/gmxpreprocess/h_db.h"
 #include "gromacs/gmxpreprocess/notset.h"
-#include "gromacs/gmxpreprocess/resall.h"
 #include "gromacs/gmxpreprocess/toputil.h"
 #include "gromacs/utility/cstringutil.h"
 #include "gromacs/utility/fatalerror.h"
@@ -56,16 +58,17 @@
 #include "gromacs/utility/smalloc.h"
 #include "gromacs/utility/strdb.h"
 
-/* use bonded types definitions in hackblock.h */
-#define ekwRepl (ebtsNR+1)
-#define ekwAdd  (ebtsNR+2)
-#define ekwDel  (ebtsNR+3)
-#define ekwNR   3
-static const char *kw_names[ekwNR] = {
-    "replace", "add", "delete"
-};
+#include "hackblock.h"
+#include "resall.h"
 
-static int find_kw(char *keyw)
+/* use bonded types definitions in hackblock.h */
+#define ekwRepl (ebtsNR + 1)
+#define ekwAdd (ebtsNR + 2)
+#define ekwDel (ebtsNR + 3)
+#define ekwNR 3
+static const char* kw_names[ekwNR] = { "replace", "add", "delete" };
+
+static int find_kw(char* keyw)
 {
     int i;
 
@@ -89,8 +92,7 @@ static int find_kw(char *keyw)
 
 #define FATAL() gmx_fatal(FARGS, "Reading Termini Database: not enough items on line\n%s", line)
 
-static void read_atom(char *line, bool bAdd,
-                      char **nname, t_atom *a, gpp_atomtype_t atype, int *cgnr)
+static void read_atom(char* line, bool bAdd, std::string* nname, t_atom* a, PreprocessingAtomTypes* atype, int* cgnr)
 {
     int    nr, i;
     char   buf[5][30];
@@ -114,21 +116,24 @@ static void read_atom(char *line, bool bAdd,
 
     if (nr < 3 || nr > 4)
     {
-        gmx_fatal(FARGS, "Reading Termini Database: expected %d or %d items of atom data in stead of %d on line\n%s", 3, 4, nr, line);
+        gmx_fatal(FARGS,
+                  "Reading Termini Database: expected %d or %d items of atom data in stead of %d "
+                  "on line\n%s",
+                  3, 4, nr, line);
     }
     i = 0;
     if (!bAdd)
     {
         if (nr == 4)
         {
-            *nname = gmx_strdup(buf[i++]);
+            *nname = buf[i++];
         }
         else
         {
-            *nname = nullptr;
+            *nname = "";
         }
     }
-    a->type = get_atomtype_type(buf[i++], atype);
+    a->type = atype->atomTypeFromName(buf[i++]);
     sscanf(buf[i++], "%lf", &m);
     a->m = m;
     sscanf(buf[i++], "%lf", &q);
@@ -143,98 +148,75 @@ static void read_atom(char *line, bool bAdd,
     }
 }
 
-static void print_atom(FILE *out, t_atom *a, gpp_atomtype_t atype)
+static void print_atom(FILE* out, const t_atom& a, PreprocessingAtomTypes* atype)
 {
-    fprintf(out, "\t%s\t%g\t%g\n",
-            get_atomtype_name(a->type, atype), a->m, a->q);
+    fprintf(out, "\t%s\t%g\t%g\n", atype->atomNameFromAtomType(a.type), a.m, a.q);
 }
 
-static void print_ter_db(const char *ff, char C, int nb, t_hackblock tb[],
-                         gpp_atomtype_t atype)
+static void print_ter_db(const char*                                ff,
+                         char                                       C,
+                         gmx::ArrayRef<const MoleculePatchDatabase> tb,
+                         PreprocessingAtomTypes*                    atype)
 {
-    FILE *out;
-    int   i, j, k, bt, nrepl, nadd, ndel;
-    char  buf[STRLEN];
+    std::string buf = gmx::formatString("%s-%c.tdb", ff, C);
+    FILE*       out = gmx_fio_fopen(buf.c_str(), "w");
 
-    sprintf(buf, "%s-%c.tdb", ff, C);
-    out = gmx_fio_fopen(buf, "w");
-
-    for (i = 0; (i < nb); i++)
+    for (const auto& modification : tb)
     {
-        fprintf(out, "[ %s ]\n", tb[i].name);
+        fprintf(out, "[ %s ]\n", modification.name.c_str());
 
-        /* first count: */
-        nrepl = 0;
-        nadd  = 0;
-        ndel  = 0;
-        for (j = 0; j < tb[i].nhack; j++)
+        if (std::any_of(modification.hack.begin(), modification.hack.end(),
+                        [](const auto& mod) { return mod.type() == MoleculePatchType::Replace; }))
         {
-            if (tb[i].hack[j].oname != nullptr && tb[i].hack[j].nname != nullptr)
+            fprintf(out, "[ %s ]\n", kw_names[ekwRepl - ebtsNR - 1]);
+            for (const auto& hack : modification.hack)
             {
-                nrepl++;
-            }
-            else if (tb[i].hack[j].oname == nullptr && tb[i].hack[j].nname != nullptr)
-            {
-                nadd++;
-            }
-            else if (tb[i].hack[j].oname != nullptr && tb[i].hack[j].nname == nullptr)
-            {
-                ndel++;
-            }
-            else if (tb[i].hack[j].oname == nullptr && tb[i].hack[j].nname == nullptr)
-            {
-                gmx_fatal(FARGS, "invalid hack (%s) in termini database", tb[i].name);
-            }
-        }
-        if (nrepl)
-        {
-            fprintf(out, "[ %s ]\n", kw_names[ekwRepl-ebtsNR-1]);
-            for (j = 0; j < tb[i].nhack; j++)
-            {
-                if (tb[i].hack[j].oname != nullptr && tb[i].hack[j].nname != nullptr)
+                if (hack.type() == MoleculePatchType::Replace)
                 {
-                    fprintf(out, "%s\t", tb[i].hack[j].oname);
-                    print_atom(out, tb[i].hack[j].atom, atype);
+                    fprintf(out, "%s\t", hack.oname.c_str());
+                    print_atom(out, hack.atom.back(), atype);
                 }
             }
         }
-        if (nadd)
+        if (std::any_of(modification.hack.begin(), modification.hack.end(),
+                        [](const auto& mod) { return mod.type() == MoleculePatchType::Add; }))
         {
-            fprintf(out, "[ %s ]\n", kw_names[ekwAdd-ebtsNR-1]);
-            for (j = 0; j < tb[i].nhack; j++)
+            fprintf(out, "[ %s ]\n", kw_names[ekwAdd - ebtsNR - 1]);
+            for (const auto& hack : modification.hack)
             {
-                if (tb[i].hack[j].oname == nullptr && tb[i].hack[j].nname != nullptr)
+                if (hack.type() == MoleculePatchType::Add)
                 {
-                    print_ab(out, &(tb[i].hack[j]), tb[i].hack[j].nname);
-                    print_atom(out, tb[i].hack[j].atom, atype);
+                    print_ab(out, hack, hack.nname.c_str());
+                    print_atom(out, hack.atom.back(), atype);
                 }
             }
         }
-        if (ndel)
+        if (std::any_of(modification.hack.begin(), modification.hack.end(),
+                        [](const auto& mod) { return mod.type() == MoleculePatchType::Delete; }))
         {
-            fprintf(out, "[ %s ]\n", kw_names[ekwDel-ebtsNR-1]);
-            for (j = 0; j < tb[i].nhack; j++)
+            fprintf(out, "[ %s ]\n", kw_names[ekwDel - ebtsNR - 1]);
+            for (const auto& hack : modification.hack)
             {
-                if (tb[i].hack[j].oname != nullptr && tb[i].hack[j].nname == nullptr)
+                if (hack.type() == MoleculePatchType::Delete)
                 {
-                    fprintf(out, "%s\n", tb[i].hack[j].oname);
+                    fprintf(out, "%s\n", hack.oname.c_str());
                 }
             }
         }
-        for (bt = 0; bt < ebtsNR; bt++)
+        for (int bt = 0; bt < ebtsNR; bt++)
         {
-            if (tb[i].rb[bt].nb)
+            if (!modification.rb[bt].b.empty())
             {
                 fprintf(out, "[ %s ]\n", btsNames[bt]);
-                for (j = 0; j < tb[i].rb[bt].nb; j++)
+                for (const auto& b : modification.rb[bt].b)
                 {
-                    for (k = 0; k < btsNiatoms[bt]; k++)
+                    for (int k = 0; k < btsNiatoms[bt]; k++)
                     {
-                        fprintf(out, "%s%s", k ? "\t" : "", tb[i].rb[bt].b[j].a[k]);
+                        fprintf(out, "%s%s", k ? "\t" : "", b.a[k].c_str());
                     }
-                    if (tb[i].rb[bt].b[j].s)
+                    if (!b.s.empty())
                     {
-                        fprintf(out, "\t%s", tb[i].rb[bt].b[j].s);
+                        fprintf(out, "\t%s", b.s.c_str());
                     }
                     fprintf(out, "\n");
                 }
@@ -245,31 +227,26 @@ static void print_ter_db(const char *ff, char C, int nb, t_hackblock tb[],
     gmx_fio_fclose(out);
 }
 
-static void read_ter_db_file(const char *fn,
-                             int *ntbptr, t_hackblock **tbptr,
-                             gpp_atomtype_t atype)
+static void read_ter_db_file(const char*                         fn,
+                             std::vector<MoleculePatchDatabase>* tbptr,
+                             PreprocessingAtomTypes*             atype)
 {
-    char         filebase[STRLEN], *ptr;
-    FILE        *in;
-    char         header[STRLEN], buf[STRLEN], line[STRLEN];
-    t_hackblock *tb;
-    int          i, j, n, ni, kwnr, nb, maxnb, nh;
+    char filebase[STRLEN];
+    char header[STRLEN], buf[STRLEN], line[STRLEN];
 
     fflib_filename_base(fn, filebase, STRLEN);
     /* Remove the C/N termini extension */
-    ptr = strrchr(filebase, '.');
+    char* ptr = strrchr(filebase, '.');
     if (ptr != nullptr)
     {
         ptr[0] = '\0';
     }
 
-    in = fflib_open(fn);
+    FILE* in = fflib_open(fn);
 
-    tb    = *tbptr;
-    nb    = *ntbptr - 1;
-    maxnb = 0;
-    kwnr  = NOTSET;
+    int kwnr = NOTSET;
     get_a_line(in, line, STRLEN);
+    MoleculePatchDatabase* block = nullptr;
     while (!feof(in))
     {
         if (get_header(line, header))
@@ -279,82 +256,72 @@ static void read_ter_db_file(const char *fn,
 
             if (kwnr == NOTSET)
             {
-                nb++;
-                /* here starts a new block */
-                if (nb >= maxnb)
-                {
-                    maxnb = nb + 100;
-                    srenew(tb, maxnb);
-                }
-                clear_t_hackblock(&tb[nb]);
-                tb[nb].name     = gmx_strdup(header);
-                tb[nb].filebase = gmx_strdup(filebase);
+                tbptr->emplace_back(MoleculePatchDatabase());
+                block = &tbptr->back();
+                clearModificationBlock(block);
+                block->name     = header;
+                block->filebase = filebase;
             }
         }
         else
         {
-            if (nb < 0)
+            if (block == nullptr)
             {
-                gmx_fatal(FARGS, "reading termini database: "
+                gmx_fatal(FARGS,
+                          "reading termini database: "
                           "directive expected before line:\n%s\n"
-                          "This might be a file in an old format.", line);
+                          "This might be a file in an old format.",
+                          line);
             }
             /* this is not a header, so it must be data */
             if (kwnr >= ebtsNR)
             {
                 /* this is a hack: add/rename/delete atoms */
                 /* make space for hacks */
-                if (tb[nb].nhack >= tb[nb].maxhack)
-                {
-                    tb[nb].maxhack += 10;
-                    srenew(tb[nb].hack, tb[nb].maxhack);
-                }
-                nh = tb[nb].nhack;
-                clear_t_hack(&(tb[nb].hack[nh]));
-                for (i = 0; i < 4; i++)
-                {
-                    tb[nb].hack[nh].a[i] = nullptr;
-                }
-                tb[nb].nhack++;
+                block->hack.emplace_back(MoleculePatch());
+                MoleculePatch* hack = &block->hack.back();
 
                 /* get data */
-                n = 0;
+                int n = 0;
                 if (kwnr == ekwRepl || kwnr == ekwDel)
                 {
                     if (sscanf(line, "%s%n", buf, &n) != 1)
                     {
-                        gmx_fatal(FARGS, "Reading Termini Database '%s': "
-                                  "expected atom name on line\n%s", fn, line);
+                        gmx_fatal(FARGS,
+                                  "Reading Termini Database '%s': "
+                                  "expected atom name on line\n%s",
+                                  fn, line);
                     }
-                    tb[nb].hack[nh].oname = gmx_strdup(buf);
+                    hack->oname = buf;
                     /* we only replace or delete one atom at a time */
-                    tb[nb].hack[nh].nr = 1;
+                    hack->nr = 1;
                 }
                 else if (kwnr == ekwAdd)
                 {
-                    read_ab(line, fn, &(tb[nb].hack[nh]));
+                    read_ab(line, fn, hack);
                     get_a_line(in, line, STRLEN);
                 }
                 else
                 {
-                    gmx_fatal(FARGS, "unimplemented keyword number %d (%s:%d)",
-                              kwnr, __FILE__, __LINE__);
+                    gmx_fatal(FARGS, "unimplemented keyword number %d (%s:%d)", kwnr, __FILE__, __LINE__);
                 }
                 if (kwnr == ekwRepl || kwnr == ekwAdd)
                 {
-                    snew(tb[nb].hack[nh].atom, 1);
-                    read_atom(line+n, kwnr == ekwAdd,
-                              &tb[nb].hack[nh].nname, tb[nb].hack[nh].atom, atype,
-                              &tb[nb].hack[nh].cgnr);
-                    if (tb[nb].hack[nh].nname == nullptr)
+                    hack->atom.emplace_back();
+                    read_atom(line + n, kwnr == ekwAdd, &hack->nname, &hack->atom.back(), atype,
+                              &hack->cgnr);
+                    if (hack->nname.empty())
                     {
-                        if (tb[nb].hack[nh].oname != nullptr)
+                        if (!hack->oname.empty())
                         {
-                            tb[nb].hack[nh].nname = gmx_strdup(tb[nb].hack[nh].oname);
+                            hack->nname = hack->oname;
                         }
                         else
                         {
-                            gmx_fatal(FARGS, "Reading Termini Database '%s': don't know which name the new atom should have on line\n%s", fn, line);
+                            gmx_fatal(FARGS,
+                                      "Reading Termini Database '%s': don't know which name the "
+                                      "new atom should have on line\n%s",
+                                      fn, line);
                         }
                     }
                 }
@@ -362,76 +329,66 @@ static void read_ter_db_file(const char *fn,
             else if (kwnr >= 0 && kwnr < ebtsNR)
             {
                 /* this is bonded data: bonds, angles, dihedrals or impropers */
-                srenew(tb[nb].rb[kwnr].b, tb[nb].rb[kwnr].nb+1);
-                n = 0;
-                for (j = 0; j < btsNiatoms[kwnr]; j++)
+                int n = 0;
+                block->rb[kwnr].b.emplace_back();
+                BondedInteraction* newBond = &block->rb[kwnr].b.back();
+                for (int j = 0; j < btsNiatoms[kwnr]; j++)
                 {
-                    if (sscanf(line+n, "%s%n", buf, &ni) == 1)
+                    int ni;
+                    if (sscanf(line + n, "%s%n", buf, &ni) == 1)
                     {
-                        tb[nb].rb[kwnr].b[tb[nb].rb[kwnr].nb].a[j] = gmx_strdup(buf);
+                        newBond->a[j] = buf;
                     }
                     else
                     {
-                        gmx_fatal(FARGS, "Reading Termini Database '%s': expected %d atom names (found %d) on line\n%s", fn, btsNiatoms[kwnr], j-1, line);
+                        gmx_fatal(FARGS,
+                                  "Reading Termini Database '%s': expected %d atom names (found "
+                                  "%d) on line\n%s",
+                                  fn, btsNiatoms[kwnr], j - 1, line);
                     }
                     n += ni;
                 }
-                for (; j < MAXATOMLIST; j++)
-                {
-                    tb[nb].rb[kwnr].b[tb[nb].rb[kwnr].nb].a[j] = nullptr;
-                }
                 strcpy(buf, "");
-                sscanf(line+n, "%s", buf);
-                tb[nb].rb[kwnr].b[tb[nb].rb[kwnr].nb].s = gmx_strdup(buf);
-                tb[nb].rb[kwnr].nb++;
+                sscanf(line + n, "%s", buf);
+                newBond->s = buf;
             }
             else
             {
-                gmx_fatal(FARGS, "Reading Termini Database: Expecting a header at line\n"
-                          "%s", line);
+                gmx_fatal(FARGS,
+                          "Reading Termini Database: Expecting a header at line\n"
+                          "%s",
+                          line);
             }
         }
         get_a_line(in, line, STRLEN);
     }
-    nb++;
-    srenew(tb, nb);
 
     gmx_ffclose(in);
-
-    *ntbptr = nb;
-    *tbptr  = tb;
 }
 
-int read_ter_db(const char *ffdir, char ter,
-                t_hackblock **tbptr, gpp_atomtype_t atype)
+int read_ter_db(const char* ffdir, char ter, std::vector<MoleculePatchDatabase>* tbptr, PreprocessingAtomTypes* atype)
 {
-    char   ext[STRLEN];
-    int    ntb;
-
-    sprintf(ext, ".%c.tdb", ter);
+    std::string ext = gmx::formatString(".%c.tdb", ter);
 
     /* Search for termini database files.
      * Do not generate an error when none are found.
      */
-    std::vector<std::string> tdbf  = fflib_search_file_end(ffdir, ext, FALSE);
-    ntb    = 0;
-    *tbptr = nullptr;
-    for (const auto &filename : tdbf)
+    std::vector<std::string> tdbf = fflib_search_file_end(ffdir, ext.c_str(), FALSE);
+    tbptr->clear();
+    for (const auto& filename : tdbf)
     {
-        read_ter_db_file(filename.c_str(), &ntb, tbptr, atype);
+        read_ter_db_file(filename.c_str(), tbptr, atype);
     }
 
     if (debug)
     {
-        print_ter_db("new", ter, ntb, *tbptr, atype);
+        print_ter_db("new", ter, *tbptr, atype);
     }
 
-    return ntb;
+    return tbptr->size();
 }
 
-t_hackblock **filter_ter(int nb, t_hackblock tb[],
-                         const char *resname,
-                         int *nret)
+std::vector<MoleculePatchDatabase*> filter_ter(gmx::ArrayRef<MoleculePatchDatabase> tb, const char* resname)
 {
     // TODO Four years later, no force fields have ever used this, so decide status of this feature
     /* Since some force fields (e.g. OPLS) needs different
@@ -455,26 +412,19 @@ t_hackblock **filter_ter(int nb, t_hackblock tb[],
      * Remember to free the list when you are done with it...
      */
 
-    int             i, j, n, none_idx;
-    bool            found;
-    char           *s;
-    t_hackblock   **list;
+    auto                                none_idx = tb.end();
+    std::vector<MoleculePatchDatabase*> list;
 
-    n    = 0;
-    list = nullptr;
-
-    for (i = 0; i < nb; i++)
+    for (auto it = tb.begin(); it != tb.end(); it++)
     {
-        s     = tb[i].name;
-        found = FALSE;
+        const char* s     = it->name.c_str();
+        bool        found = false;
         do
         {
-            if (gmx_strncasecmp(resname, s, 3) == 0)
+            if (gmx::equalCaseInsensitive(resname, s, 3))
             {
-                found = TRUE;
-                srenew(list, n+1);
-                list[n] = &(tb[i]);
-                n++;
+                found = true;
+                list.push_back(it);
             }
             else
             {
@@ -485,8 +435,7 @@ t_hackblock **filter_ter(int nb, t_hackblock tb[],
                     s++;
                 }
             }
-        }
-        while (!found && s != nullptr);
+        } while (!found && s != nullptr);
     }
 
     /* All residue-specific termini have been added. We might have to fall
@@ -495,19 +444,18 @@ t_hackblock **filter_ter(int nb, t_hackblock tb[],
      * The [ None ] alternative is special since we don't want that
      * to be the default, so we put it last in the list we return.
      */
-    none_idx = -1;
-    for (i = 0; i < nb; i++)
+    for (auto it = tb.begin(); it != tb.end(); it++)
     {
-        s = tb[i].name;
-        if (!gmx_strcasecmp("None", s))
+        const char* s = it->name.c_str();
+        if (gmx::equalCaseInsensitive("None", it->name))
         {
-            none_idx = i;
+            none_idx = it;
         }
         else
         {
             /* Time to see if there's a generic terminus that matches.
                Is there a hyphen? */
-            char *c = strchr(s, '-');
+            const char* c = strchr(s, '-');
 
             /* A conjunction hyphen normally indicates a residue-specific
                terminus, which is named like "GLY-COOH". A generic terminus
@@ -516,8 +464,7 @@ t_hackblock **filter_ter(int nb, t_hackblock tb[],
             /* '-' as the last character indicates charge, so if that's
                the only one found e.g. "COO-", then it was not a conjunction
                hyphen, so this is a generic terminus */
-            bool bOnlyFoundChargeHyphen = (bFoundAnyHyphen &&
-                                           *(c+1) == '\0');
+            bool bOnlyFoundChargeHyphen = (bFoundAnyHyphen && *(c + 1) == '\0');
             /* Thus, "GLY-COO-" is not recognized as a generic terminus. */
             bool bFoundGenericTerminus = !bFoundAnyHyphen || bOnlyFoundChargeHyphen;
             if (bFoundGenericTerminus)
@@ -525,47 +472,42 @@ t_hackblock **filter_ter(int nb, t_hackblock tb[],
                 /* Check that we haven't already added a residue-specific version
                  * of this terminus.
                  */
-                for (j = 0; j < n && strstr((*list[j]).name, s) == nullptr; j++)
+                auto found = std::find_if(list.begin(), list.end(), [&s](const MoleculePatchDatabase* b) {
+                    return strstr(b->name.c_str(), s) != nullptr;
+                });
+                if (found == list.end())
                 {
-                    ;
-                }
-                if (j == n)
-                {
-                    srenew(list, n+1);
-                    list[n] = &(tb[i]);
-                    n++;
+                    list.push_back(it);
                 }
             }
         }
     }
-    if (none_idx >= 0)
+    if (none_idx != tb.end())
     {
-        srenew(list, n+1);
-        list[n] = &(tb[none_idx]);
-        n++;
+        list.push_back(none_idx);
     }
 
-    *nret = n;
     return list;
 }
 
 
-t_hackblock *choose_ter(int nb, t_hackblock **tb, const char *title)
+MoleculePatchDatabase* choose_ter(gmx::ArrayRef<MoleculePatchDatabase*> tb, const char* title)
 {
-    int i, sel, ret;
+    int sel, ret;
 
     printf("%s\n", title);
-    for (i = 0; (i < nb); i++)
+    int i = 0;
+    for (const auto& modification : tb)
     {
-        bool bIsZwitterion = (0 == gmx_wcmatch("*ZWITTERION*", (*tb[i]).name));
-        printf("%2d: %s%s\n", i, (*tb[i]).name,
+        bool bIsZwitterion = (0 == gmx_wcmatch("*ZWITTERION*", modification->name.c_str()));
+        printf("%2d: %s%s\n", i, modification->name.c_str(),
                bIsZwitterion ? " (only use with zwitterions containing exactly one residue)" : "");
+        i++;
     }
     do
     {
         ret = fscanf(stdin, "%d", &sel);
-    }
-    while ((ret != 1) || (sel < 0) || (sel >= nb));
+    } while ((ret != 1) || (sel < 0) || (sel >= tb.ssize()));
 
     return tb[sel];
 }
