@@ -1,7 +1,7 @@
 /*
  * This file is part of the GROMACS molecular simulation package.
  *
- * Copyright (c) 2014,2015,2017,2018, by the GROMACS development team, led by
+ * Copyright (c) 2014,2015,2017,2018,2019, by the GROMACS development team, led by
  * Mark Abraham, David van der Spoel, Berk Hess, and Erik Lindahl,
  * and including many others, as listed in the AUTHORS file in the
  * top-level source directory and at http://www.gromacs.org.
@@ -50,31 +50,38 @@
 #include "gromacs/utility/smalloc.h"
 #include "gromacs/utility/stringutil.h"
 
-#if !GMX_GPU
-/*! \brief Set allocation functions used by the GPU host
- *
- * Since GPU support is not configured, there is no host memory to
- * allocate. */
-void gpu_set_host_malloc_and_free(bool /*unused*/,
-                                  gmx_host_alloc_t **nb_alloc,
-                                  gmx_host_free_t  **nb_free)
+#ifdef _MSC_VER
+#    pragma warning(disable : 6237)
+#endif
+
+//! Constant used to help minimize preprocessed code
+static constexpr bool c_binarySupportsGpus = (GMX_GPU != GMX_GPU_NONE);
+
+bool canPerformGpuDetection()
 {
-    *nb_alloc = nullptr;
-    *nb_free  = nullptr;
+    if (c_binarySupportsGpus && getenv("GMX_DISABLE_GPU_DETECTION") == nullptr)
+    {
+        return isGpuDetectionFunctional(nullptr);
+    }
+    else
+    {
+        return false;
+    }
 }
 
-int gpu_info_get_stat(const gmx_gpu_info_t & /*unused*/, int /*unused*/)
+#if GMX_GPU == GMX_GPU_NONE
+int gpu_info_get_stat(const gmx_gpu_info_t& /*unused*/, int /*unused*/)
 {
     return egpuNonexistent;
 }
 #endif
 
-void free_gpu_info(const gmx_gpu_info_t *gpu_info)
+void free_gpu_info(const gmx_gpu_info_t* gpu_info)
 {
-    sfree(static_cast<void*>(gpu_info->gpu_dev)); //circumvent is_pod check in sfree
+    sfree(static_cast<void*>(gpu_info->gpu_dev)); // circumvent is_pod check in sfree
 }
 
-std::vector<int> getCompatibleGpus(const gmx_gpu_info_t &gpu_info)
+std::vector<int> getCompatibleGpus(const gmx_gpu_info_t& gpu_info)
 {
     // Possible minor over-allocation here, but not important for anything
     std::vector<int> compatibleGpus;
@@ -90,38 +97,34 @@ std::vector<int> getCompatibleGpus(const gmx_gpu_info_t &gpu_info)
     return compatibleGpus;
 }
 
-const char *getGpuCompatibilityDescription(const gmx_gpu_info_t &gpu_info,
-                                           int                   index)
+const char* getGpuCompatibilityDescription(const gmx_gpu_info_t& gpu_info, int index)
 {
-    return (index >= gpu_info.n_dev ?
-            gpu_detect_res_str[egpuNonexistent] :
-            gpu_detect_res_str[gpu_info_get_stat(gpu_info, index)]);
+    return (index >= gpu_info.n_dev ? gpu_detect_res_str[egpuNonexistent]
+                                    : gpu_detect_res_str[gpu_info_get_stat(gpu_info, index)]);
 }
 /*! \brief Help build a descriptive message in \c error if there are
  * \c errorReasons why nonbondeds on a GPU are not supported.
  *
  * \returns Whether the lack of errorReasons indicate there is support. */
-static bool
-addMessageIfNotSupported(gmx::ArrayRef <const std::string> errorReasons,
-                         std::string                      *error)
+static bool addMessageIfNotSupported(gmx::ArrayRef<const std::string> errorReasons, std::string* error)
 {
     bool isSupported = errorReasons.empty();
     if (!isSupported && error)
     {
-        *error  = "Nonbonded interactions cannot run on GPUs: ";
+        *error = "Nonbonded interactions cannot run on GPUs: ";
         *error += joinStrings(errorReasons, "; ") + ".";
     }
     return isSupported;
 }
 
-bool buildSupportsNonbondedOnGpu(std::string *error)
+bool buildSupportsNonbondedOnGpu(std::string* error)
 {
     std::vector<std::string> errorReasons;
     if (GMX_DOUBLE)
     {
         errorReasons.emplace_back("double precision");
     }
-    if (GMX_GPU == GMX_GPU_NONE)
+    if (!c_binarySupportsGpus)
     {
         errorReasons.emplace_back("non-GPU build of GROMACS");
     }
