@@ -1,7 +1,7 @@
 /*
  * This file is part of the GROMACS molecular simulation package.
  *
- * Copyright (c) 2017,2018, by the GROMACS development team, led by
+ * Copyright (c) 2017,2018,2019, by the GROMACS development team, led by
  * Mark Abraham, David van der Spoel, Berk Hess, and Erik Lindahl,
  * and including many others, as listed in the AUTHORS file in the
  * top-level source directory and at http://www.gromacs.org.
@@ -54,31 +54,32 @@ enum class Architecture
 };
 
 //! Whether the compilation is targeting 32-bit x86.
-# if (defined __i386__ || defined __i386 || defined _X86_ || defined _M_IX86)
-#define GMX_IS_X86_32 1
+#if (defined __i386__ || defined __i386 || defined _X86_ || defined _M_IX86)
+#    define GMX_IS_X86_32 1
 #else
-#define GMX_IS_X86_32 0
+#    define GMX_IS_X86_32 0
 #endif
 
 //! Whether the compilation is targeting 64-bit x86.
-#if (defined __x86_64__ || defined __x86_64 || defined __amd64__ || defined __amd64 || defined _M_X64 || defined _M_AMD64)
-#define GMX_IS_X86_64 1
+#if (defined __x86_64__ || defined __x86_64 || defined __amd64__ || defined __amd64 \
+     || defined _M_X64 || defined _M_AMD64)
+#    define GMX_IS_X86_64 1
 #else
-#define GMX_IS_X86_64 0
+#    define GMX_IS_X86_64 0
 #endif
 
 //! Constant that tells what the architecture is
 static constexpr Architecture c_architecture =
 #if GMX_IS_X86_32 || GMX_IS_X86_64
-    Architecture::X86;
+        Architecture::X86;
 #elif defined __arm__ || defined __arm || defined _M_ARM || defined __aarch64__
-    Architecture::Arm;
+        Architecture::Arm;
 #elif defined __powerpc__ || defined __ppc__ || defined __PPC__
-    Architecture::PowerPC;
+        Architecture::PowerPC;
 #else
-    Architecture::Unknown;
+        Architecture::Unknown;
 #endif
 
-}      // namespace gmx
+} // namespace gmx
 
 #endif // GMX_ARCHITECTURE_H
