@@ -1,7 +1,8 @@
 /*
  * This file is part of the GROMACS molecular simulation package.
  *
- * Copyright (c) 2012,2013,2014,2015,2016,2017,2018,2019, by the GROMACS development team, led by
+ * Copyright (c) 2012,2013,2014,2015,2016, The GROMACS development team.
+ * Copyright (c) 2017,2018,2019,2020, by the GROMACS development team, led by
  * Mark Abraham, David van der Spoel, Berk Hess, and Erik Lindahl,
  * and including many others, as listed in the AUTHORS file in the
  * top-level source directory and at http://www.gromacs.org.
@@ -59,6 +60,8 @@
 #include "gromacs/utility/stringutil.h"
 #include "gromacs/utility/sysinfo.h"
 
+#include "architecture.h"
+
 //! Constant used to help minimize preprocessed code
 static const bool bGPUBinary = GMX_GPU != GMX_GPU_NONE;
 
@@ -380,6 +383,9 @@ void gmx_print_detected_hardware(FILE*                fplog,
         gmx::simdCheck(static_cast<gmx::SimdType>(hwinfo->simd_suggest_min), fplog, warnToStdErr);
     }
 
-    /* For RDTSCP we only check on our local node and skip the MPI reduction */
-    check_use_of_rdtscp_on_this_cpu(mdlog, cpuInfo);
+    /* For RDTSCP we only check on our local node and skip the MPI reduction, only on x86 */
+    if (gmx::c_architecture == gmx::Architecture::X86)
+    {
+        check_use_of_rdtscp_on_this_cpu(mdlog, cpuInfo);
+    }
 }
