@@ -3,7 +3,7 @@
  *
  * Copyright (c) 1991-2000, University of Groningen, The Netherlands.
  * Copyright (c) 2001-2004, The GROMACS development team.
- * Copyright (c) 2010,2014,2015,2016,2018, by the GROMACS development team, led by
+ * Copyright (c) 2010,2014,2015,2016,2018,2019, by the GROMACS development team, led by
  * Mark Abraham, David van der Spoel, Berk Hess, and Erik Lindahl,
  * and including many others, as listed in the AUTHORS file in the
  * top-level source directory and at http://www.gromacs.org.
@@ -41,12 +41,10 @@
 #include "gromacs/utility/basedefinitions.h"
 #include "gromacs/utility/real.h"
 
-real calc_similar_ind(gmx_bool bRho, int nind, const int *index, const real mass[],
-                      rvec x[], rvec xp[]);
+real calc_similar_ind(gmx_bool bRho, int nind, const int* index, const real mass[], rvec x[], rvec xp[]);
 /* Returns RMSD or Rho (depending on bRho) over all atoms in index */
 
-real rmsdev_ind(int nind, int index[], real mass[],
-                rvec x[], rvec xp[]);
+real rmsdev_ind(int nind, int index[], real mass[], rvec x[], rvec xp[]);
 /* Returns the RMS Deviation betweem x and xp over all atoms in index */
 
 real rmsdev(int natoms, real mass[], rvec x[], rvec xp[]);
@@ -62,8 +60,7 @@ real rhodev(int natoms, real mass[], rvec x[], rvec xp[]);
  * Maiorov & Crippen, PROTEINS 22, 273 (1995).
  */
 
-void calc_fit_R(int ndim, int natoms, const real *w_rls, const rvec *xp, rvec *x,
-                matrix R);
+void calc_fit_R(int ndim, int natoms, const real* w_rls, const rvec* xp, rvec* x, matrix R);
 /* Calculates the rotation matrix R for which
  * sum_i w_rls_i (xp_i - R x_i).(xp_i - R x_i)
  * is minimal. ndim=3 gives full fit, ndim=2 gives xy fit.
@@ -71,7 +68,7 @@ void calc_fit_R(int ndim, int natoms, const real *w_rls, const rvec *xp, rvec *x
  * x_rotated[i] = sum R[i][j]*x[j]
  */
 
-void do_fit_ndim(int ndim, int natoms, real *w_rls, const rvec *xp, rvec *x);
+void do_fit_ndim(int ndim, int natoms, real* w_rls, const rvec* xp, rvec* x);
 /* Do a least squares fit of x to xp. Atoms which have zero mass
  * (w_rls[i]) are not taken into account in fitting.
  * This makes is possible to fit eg. on Calpha atoms and orient
@@ -79,12 +76,10 @@ void do_fit_ndim(int ndim, int natoms, real *w_rls, const rvec *xp, rvec *x);
  * therefore both xp and x should be centered round the origin.
  */
 
-void do_fit(int natoms, real *w_rls, const rvec *xp, rvec *x);
+void do_fit(int natoms, real* w_rls, const rvec* xp, rvec* x);
 /* Calls do_fit with ndim=3, thus fitting in 3D */
 
-void reset_x_ndim(int ndim, int ncm, const int *ind_cm,
-                  int nreset, const int *ind_reset,
-                  rvec x[], const real mass[]);
+void reset_x_ndim(int ndim, int ncm, const int* ind_cm, int nreset, const int* ind_reset, rvec x[], const real mass[]);
 /* Put the center of mass of atoms in the origin for dimensions 0 to ndim.
  * The center of mass is computed from the index ind_cm.
  * When ind_cm!=NULL the COM is determined using ind_cm.
@@ -93,9 +88,7 @@ void reset_x_ndim(int ndim, int ncm, const int *ind_cm,
  * When ind_reset==NULL the coordinates up to nreset are reset.
  */
 
-void reset_x(int ncm, const int *ind_cm,
-             int nreset, const int *ind_reset,
-             rvec x[], const real mass[]);
+void reset_x(int ncm, const int* ind_cm, int nreset, const int* ind_reset, rvec x[], const real mass[]);
 /* Calls reset_x with ndim=3, thus resetting all dimesions */
 
 #endif
