@@ -1,7 +1,7 @@
 /*
  * This file is part of the GROMACS molecular simulation package.
  *
- * Copyright (c) 2017,2018, by the GROMACS development team, led by
+ * Copyright (c) 2017,2018,2019, by the GROMACS development team, led by
  * Mark Abraham, David van der Spoel, Berk Hess, and Erik Lindahl,
  * and including many others, as listed in the AUTHORS file in the
  * top-level source directory and at http://www.gromacs.org.
@@ -35,13 +35,10 @@
 #include "gromacs/mdlib/qmmm.h"
 
 #ifndef GMX_MDLIB_QM_ORCA_H
-#define GMX_MDLIB_QM_ORCA_H
+#    define GMX_MDLIB_QM_ORCA_H
 
-void
-init_orca(t_QMrec *qm);
+void init_orca(t_QMrec* qm);
 
-real
-call_orca(const t_forcerec *fr, t_QMrec *qm,
-          t_MMrec *mm, rvec f[], rvec fshift[]);
+real call_orca(const t_forcerec* fr, t_QMrec* qm, t_MMrec* mm, rvec f[], rvec fshift[]);
 
 #endif
