@@ -3,7 +3,7 @@
  *
  * Copyright (c) 1991-2000, University of Groningen, The Netherlands.
  * Copyright (c) 2001-2004, The GROMACS development team.
- * Copyright (c) 2013,2014,2015,2016,2017,2018, by the GROMACS development team, led by
+ * Copyright (c) 2013,2014,2015,2016,2017,2018,2019, by the GROMACS development team, led by
  * Mark Abraham, David van der Spoel, Berk Hess, and Erik Lindahl,
  * and including many others, as listed in the AUTHORS file in the
  * top-level source directory and at http://www.gromacs.org.
@@ -36,6 +36,8 @@
  */
 #include "gmxpre.h"
 
+#include "stat.h"
+
 #include <cstdio>
 #include <cstring>
 
@@ -48,12 +50,11 @@
 #include "gromacs/math/vec.h"
 #include "gromacs/mdlib/constr.h"
 #include "gromacs/mdlib/md_support.h"
-#include "gromacs/mdlib/mdrun.h"
 #include "gromacs/mdlib/rbin.h"
-#include "gromacs/mdlib/sim_util.h"
 #include "gromacs/mdlib/tgroup.h"
 #include "gromacs/mdlib/vcm.h"
 #include "gromacs/mdtypes/commrec.h"
+#include "gromacs/mdtypes/enerdata.h"
 #include "gromacs/mdtypes/group.h"
 #include "gromacs/mdtypes/inputrec.h"
 #include "gromacs/mdtypes/md_enums.h"
@@ -63,12 +64,12 @@
 
 typedef struct gmx_global_stat
 {
-    t_bin *rb;
-    int   *itc0;
-    int   *itc1;
+    t_bin* rb;
+    int*   itc0;
+    int*   itc1;
 } t_gmx_global_stat;
 
-gmx_global_stat_t global_stat_init(const t_inputrec *ir)
+gmx_global_stat_t global_stat_init(const t_inputrec* ir)
 {
     gmx_global_stat_t gs;
 
@@ -89,8 +90,7 @@ void global_stat_destroy(gmx_global_stat_t gs)
     sfree(gs);
 }
 
-static int filter_enerdterm(const real *afrom, gmx_bool bToBuffer, real *ato,
-                            gmx_bool bTemp, gmx_bool bPres, gmx_bool bEner)
+static int filter_enerdterm(const real* afrom, gmx_bool bToBuffer, real* ato, gmx_bool bTemp, gmx_bool bPres, gmx_bool bEner)
 {
     int i, to, from;
 
@@ -135,37 +135,43 @@ static int filter_enerdterm(const real *afrom, gmx_bool bToBuffer, real *ato,
     return to;
 }
 
-void global_stat(const gmx_global_stat *gs,
-                 const t_commrec *cr, gmx_enerdata_t *enerd,
-                 tensor fvir, tensor svir, rvec mu_tot,
-                 const t_inputrec *inputrec,
-                 gmx_ekindata_t *ekind, const gmx::Constraints *constr,
-                 t_vcm *vcm,
-                 int nsig, real *sig,
-                 int *totalNumberOfBondedInteractions,
-                 gmx_bool bSumEkinhOld, int flags)
+void global_stat(const gmx_global_stat*  gs,
+                 const t_commrec*        cr,
+                 gmx_enerdata_t*         enerd,
+                 tensor                  fvir,
+                 tensor                  svir,
+                 rvec                    mu_tot,
+                 const t_inputrec*       inputrec,
+                 gmx_ekindata_t*         ekind,
+                 const gmx::Constraints* constr,
+                 t_vcm*                  vcm,
+                 int                     nsig,
+                 real*                   sig,
+                 int*                    totalNumberOfBondedInteractions,
+                 gmx_bool                bSumEkinhOld,
+                 int                     flags)
 /* instead of current system, gmx_booleans for summing virial, kinetic energy, and other terms */
 {
-    t_bin     *rb;
-    int       *itc0, *itc1;
-    int        ie    = 0, ifv = 0, isv = 0, irmsd = 0, imu = 0;
-    int        idedl = 0, idedlo = 0, idvdll = 0, idvdlnl = 0, iepl = 0, icm = 0, imass = 0, ica = 0, inb = 0;
-    int        isig  = -1;
-    int        icj   = -1, ici = -1, icx = -1;
-    int        inn[egNR];
-    real       copyenerd[F_NRE];
-    int        nener, j;
-    double     nb;
-    gmx_bool   bVV, bTemp, bEner, bPres, bConstrVir, bEkinAveVel, bReadEkin;
-    bool       checkNumberOfBondedInteractions = (flags & CGLO_CHECK_NUMBER_OF_BONDED_INTERACTIONS) != 0;
+    t_bin* rb;
+    int *  itc0, *itc1;
+    int    ie = 0, ifv = 0, isv = 0, irmsd = 0, imu = 0;
+    int idedl = 0, idedlo = 0, idvdll = 0, idvdlnl = 0, iepl = 0, icm = 0, imass = 0, ica = 0, inb = 0;
+    int      isig = -1;
+    int      icj = -1, ici = -1, icx = -1;
+    int      inn[egNR];
+    real     copyenerd[F_NRE];
+    int      nener, j;
+    double   nb;
+    gmx_bool bVV, bTemp, bEner, bPres, bConstrVir, bEkinAveVel, bReadEkin;
+    bool checkNumberOfBondedInteractions = (flags & CGLO_CHECK_NUMBER_OF_BONDED_INTERACTIONS) != 0;
 
-    bVV           = EI_VV(inputrec->eI);
-    bTemp         = ((flags & CGLO_TEMPERATURE) != 0);
-    bEner         = ((flags & CGLO_ENERGY) != 0);
-    bPres         = ((flags & CGLO_PRESSURE) != 0);
-    bConstrVir    = ((flags & CGLO_CONSTRAINT) != 0);
-    bEkinAveVel   = (inputrec->eI == eiVV || (inputrec->eI == eiVVAK && bPres));
-    bReadEkin     = ((flags & CGLO_READEKIN) != 0);
+    bVV         = EI_VV(inputrec->eI);
+    bTemp       = ((flags & CGLO_TEMPERATURE) != 0);
+    bEner       = ((flags & CGLO_ENERGY) != 0);
+    bPres       = ((flags & CGLO_PRESSURE) != 0);
+    bConstrVir  = ((flags & CGLO_CONSTRAINT) != 0);
+    bEkinAveVel = (inputrec->eI == eiVV || (inputrec->eI == eiVVAK && bPres));
+    bReadEkin   = ((flags & CGLO_READEKIN) != 0);
 
     rb   = gs->rb;
     itc0 = gs->itc0;
@@ -188,10 +194,10 @@ void global_stat(const gmx_global_stat *gs,
        This is just the constraint virial.*/
     if (bConstrVir)
     {
-        isv = add_binr(rb, DIM*DIM, svir[0]);
+        isv = add_binr(rb, DIM * DIM, svir[0]);
     }
 
-/* We need the force virial and the kinetic energy for the first time through with velocity verlet */
+    /* We need the force virial and the kinetic energy for the first time through with velocity verlet */
     if (bTemp || !bVV)
     {
         if (ekind)
@@ -200,15 +206,15 @@ void global_stat(const gmx_global_stat *gs,
             {
                 if (bSumEkinhOld)
                 {
-                    itc0[j] = add_binr(rb, DIM*DIM, ekind->tcstat[j].ekinh_old[0]);
+                    itc0[j] = add_binr(rb, DIM * DIM, ekind->tcstat[j].ekinh_old[0]);
                 }
                 if (bEkinAveVel && !bReadEkin)
                 {
-                    itc1[j] = add_binr(rb, DIM*DIM, ekind->tcstat[j].ekinf[0]);
+                    itc1[j] = add_binr(rb, DIM * DIM, ekind->tcstat[j].ekinf[0]);
                 }
                 else if (!bReadEkin)
                 {
-                    itc1[j] = add_binr(rb, DIM*DIM, ekind->tcstat[j].ekinh[0]);
+                    itc1[j] = add_binr(rb, DIM * DIM, ekind->tcstat[j].ekinh[0]);
                 }
             }
             /* these probably need to be put into one of these categories */
@@ -217,19 +223,22 @@ void global_stat(const gmx_global_stat *gs,
             {
                 idedlo = add_binr(rb, 1, &(ekind->dekindl_old));
             }
-            ica   = add_binr(rb, 1, &(ekind->cosacc.mvcos));
+            if (ekind->cosacc.cos_accel != 0)
+            {
+                ica = add_binr(rb, 1, &(ekind->cosacc.mvcos));
+            }
         }
     }
 
     if (bPres)
     {
-        ifv = add_binr(rb, DIM*DIM, fvir[0]);
+        ifv = add_binr(rb, DIM * DIM, fvir[0]);
     }
 
     gmx::ArrayRef<real> rmsdData;
     if (bEner)
     {
-        ie  = add_binr(rb, nener, copyenerd);
+        ie = add_binr(rb, nener, copyenerd);
         if (constr)
         {
             rmsdData = constr->rmsdData();
@@ -245,28 +254,28 @@ void global_stat(const gmx_global_stat *gs,
 
         for (j = 0; (j < egNR); j++)
         {
-            inn[j] = add_binr(rb, enerd->grpp.nener, enerd->grpp.ener[j]);
+            inn[j] = add_binr(rb, enerd->grpp.nener, enerd->grpp.ener[j].data());
         }
         if (inputrec->efep != efepNO)
         {
             idvdll  = add_bind(rb, efptNR, enerd->dvdl_lin);
             idvdlnl = add_bind(rb, efptNR, enerd->dvdl_nonlin);
-            if (enerd->n_lambda > 0)
+            if (!enerd->enerpart_lambda.empty())
             {
-                iepl = add_bind(rb, enerd->n_lambda, enerd->enerpart_lambda);
+                iepl = add_bind(rb, enerd->enerpart_lambda.size(), enerd->enerpart_lambda.data());
             }
         }
     }
 
     if (vcm)
     {
-        icm   = add_binr(rb, DIM*vcm->nr, vcm->group_p[0]);
-        imass = add_binr(rb, vcm->nr, vcm->group_mass);
+        icm   = add_binr(rb, DIM * vcm->nr, vcm->group_p[0]);
+        imass = add_binr(rb, vcm->nr, vcm->group_mass.data());
         if (vcm->mode == ecmANGULAR)
         {
-            icj   = add_binr(rb, DIM*vcm->nr, vcm->group_j[0]);
-            icx   = add_binr(rb, DIM*vcm->nr, vcm->group_x[0]);
-            ici   = add_binr(rb, DIM*DIM*vcm->nr, vcm->group_i[0][0]);
+            icj = add_binr(rb, DIM * vcm->nr, vcm->group_j[0]);
+            icx = add_binr(rb, DIM * vcm->nr, vcm->group_x[0]);
+            ici = add_binr(rb, DIM * DIM * vcm->nr, vcm->group_i[0][0]);
         }
     }
 
@@ -291,7 +300,7 @@ void global_stat(const gmx_global_stat *gs,
 
     if (bConstrVir)
     {
-        extract_binr(rb, isv, DIM*DIM, svir[0]);
+        extract_binr(rb, isv, DIM * DIM, svir[0]);
     }
 
     /* We need the force virial and the kinetic energy for the first time through with velocity verlet */
@@ -303,15 +312,15 @@ void global_stat(const gmx_global_stat *gs,
             {
                 if (bSumEkinhOld)
                 {
-                    extract_binr(rb, itc0[j], DIM*DIM, ekind->tcstat[j].ekinh_old[0]);
+                    extract_binr(rb, itc0[j], DIM * DIM, ekind->tcstat[j].ekinh_old[0]);
                 }
                 if (bEkinAveVel && !bReadEkin)
                 {
-                    extract_binr(rb, itc1[j], DIM*DIM, ekind->tcstat[j].ekinf[0]);
+                    extract_binr(rb, itc1[j], DIM * DIM, ekind->tcstat[j].ekinf[0]);
                 }
                 else if (!bReadEkin)
                 {
-                    extract_binr(rb, itc1[j], DIM*DIM, ekind->tcstat[j].ekinh[0]);
+                    extract_binr(rb, itc1[j], DIM * DIM, ekind->tcstat[j].ekinh[0]);
                 }
             }
             extract_binr(rb, idedl, 1, &(ekind->dekindl));
@@ -319,12 +328,15 @@ void global_stat(const gmx_global_stat *gs,
             {
                 extract_binr(rb, idedlo, 1, &(ekind->dekindl_old));
             }
-            extract_binr(rb, ica, 1, &(ekind->cosacc.mvcos));
+            if (ekind->cosacc.cos_accel != 0)
+            {
+                extract_binr(rb, ica, 1, &(ekind->cosacc.mvcos));
+            }
         }
     }
     if (bPres)
     {
-        extract_binr(rb, ifv, DIM*DIM, fvir[0]);
+        extract_binr(rb, ifv, DIM * DIM, fvir[0]);
     }
 
     if (bEner)
@@ -341,15 +353,15 @@ void global_stat(const gmx_global_stat *gs,
 
         for (j = 0; (j < egNR); j++)
         {
-            extract_binr(rb, inn[j], enerd->grpp.nener, enerd->grpp.ener[j]);
+            extract_binr(rb, inn[j], enerd->grpp.nener, enerd->grpp.ener[j].data());
         }
         if (inputrec->efep != efepNO)
         {
             extract_bind(rb, idvdll, efptNR, enerd->dvdl_lin);
             extract_bind(rb, idvdlnl, efptNR, enerd->dvdl_nonlin);
-            if (enerd->n_lambda > 0)
+            if (!enerd->enerpart_lambda.empty())
             {
-                extract_bind(rb, iepl, enerd->n_lambda, enerd->enerpart_lambda);
+                extract_bind(rb, iepl, enerd->enerpart_lambda.size(), enerd->enerpart_lambda.data());
             }
         }
 
@@ -358,13 +370,13 @@ void global_stat(const gmx_global_stat *gs,
 
     if (vcm)
     {
-        extract_binr(rb, icm, DIM*vcm->nr, vcm->group_p[0]);
-        extract_binr(rb, imass, vcm->nr, vcm->group_mass);
+        extract_binr(rb, icm, DIM * vcm->nr, vcm->group_p[0]);
+        extract_binr(rb, imass, vcm->nr, vcm->group_mass.data());
         if (vcm->mode == ecmANGULAR)
         {
-            extract_binr(rb, icj, DIM*vcm->nr, vcm->group_j[0]);
-            extract_binr(rb, icx, DIM*vcm->nr, vcm->group_x[0]);
-            extract_binr(rb, ici, DIM*DIM*vcm->nr, vcm->group_i[0][0]);
+            extract_binr(rb, icj, DIM * vcm->nr, vcm->group_j[0]);
+            extract_binr(rb, icx, DIM * vcm->nr, vcm->group_x[0]);
+            extract_binr(rb, ici, DIM * DIM * vcm->nr, vcm->group_i[0][0]);
         }
     }
 
@@ -379,15 +391,3 @@ void global_stat(const gmx_global_stat *gs,
         extract_binr(rb, isig, nsig, sig);
     }
 }
-
-bool do_per_step(int64_t step, int64_t nstep)
-{
-    if (nstep != 0)
-    {
-        return (step % nstep) == 0;
-    }
-    else
-    {
-        return false;
-    }
-}
