@@ -3,7 +3,7 @@
  *
  * Copyright (c) 1991-2000, University of Groningen, The Netherlands.
  * Copyright (c) 2001-2008, The GROMACS development team.
- * Copyright (c) 2013,2014,2015,2016,2017,2018, by the GROMACS development team, led by
+ * Copyright (c) 2013,2014,2015,2016,2017,2018,2019, by the GROMACS development team, led by
  * Mark Abraham, David van der Spoel, Berk Hess, and Erik Lindahl,
  * and including many others, as listed in the AUTHORS file in the
  * top-level source directory and at http://www.gromacs.org.
@@ -58,22 +58,21 @@
 #include "gromacs/utility/fatalerror.h"
 #include "gromacs/utility/smalloc.h"
 
-void make_wall_tables(FILE *fplog,
-                      const t_inputrec *ir, const char *tabfn,
-                      const gmx_groups_t *groups,
-                      t_forcerec *fr)
+void make_wall_tables(FILE*                   fplog,
+                      const t_inputrec*       ir,
+                      const char*             tabfn,
+                      const SimulationGroups* groups,
+                      t_forcerec*             fr)
 {
-    int           negp_pp;
-    int          *nm_ind;
-    char          buf[STRLEN];
+    int  negp_pp;
+    char buf[STRLEN];
 
-    negp_pp = ir->opts.ngener - ir->nwall;
-    nm_ind  = groups->grps[egcENER].nm_ind;
+    negp_pp                         = ir->opts.ngener - ir->nwall;
+    gmx::ArrayRef<const int> nm_ind = groups->groups[SimulationAtomGroupType::EnergyOutput];
 
     if (fplog)
     {
-        fprintf(fplog, "Reading user tables for %d energy groups with %d walls\n",
-                negp_pp, ir->nwall);
+        fprintf(fplog, "Reading user tables for %d energy groups with %d walls\n", negp_pp, ir->nwall);
     }
 
     snew(fr->wall_tab, ir->nwall);
@@ -83,23 +82,21 @@ void make_wall_tables(FILE *fplog,
         for (int egp = 0; egp < negp_pp; egp++)
         {
             /* If the energy group pair is excluded, we don't need a table */
-            if (!(fr->egp_flags[egp*ir->opts.ngener+negp_pp+w] & EGP_EXCL))
+            if (!(fr->egp_flags[egp * ir->opts.ngener + negp_pp + w] & EGP_EXCL))
             {
                 sprintf(buf, "%s", tabfn);
                 sprintf(buf + strlen(tabfn) - strlen(ftp2ext(efXVG)) - 1, "_%s_%s.%s",
-                        *groups->grpname[nm_ind[egp]],
-                        *groups->grpname[nm_ind[negp_pp+w]],
+                        *groups->groupNames[nm_ind[egp]], *groups->groupNames[nm_ind[negp_pp + w]],
                         ftp2ext(efXVG));
-                fr->wall_tab[w][egp] = make_tables(fplog, fr->ic, buf, 0,
-                                                   GMX_MAKETABLES_FORCEUSER);
+                fr->wall_tab[w][egp] = make_tables(fplog, fr->ic, buf, 0, GMX_MAKETABLES_FORCEUSER);
 
                 /* Since wall have no charge, we can compress the table */
                 for (int i = 0; i <= fr->wall_tab[w][egp]->n; i++)
                 {
                     for (int j = 0; j < 8; j++)
                     {
-                        fr->wall_tab[w][egp]->data[8*i+j] =
-                            fr->wall_tab[w][egp]->data[12*i+4+j];
+                        fr->wall_tab[w][egp]->data[8 * i + j] =
+                                fr->wall_tab[w][egp]->data[12 * i + 4 + j];
                     }
                 }
             }
@@ -107,7 +104,7 @@ void make_wall_tables(FILE *fplog,
     }
 }
 
-[[ noreturn ]] static void wall_error(int a, const rvec *x, real r)
+[[noreturn]] static void wall_error(int a, const rvec* x, real r)
 {
     gmx_fatal(FARGS,
               "An atom is beyond the wall: coordinates %f %f %f, distance %f\n"
@@ -115,100 +112,99 @@ void make_wall_tables(FILE *fplog,
               x[a][XX], x[a][YY], x[a][ZZ], r);
 }
 
-static void tableForce(real                r,
-                       const t_forcetable &tab,
-                       real                Cd,
-                       real                Cr,
-                       real               *V,
-                       real               *F)
+static void tableForce(real r, const t_forcetable& tab, real Cd, real Cr, real* V, real* F)
 {
     const real  tabscale = tab.scale;
-    const real *VFtab    = tab.data;
+    const real* VFtab    = tab.data;
 
-    real        rt = r*tabscale;
-    int         n0 = static_cast<int>(rt);
+    real rt = r * tabscale;
+    int  n0 = static_cast<int>(rt);
     if (n0 >= tab.n)
     {
         /* Beyond the table range, set V and F to zero */
-        *V         = 0;
-        *F         = 0;
+        *V = 0;
+        *F = 0;
     }
     else
     {
-        real eps   = rt - n0;
-        real eps2  = eps*eps;
+        real eps  = rt - n0;
+        real eps2 = eps * eps;
         /* Dispersion */
-        int  nnn   = 8*n0;
+        int  nnn   = 8 * n0;
         real Yt    = VFtab[nnn];
         real Ft    = VFtab[nnn + 1];
-        real Geps  = VFtab[nnn + 2]*eps;
-        real Heps2 = VFtab[nnn + 3]*eps2;
+        real Geps  = VFtab[nnn + 2] * eps;
+        real Heps2 = VFtab[nnn + 3] * eps2;
         real Fp    = Ft + Geps + Heps2;
-        real VV    = Yt + Fp*eps;
-        real FF    = Fp + Geps + 2.0*Heps2;
-        real Vd    = 6*Cd*VV;
-        real Fd    = 6*Cd*FF;
+        real VV    = Yt + Fp * eps;
+        real FF    = Fp + Geps + 2.0 * Heps2;
+        real Vd    = 6 * Cd * VV;
+        real Fd    = 6 * Cd * FF;
         /* Repulsion */
-        nnn        = nnn + 4;
-        Yt         = VFtab[nnn];
-        Ft         = VFtab[nnn+1];
-        Geps       = VFtab[nnn+2]*eps;
-        Heps2      = VFtab[nnn+3]*eps2;
-        Fp         = Ft + Geps + Heps2;
-        VV         = Yt + Fp*eps;
-        FF         = Fp + Geps + 2.0*Heps2;
-        real Vr    = 12*Cr*VV;
-        real Fr    = 12*Cr*FF;
-        *V         = Vd + Vr;
-        *F         = -(Fd + Fr)*tabscale;
+        nnn     = nnn + 4;
+        Yt      = VFtab[nnn];
+        Ft      = VFtab[nnn + 1];
+        Geps    = VFtab[nnn + 2] * eps;
+        Heps2   = VFtab[nnn + 3] * eps2;
+        Fp      = Ft + Geps + Heps2;
+        VV      = Yt + Fp * eps;
+        FF      = Fp + Geps + 2.0 * Heps2;
+        real Vr = 12 * Cr * VV;
+        real Fr = 12 * Cr * FF;
+        *V      = Vd + Vr;
+        *F      = -(Fd + Fr) * tabscale;
     }
 }
 
-real do_walls(const t_inputrec &ir, const t_forcerec &fr,
-              const matrix box, const t_mdatoms &md,
-              const rvec *x, gmx::ForceWithVirial *forceWithVirial,
-              real lambda, real Vlj[], t_nrnb *nrnb)
+real do_walls(const t_inputrec&     ir,
+              const t_forcerec&     fr,
+              const matrix          box,
+              const t_mdatoms&      md,
+              const rvec*           x,
+              gmx::ForceWithVirial* forceWithVirial,
+              real                  lambda,
+              real                  Vlj[],
+              t_nrnb*               nrnb)
 {
-    constexpr real        sixth   = 1.0/6.0;
-    constexpr real        twelfth = 1.0/12.0;
+    constexpr real sixth   = 1.0 / 6.0;
+    constexpr real twelfth = 1.0 / 12.0;
 
     int                   ntw[2];
     real                  fac_d[2], fac_r[2];
-    const unsigned short *gid = md.cENER;
+    const unsigned short* gid = md.cENER;
 
-    const int             nwall     = ir.nwall;
-    const int             ngid      = ir.opts.ngener;
-    const int             ntype     = fr.ntype;
-    const real           *nbfp      = fr.nbfp;
-    const int            *egp_flags = fr.egp_flags;
+    const int   nwall     = ir.nwall;
+    const int   ngid      = ir.opts.ngener;
+    const int   ntype     = fr.ntype;
+    const real* nbfp      = fr.nbfp;
+    const int*  egp_flags = fr.egp_flags;
 
     for (int w = 0; w < nwall; w++)
     {
-        ntw[w] = 2*ntype*ir.wall_atomtype[w];
+        ntw[w] = 2 * ntype * ir.wall_atomtype[w];
         switch (ir.wall_type)
         {
             case ewt93:
-                fac_d[w] = ir.wall_density[w]*M_PI/6;
-                fac_r[w] = ir.wall_density[w]*M_PI/45;
+                fac_d[w] = ir.wall_density[w] * M_PI / 6;
+                fac_r[w] = ir.wall_density[w] * M_PI / 45;
                 break;
             case ewt104:
-                fac_d[w] = ir.wall_density[w]*M_PI/2;
-                fac_r[w] = ir.wall_density[w]*M_PI/5;
-                break;
-            default:
+                fac_d[w] = ir.wall_density[w] * M_PI / 2;
+                fac_r[w] = ir.wall_density[w] * M_PI / 5;
                 break;
+            default: break;
         }
     }
-    const real          wall_z[2] = { 0, box[ZZ][ZZ] };
+    const real wall_z[2] = { 0, box[ZZ][ZZ] };
 
-    rvec * gmx_restrict f = as_rvec_array(forceWithVirial->force_.data());
+    rvec* gmx_restrict f = as_rvec_array(forceWithVirial->force_.data());
 
-    real                dvdlambda = 0;
-    double              sumRF     = 0;
+    real   dvdlambda = 0;
+    double sumRF     = 0;
     for (int lam = 0; lam < (md.nPerturbed ? 2 : 1); lam++)
     {
         real       lamfac;
-        const int *type;
+        const int* type;
         if (md.nPerturbed)
         {
             if (lam == 0)
@@ -234,11 +230,11 @@ real do_walls(const t_inputrec &ir, const t_forcerec &fr,
             for (int w = 0; w < std::min(nwall, 2); w++)
             {
                 /* The wall energy groups are always at the end of the list */
-                const int  ggid = gid[i]*ngid + ngid - nwall + w;
-                const int  at   = type[i];
+                const int ggid = gid[i] * ngid + ngid - nwall + w;
+                const int at   = type[i];
                 /* nbfp now includes the 6/12 derivative prefactors */
-                const real Cd = nbfp[ntw[w] + 2*at]*sixth;
-                const real Cr = nbfp[ntw[w] + 2*at + 1]*twelfth;
+                const real Cd = nbfp[ntw[w] + 2 * at] * sixth;
+                const real Cr = nbfp[ntw[w] + 2 * at + 1] * twelfth;
                 if (!((Cd == 0 && Cr == 0) || (egp_flags[ggid] & EGP_EXCL)))
                 {
                     real r, mr;
@@ -273,55 +269,55 @@ real do_walls(const t_inputrec &ir, const t_forcerec &fr,
                             F *= lamfac;
                             break;
                         case ewt93:
-                            r1 = 1/r;
-                            r2 = r1*r1;
-                            r4 = r2*r2;
-                            Vd = fac_d[w]*Cd*r2*r1;
-                            Vr = fac_r[w]*Cr*r4*r4*r1;
+                            r1 = 1 / r;
+                            r2 = r1 * r1;
+                            r4 = r2 * r2;
+                            Vd = fac_d[w] * Cd * r2 * r1;
+                            Vr = fac_r[w] * Cr * r4 * r4 * r1;
                             V  = Vr - Vd;
-                            F  = lamfac*(9*Vr - 3*Vd)*r1;
+                            F  = lamfac * (9 * Vr - 3 * Vd) * r1;
                             break;
                         case ewt104:
-                            r1 = 1/r;
-                            r2 = r1*r1;
-                            r4 = r2*r2;
-                            Vd = fac_d[w]*Cd*r4;
-                            Vr = fac_r[w]*Cr*r4*r4*r2;
+                            r1 = 1 / r;
+                            r2 = r1 * r1;
+                            r4 = r2 * r2;
+                            Vd = fac_d[w] * Cd * r4;
+                            Vr = fac_r[w] * Cr * r4 * r4 * r2;
                             V  = Vr - Vd;
-                            F  = lamfac*(10*Vr - 4*Vd)*r1;
+                            F  = lamfac * (10 * Vr - 4 * Vd) * r1;
                             break;
                         case ewt126:
-                            r1 = 1/r;
-                            r2 = r1*r1;
-                            r4 = r2*r2;
-                            Vd = Cd*r4*r2;
-                            Vr = Cr*r4*r4*r4;
+                            r1 = 1 / r;
+                            r2 = r1 * r1;
+                            r4 = r2 * r2;
+                            Vd = Cd * r4 * r2;
+                            Vr = Cr * r4 * r4 * r4;
                             V  = Vr - Vd;
-                            F  = lamfac*(12*Vr - 6*Vd)*r1;
+                            F  = lamfac * (12 * Vr - 6 * Vd) * r1;
                             break;
                         default:
-                            V  = 0;
-                            F  = 0;
+                            V = 0;
+                            F = 0;
                             break;
                     }
                     if (mr > 0)
                     {
-                        V     += mr*F;
+                        V += mr * F;
                     }
-                    sumRF     += r*F;
+                    sumRF += r * F;
                     if (w == 1)
                     {
-                        F      = -F;
+                        F = -F;
                     }
-                    Vlj[ggid] += lamfac*V;
-                    Vlambda   += V;
-                    f[i][ZZ]  += F;
+                    Vlj[ggid] += lamfac * V;
+                    Vlambda += V;
+                    f[i][ZZ] += F;
                 }
             }
         }
         if (md.nPerturbed)
         {
-            dvdlambda += (lam == 0 ? -1 : 1)*Vlambda;
+            dvdlambda += (lam == 0 ? -1 : 1) * Vlambda;
         }
 
         inc_nrnb(nrnb, eNR_WALLS, md.homenr);
@@ -329,7 +325,7 @@ real do_walls(const t_inputrec &ir, const t_forcerec &fr,
 
     if (forceWithVirial->computeVirial_)
     {
-        rvec virial = { 0, 0, static_cast<real>(-0.5*sumRF) };
+        rvec virial = { 0, 0, static_cast<real>(-0.5 * sumRF) };
         forceWithVirial->addVirialContribution(virial);
     }
 
