@@ -1,7 +1,7 @@
 /*
  * This file is part of the GROMACS molecular simulation package.
  *
- * Copyright (c) 2015,2016,2018, by the GROMACS development team, led by
+ * Copyright (c) 2015,2016,2018,2019, by the GROMACS development team, led by
  * Mark Abraham, David van der Spoel, Berk Hess, and Erik Lindahl,
  * and including many others, as listed in the AUTHORS file in the
  * top-level source directory and at http://www.gromacs.org.
@@ -59,48 +59,44 @@
 //! \brief Energy history for delta_h histograms in between energy file frames
 class delta_h_history_t
 {
-    public:
-        //! Vector (size number of intermediate data points) of vector of Hamiltonian differences for each foreign lambda
-        std::vector<std::vector<real> > dh;
-        //! The start time of these energy diff blocks
-        double                          start_time;
-        //! Lambda at start time
-        double                          start_lambda;
-        //! Whether the lambda value is set. Here for backward-compatibility.
-        gmx_bool                        start_lambda_set;
+public:
+    //! Vector (size number of intermediate data points) of vector of Hamiltonian differences for each foreign lambda
+    std::vector<std::vector<real>> dh;
+    //! The start time of these energy diff blocks
+    double start_time;
+    //! Lambda at start time
+    double start_lambda;
+    //! Whether the lambda value is set. Here for backward-compatibility.
+    gmx_bool start_lambda_set;
 
-        delta_h_history_t() :
-            start_time(0),
-            start_lambda(0),
-            start_lambda_set(false)
-        {
-        }
+    delta_h_history_t() : start_time(0), start_lambda(0), start_lambda_set(false) {}
 };
 
 
 //! \brief Energy statistics history, only used for output and reporting
 class energyhistory_t
 {
-    public:
-        int64_t             nsteps;       //! The number of steps in the history
-        int64_t             nsum;         //! Nr. of steps in the ener_ave and ener_sum
-        std::vector<double> ener_ave;     //! Energy terms difference^2 sum to get fluctuations
-        std::vector<double> ener_sum;     //! Energy terms sum
-        int64_t             nsteps_sim;   //! The number of steps in ener_sum_sim
-        int64_t             nsum_sim;     //! The number of frames in ener_sum_sim
-        std::vector<double> ener_sum_sim; //! Energy term history sum of the whole sim
+public:
+    int64_t             nsteps;       //! The number of steps in the history
+    int64_t             nsum;         //! Nr. of steps in the ener_ave and ener_sum
+    std::vector<double> ener_ave;     //! Energy terms difference^2 sum to get fluctuations
+    std::vector<double> ener_sum;     //! Energy terms sum
+    int64_t             nsteps_sim;   //! The number of steps in ener_sum_sim
+    int64_t             nsum_sim;     //! The number of frames in ener_sum_sim
+    std::vector<double> ener_sum_sim; //! Energy term history sum of the whole sim
 
-        //! History for energy difference for foreign lambdas (useful for BAR)
-        std::unique_ptr<delta_h_history_t> deltaHForeignLambdas;
+    //! History for energy difference for foreign lambdas (useful for BAR)
+    std::unique_ptr<delta_h_history_t> deltaHForeignLambdas;
 
-        energyhistory_t() : nsteps(0),
-                            nsum(0),
+    energyhistory_t() :
+        nsteps(0),
+        nsum(0),
 
-                            nsteps_sim(0),
-                            nsum_sim(0),
-                            ener_sum_sim(0)
-        {
-        }
+        nsteps_sim(0),
+        nsum_sim(0),
+        ener_sum_sim(0)
+    {
+    }
 };
 
 //! \endcond
