@@ -1,7 +1,7 @@
 /*
  * This file is part of the GROMACS molecular simulation package.
  *
- * Copyright (c) 2016,2018, by the GROMACS development team, led by
+ * Copyright (c) 2016,2018,2019, by the GROMACS development team, led by
  * Mark Abraham, David van der Spoel, Berk Hess, and Erik Lindahl,
  * and including many others, as listed in the AUTHORS file in the
  * top-level source directory and at http://www.gromacs.org.
@@ -36,8 +36,9 @@
 
 #include "optionsection.h"
 
-#include "gromacs/compat/make_unique.h"
-#include "gromacs/options/isectionstorage.h"
+#include <memory>
+
+#include "isectionstorage.h"
 
 namespace gmx
 {
@@ -47,17 +48,17 @@ namespace
 
 class OptionSectionStorage : public IOptionSectionStorage
 {
-    public:
-        void initStorage() override {}
-        void startSection() override {}
-        void finishSection() override {}
+public:
+    void initStorage() override {}
+    void startSection() override {}
+    void finishSection() override {}
 };
 
-}   // namespace
+} // namespace
 
 std::unique_ptr<IOptionSectionStorage> OptionSection::createStorage() const
 {
-    return compat::make_unique<OptionSectionStorage>();
+    return std::make_unique<OptionSectionStorage>();
 }
 
 } // namespace gmx
