@@ -1,7 +1,7 @@
 /*
  * This file is part of the GROMACS molecular simulation package.
  *
- * Copyright (c) 2016,2018, by the GROMACS development team, led by
+ * Copyright (c) 2016,2018,2019, by the GROMACS development team, led by
  * Mark Abraham, David van der Spoel, Berk Hess, and Erik Lindahl,
  * and including many others, as listed in the AUTHORS file in the
  * top-level source directory and at http://www.gromacs.org.
@@ -43,9 +43,10 @@
 #ifndef GMX_OPTIONS_OPTIONSECTION_H
 #define GMX_OPTIONS_OPTIONSECTION_H
 
-#include "gromacs/options/abstractsection.h"
 #include "gromacs/utility/classhelpers.h"
 
+#include "abstractsection.h"
+
 namespace gmx
 {
 
@@ -63,15 +64,15 @@ class OptionSectionHandle;
  */
 class OptionSection : public AbstractOptionSection
 {
-    public:
-        //! AbstractOptionSectionHandle corresponding to this option type.
-        typedef OptionSectionHandle HandleType;
+public:
+    //! AbstractOptionSectionHandle corresponding to this option type.
+    typedef OptionSectionHandle HandleType;
 
-        //! Creates a section with the given name.
-        explicit OptionSection(const char *name) : AbstractOptionSection(name) {}
+    //! Creates a section with the given name.
+    explicit OptionSection(const char* name) : AbstractOptionSection(name) {}
 
-    private:
-        std::unique_ptr<IOptionSectionStorage> createStorage() const override;
+private:
+    std::unique_ptr<IOptionSectionStorage> createStorage() const override;
 };
 
 /*! \brief
@@ -86,22 +87,22 @@ class OptionSection : public AbstractOptionSection
  */
 class OptionSectionHandle : public AbstractOptionSectionHandle
 {
-    public:
-        //! Wraps a given section storage object.
-        explicit OptionSectionHandle(internal::OptionSectionImpl *section)
-            : AbstractOptionSectionHandle(section)
-        {
-        }
+public:
+    //! Wraps a given section storage object.
+    explicit OptionSectionHandle(internal::OptionSectionImpl* section) :
+        AbstractOptionSectionHandle(section)
+    {
+    }
 };
 
 class OptionSectionInfo : public AbstractOptionSectionInfo
 {
-    public:
-        //! Wraps a given section storage object.
-        explicit OptionSectionInfo(internal::OptionSectionImpl *section)
-            : AbstractOptionSectionInfo(section)
-        {
-        }
+public:
+    //! Wraps a given section storage object.
+    explicit OptionSectionInfo(internal::OptionSectionImpl* section) :
+        AbstractOptionSectionInfo(section)
+    {
+    }
 };
 
 } // namespace gmx
