@@ -1,7 +1,7 @@
 /*
  * This file is part of the GROMACS molecular simulation package.
  *
- * Copyright (c) 2018, by the GROMACS development team, led by
+ * Copyright (c) 2018,2019, by the GROMACS development team, led by
  * Mark Abraham, David van der Spoel, Berk Hess, and Erik Lindahl,
  * and including many others, as listed in the AUTHORS file in the
  * top-level source directory and at http://www.gromacs.org.
@@ -62,66 +62,66 @@ class RestraintMDModuleImpl;
  */
 class RestraintMDModule final : public gmx::IMDModule
 {
-    public:
-        RestraintMDModule() = delete;
+public:
+    RestraintMDModule() = delete;
 
-        /*!
-         * \brief Constructor used by static create() method.
-         */
-        explicit RestraintMDModule(std::unique_ptr<RestraintMDModuleImpl> restraint);
+    /*!
+     * \brief Constructor used by static create() method.
+     */
+    explicit RestraintMDModule(std::unique_ptr<RestraintMDModuleImpl> restraint);
 
-        ~RestraintMDModule() override;
+    ~RestraintMDModule() override;
 
-        /*!
-         * \brief Wrap a restraint potential as an MDModule
-         *
-         * \param restraint shared ownership of an object for calculating restraint forces.
-         * \return new wrapper object sharing ownership of restraint.
-         *
-         * Consumers of the interfaces provided by an IMDModule do not extend the lifetime
-         * of the interface objects returned by mdpOptionProvider(), outputProvider(), or
-         * registered via initForceProviders(). Calling code must keep this object alive
-         * as long as those interfaces are needed (probably the duration of an MD run).
-         *
-         * \param restraint handle to object to wrap
-         * \param sites list of sites for the framework to pass to the restraint
-         */
-        static std::unique_ptr<RestraintMDModule>
-        create(std::shared_ptr<gmx::IRestraintPotential> restraint, const std::vector<int> &sites);
+    /*!
+     * \brief Wrap a restraint potential as an MDModule
+     *
+     * \param restraint shared ownership of an object for calculating restraint forces.
+     * \return new wrapper object sharing ownership of restraint.
+     *
+     * Consumers of the interfaces provided by an IMDModule do not extend the lifetime
+     * of the interface objects returned by mdpOptionProvider(), outputProvider(), or
+     * registered via initForceProviders(). Calling code must keep this object alive
+     * as long as those interfaces are needed (probably the duration of an MD run).
+     *
+     * \param restraint handle to object to wrap
+     * \param sites list of sites for the framework to pass to the restraint
+     */
+    static std::unique_ptr<RestraintMDModule> create(std::shared_ptr<gmx::IRestraintPotential> restraint,
+                                                     const std::vector<int>& sites);
 
-        /*!
-         * \brief Implement IMDModule interface
-         *
-         * Unused.
-         *
-         * \return nullptr.
-         */
-        IMdpOptionProvider *mdpOptionProvider() override;
+    /*!
+     * \brief Implement IMDModule interface
+     *
+     * Unused.
+     *
+     * \return nullptr.
+     */
+    IMdpOptionProvider* mdpOptionProvider() override;
 
-        /*!
-         * \brief Implement IMDModule interface
-         *
-         * Unused.
-         *
-         * \return nullptr.
-         */
-        IMDOutputProvider *outputProvider() override;
+    /*!
+     * \brief Implement IMDModule interface
+     *
+     * Unused.
+     *
+     * \return nullptr.
+     */
+    IMDOutputProvider* outputProvider() override;
 
-        /*!
-         * \brief Implement IMDModule interface.
-         *
-         * See gmx::IMDModule::initForceProviders()
-         * \param forceProviders manager in the force record.
-         */
-        void initForceProviders(ForceProviders *forceProviders) override;
+    /*!
+     * \brief Implement IMDModule interface.
+     *
+     * See gmx::IMDModule::initForceProviders()
+     * \param forceProviders manager in the force record.
+     */
+    void initForceProviders(ForceProviders* forceProviders) override;
 
-    private:
-        /*!
-         * \brief Private implementation opaque pointer.
-         */
-        std::unique_ptr<RestraintMDModuleImpl> impl_;
+private:
+    /*!
+     * \brief Private implementation opaque pointer.
+     */
+    std::unique_ptr<RestraintMDModuleImpl> impl_;
 };
 
-}      // end namespace gmx
+} // end namespace gmx
 
-#endif //GROMACS_RESTRAINTMDMODULE_H
+#endif // GROMACS_RESTRAINTMDMODULE_H
