@@ -1,7 +1,7 @@
 /*
  * This file is part of the GROMACS molecular simulation package.
  *
- * Copyright (c) 2009,2010,2011,2012,2013,2014, by the GROMACS development team, led by
+ * Copyright (c) 2009,2010,2011,2012,2013,2014,2019, by the GROMACS development team, led by
  * Mark Abraham, David van der Spoel, Berk Hess, and Erik Lindahl,
  * and including many others, as listed in the AUTHORS file in the
  * top-level source directory and at http://www.gromacs.org.
@@ -59,68 +59,55 @@ struct gmx_ana_pos_t
     /*! \brief
      * Array of positions.
      */
-    rvec               *x;
+    rvec* x;
     /*! \brief
      * Velocities (can be NULL).
      */
-    rvec               *v;
+    rvec* v;
     /*! \brief
      * Forces (can be NULL).
      */
-    rvec               *f;
+    rvec* f;
     /*! \brief
      * Mapping of the current positions to the original group.
      *
      * \see gmx_ana_indexmap_t
      */
-    gmx_ana_indexmap_t  m;
+    gmx_ana_indexmap_t m;
     /*! \brief
      * Number of elements allocated for \c x.
      */
-    int                 nalloc_x;
+    int nalloc_x;
 };
 
 /** Ensures that enough memory has been allocated to store positions. */
-void
-gmx_ana_pos_reserve(gmx_ana_pos_t *pos, int n, int isize);
+void gmx_ana_pos_reserve(gmx_ana_pos_t* pos, int n, int isize);
 /** Request memory allocation for velocities. */
-void
-gmx_ana_pos_reserve_velocities(gmx_ana_pos_t *pos);
+void gmx_ana_pos_reserve_velocities(gmx_ana_pos_t* pos);
 /** Request memory allocation for forces. */
-void
-gmx_ana_pos_reserve_forces(gmx_ana_pos_t *pos);
+void gmx_ana_pos_reserve_forces(gmx_ana_pos_t* pos);
 /** Reserves memory for use with gmx_ana_pos_append_init(). */
-void
-gmx_ana_pos_reserve_for_append(gmx_ana_pos_t *pos, int n, int isize,
-                               bool bVelocities, bool bForces);
+void gmx_ana_pos_reserve_for_append(gmx_ana_pos_t* pos, int n, int isize, bool bVelocities, bool bForces);
 /** Initializes a \c gmx_ana_pos_t to represent a constant position. */
-void
-gmx_ana_pos_init_const(gmx_ana_pos_t *pos, const rvec x);
+void gmx_ana_pos_init_const(gmx_ana_pos_t* pos, const rvec x);
 /** Copies the evaluated positions to a preallocated data structure. */
-void
-gmx_ana_pos_copy(gmx_ana_pos_t *dest, gmx_ana_pos_t *src, bool bFirst);
+void gmx_ana_pos_copy(gmx_ana_pos_t* dest, gmx_ana_pos_t* src, bool bFirst);
 
 /** Sets the number of positions in a position structure. */
-void
-gmx_ana_pos_set_nr(gmx_ana_pos_t *pos, int n);
+void gmx_ana_pos_set_nr(gmx_ana_pos_t* pos, int n);
 /** Empties a position data structure with full initialization. */
-void
-gmx_ana_pos_empty_init(gmx_ana_pos_t *pos);
+void gmx_ana_pos_empty_init(gmx_ana_pos_t* pos);
 /** Empties a position data structure. */
-void
-gmx_ana_pos_empty(gmx_ana_pos_t *pos);
+void gmx_ana_pos_empty(gmx_ana_pos_t* pos);
 /** Appends a position to a preallocated data structure with full
  * initialization. */
-void
-gmx_ana_pos_append_init(gmx_ana_pos_t *dest, gmx_ana_pos_t *src, int i);
+void gmx_ana_pos_append_init(gmx_ana_pos_t* dest, gmx_ana_pos_t* src, int i);
 /** Appends a position to a preallocated data structure. */
-void
-gmx_ana_pos_append(gmx_ana_pos_t *dest, gmx_ana_pos_t *src, int i, int refid);
+void gmx_ana_pos_append(gmx_ana_pos_t* dest, gmx_ana_pos_t* src, int i, int refid);
 /** Updates position data structure state after appends. */
-void
-gmx_ana_pos_append_finish(gmx_ana_pos_t *pos);
+void gmx_ana_pos_append_finish(gmx_ana_pos_t* pos);
 void
 /** Appends atoms from a position into a preallocated index group. */
-gmx_ana_pos_add_to_group(gmx_ana_index_t *g, gmx_ana_pos_t *src, int i);
+gmx_ana_pos_add_to_group(gmx_ana_index_t* g, gmx_ana_pos_t* src, int i);
 
 #endif
