@@ -1,7 +1,7 @@
 /*
  * This file is part of the GROMACS molecular simulation package.
  *
- * Copyright (c) 2009,2010,2011,2014, by the GROMACS development team, led by
+ * Copyright (c) 2009,2010,2011,2014,2019, by the GROMACS development team, led by
  * Mark Abraham, David van der Spoel, Berk Hess, and Erik Lindahl,
  * and including many others, as listed in the AUTHORS file in the
  * top-level source directory and at http://www.gromacs.org.
@@ -50,13 +50,13 @@
 /** Defines the value type of a different selection objects. */
 typedef enum
 {
-    NO_VALUE,           /**< No value; either an error condition or an boolean
-                             parameter. */
-    INT_VALUE,          /**< One or more integer values. */
-    REAL_VALUE,         /**< One or more real values. */
-    STR_VALUE,          /**< One or more string values. */
-    POS_VALUE,          /**< One or more position values. */
-    GROUP_VALUE         /**< One group of atoms. */
+    NO_VALUE,   /**< No value; either an error condition or an boolean
+                     parameter. */
+    INT_VALUE,  /**< One or more integer values. */
+    REAL_VALUE, /**< One or more real values. */
+    STR_VALUE,  /**< One or more string values. */
+    POS_VALUE,  /**< One or more position values. */
+    GROUP_VALUE /**< One group of atoms. */
 } e_selvalue_t;
 
 /*! \internal
@@ -69,7 +69,7 @@ typedef enum
 typedef struct gmx_ana_selvalue_t
 {
     /** Type of the value. */
-    e_selvalue_t                type;
+    e_selvalue_t type;
     /*! \brief
      * Number of values in the array pointed by the union.
      *
@@ -77,7 +77,7 @@ typedef struct gmx_ana_selvalue_t
      * data structures in the array, not the number of positions or
      * the number of atoms in the group.
      */
-    int                         nr;
+    int nr;
     /** Pointer to the value. */
     union {
         /*! \brief
@@ -85,24 +85,24 @@ typedef struct gmx_ana_selvalue_t
          *
          * Needs to be the first member to be able to use initialized arrays.
          */
-        void                   *ptr;
+        void* ptr;
         /** Integer value(s) (type \ref INT_VALUE). */
-        int                    *i;
+        int* i;
         /** Real value(s) (type \ref REAL_VALUE). */
-        real                   *r;
+        real* r;
         /** String value(s) (type \ref STR_VALUE). */
-        char                  **s;
+        char** s;
         /** Structure for the position value(s) (type \ref POS_VALUE). */
-        struct gmx_ana_pos_t   *p;
+        struct gmx_ana_pos_t* p;
         /** Group value (type \ref GROUP_VALUE). */
-        struct gmx_ana_index_t *g;
+        struct gmx_ana_index_t* g;
         /** Boolean value (only parameters of type \ref NO_VALUE); */
-        bool                   *b;
-    }                           u;
+        bool* b;
+    } u;
     /*! \brief
      * Number of elements allocated for the value array.
      */
-    int                         nalloc;
+    int nalloc;
 } gmx_ana_selvalue_t;
 
 /*! \brief
@@ -113,8 +113,7 @@ typedef struct gmx_ana_selvalue_t
  * The type of \p val is not touched.
  * Any contents of \p val are discarded without freeing.
  */
-void
-_gmx_selvalue_clear(gmx_ana_selvalue_t *val);
+void _gmx_selvalue_clear(gmx_ana_selvalue_t* val);
 /*! \brief
  * Frees memory allocated for a selection value structure.
  *
@@ -124,8 +123,7 @@ _gmx_selvalue_clear(gmx_ana_selvalue_t *val);
  * If memory is not allocated, the value pointers are simply cleared without
  * freeing.
  */
-void
-_gmx_selvalue_free(gmx_ana_selvalue_t *val);
+void _gmx_selvalue_free(gmx_ana_selvalue_t* val);
 /*! \brief
  * Reserve memory for storing selection values.
  *
@@ -141,8 +139,7 @@ _gmx_selvalue_free(gmx_ana_selvalue_t *val);
  * Similarly, for \ref STR_VALUE values, the pointers are set to NULL.
  * For other values, the memory is uninitialized.
  */
-void
-_gmx_selvalue_reserve(gmx_ana_selvalue_t *val, int n);
+void _gmx_selvalue_reserve(gmx_ana_selvalue_t* val, int n);
 /*! \brief
  * Gets and releases the memory pointer for storing selection values.
  *
@@ -153,8 +150,7 @@ _gmx_selvalue_reserve(gmx_ana_selvalue_t *val, int n);
  * Returns the pointer where values of \p val were stored in \p ptr and
  * \p nalloc, and clears the memory in \p val.
  */
-void
-_gmx_selvalue_getstore_and_release(gmx_ana_selvalue_t *val, void **ptr, int *nalloc);
+void _gmx_selvalue_getstore_and_release(gmx_ana_selvalue_t* val, void** ptr, int* nalloc);
 /*! \brief
  * Sets the memory for storing selection values.
  *
@@ -165,8 +161,7 @@ _gmx_selvalue_getstore_and_release(gmx_ana_selvalue_t *val, void **ptr, int *nal
  * Asserts if \p val had a previous storage that it owned, as that would result
  * in a memory leak.
  */
-void
-_gmx_selvalue_setstore(gmx_ana_selvalue_t *val, void *ptr);
+void _gmx_selvalue_setstore(gmx_ana_selvalue_t* val, void* ptr);
 /*! \brief
  * Sets the memory for storing selection values and marks it for automatic freeing.
  *
@@ -177,7 +172,6 @@ _gmx_selvalue_setstore(gmx_ana_selvalue_t *val, void *ptr);
  * Asserts if \p val had a previous storage that it owned, as that would result
  * in a memory leak.
  */
-void
-_gmx_selvalue_setstore_alloc(gmx_ana_selvalue_t *val, void *ptr, int nalloc);
+void _gmx_selvalue_setstore_alloc(gmx_ana_selvalue_t* val, void* ptr, int nalloc);
 
 #endif
