@@ -1,7 +1,7 @@
 /*
  * This file is part of the GROMACS molecular simulation package.
  *
- * Copyright (c) 2014,2015,2016,2017,2018,2019, by the GROMACS development team, led by
+ * Copyright (c) 2014,2015,2016,2017,2018,2019,2020, by the GROMACS development team, led by
  * Mark Abraham, David van der Spoel, Berk Hess, and Erik Lindahl,
  * and including many others, as listed in the AUTHORS file in the
  * top-level source directory and at http://www.gromacs.org.
@@ -55,8 +55,9 @@ namespace gmx
 class SimdDouble
 {
 public:
+    MSVC_DIAGNOSTIC_IGNORE(26495) // simdInternal_ is not being initialized!
     SimdDouble() {}
-
+    MSVC_DIAGNOSTIC_RESET
     SimdDouble(double d) : simdInternal_(_mm256_set1_pd(d)) {}
 
     // Internal utility constructor to simplify return statements
@@ -68,8 +69,9 @@ public:
 class SimdDInt32
 {
 public:
+    MSVC_DIAGNOSTIC_IGNORE(26495) // simdInternal_ is not being initialized!
     SimdDInt32() {}
-
+    MSVC_DIAGNOSTIC_RESET
     SimdDInt32(std::int32_t i) : simdInternal_(_mm_set1_epi32(i)) {}
 
     // Internal utility constructor to simplify return statements
@@ -81,8 +83,9 @@ public:
 class SimdDBool
 {
 public:
+    MSVC_DIAGNOSTIC_IGNORE(26495) // simdInternal_ is not being initialized!
     SimdDBool() {}
-
+    MSVC_DIAGNOSTIC_RESET
     SimdDBool(bool b) : simdInternal_(_mm256_castsi256_pd(_mm256_set1_epi32(b ? 0xFFFFFFFF : 0))) {}
 
     // Internal utility constructor to simplify return statements
@@ -94,8 +97,9 @@ public:
 class SimdDIBool
 {
 public:
+    MSVC_DIAGNOSTIC_IGNORE(26495) // simdInternal_ is not being initialized!
     SimdDIBool() {}
-
+    MSVC_DIAGNOSTIC_RESET
     SimdDIBool(bool b) : simdInternal_(_mm_set1_epi32(b ? 0xFFFFFFFF : 0)) {}
 
     // Internal utility constructor to simplify return statements
