@@ -1,7 +1,7 @@
 /*
  * This file is part of the GROMACS molecular simulation package.
  *
- * Copyright (c) 2016,2017,2018, by the GROMACS development team, led by
+ * Copyright (c) 2016,2017,2018,2019, by the GROMACS development team, led by
  * Mark Abraham, David van der Spoel, Berk Hess, and Erik Lindahl,
  * and including many others, as listed in the AUTHORS file in the
  * top-level source directory and at http://www.gromacs.org.
@@ -55,25 +55,23 @@ namespace gmx
 
 /*! \libinternal \brief Specification for analytical table function (name, function, derivative)
  */
-struct
-AnalyticalSplineTableInput
+struct AnalyticalSplineTableInput
 {
     //NOLINTNEXTLINE(google-runtime-member-string-references)
-    const std::string                    &desc;        //!< \libinternal Brief description of function
-    std::function<double(double)>         function;    //!< \libinternal Analytical form of function
-    std::function<double(double)>         derivative;  //!< \libinternal Analytical derivative
+    const std::string&            desc;       //!< \libinternal Brief description of function
+    std::function<double(double)> function;   //!< \libinternal Analytical form of function
+    std::function<double(double)> derivative; //!< \libinternal Analytical derivative
 };
 
 /*! \libinternal \brief Specification for vector table function (name, function, derivative, spacing)
  */
-struct
-NumericalSplineTableInput
+struct NumericalSplineTableInput
 {
     //NOLINTNEXTLINE(google-runtime-member-string-references)
-    const std::string                    &desc;        //!< \libinternal Brief description of function
-    ArrayRef<const double>                function;    //!< \libinternal Vector with function values
-    ArrayRef<const double>                derivative;  //!< \libinternal Vector with derivative values
-    double                                spacing;     //!< \libinternal Distance between data points
+    const std::string&     desc;       //!< \libinternal Brief description of function
+    ArrayRef<const double> function;   //!< \libinternal Vector with function values
+    ArrayRef<const double> derivative; //!< \libinternal Vector with derivative values
+    double                 spacing;    //!< \libinternal Distance between data points
 };
 
 
