@@ -3,7 +3,7 @@
  *
  * Copyright (c) 1991-2000, University of Groningen, The Netherlands.
  * Copyright (c) 2001-2008, The GROMACS development team.
- * Copyright (c) 2013,2014,2015,2016,2017,2018, by the GROMACS development team, led by
+ * Copyright (c) 2013,2014,2015,2016,2017,2018,2019, by the GROMACS development team, led by
  * Mark Abraham, David van der Spoel, Berk Hess, and Erik Lindahl,
  * and including many others, as listed in the AUTHORS file in the
  * top-level source directory and at http://www.gromacs.org.
@@ -66,7 +66,7 @@ static const bool useCycleSubcounters = GMX_CYCLE_SUBCOUNTERS;
 /* #define DEBUG_WCYCLE */
 
 #ifdef DEBUG_WCYCLE
-#include "gromacs/utility/fatalerror.h"
+#    include "gromacs/utility/fatalerror.h"
 #endif
 
 typedef struct
@@ -78,73 +78,109 @@ typedef struct
 
 struct gmx_wallcycle
 {
-    wallcc_t        *wcc;
+    wallcc_t* wcc;
     /* did we detect one or more invalid cycle counts */
-    gmx_bool         haveInvalidCount;
+    gmx_bool haveInvalidCount;
     /* variables for testing/debugging */
-    gmx_bool         wc_barrier;
-    wallcc_t        *wcc_all;
-    int              wc_depth;
+    gmx_bool  wc_barrier;
+    wallcc_t* wcc_all;
+    int       wc_depth;
 #ifdef DEBUG_WCYCLE
-#define DEPTH_MAX 6
-    int               counterlist[DEPTH_MAX];
-    int               count_depth;
+#    define DEPTH_MAX 6
+    int counterlist[DEPTH_MAX];
+    int count_depth;
 #endif
-    int               ewc_prev;
-    gmx_cycles_t      cycle_prev;
-    int64_t           reset_counters;
+    int          ewc_prev;
+    gmx_cycles_t cycle_prev;
+    int64_t      reset_counters;
 #if GMX_MPI
-    MPI_Comm          mpi_comm_mygroup;
+    MPI_Comm mpi_comm_mygroup;
 #endif
-    wallcc_t         *wcsc;
+    wallcc_t* wcsc;
 };
 
 /* Each name should not exceed 19 printing characters
    (ie. terminating null can be twentieth) */
-static const char *wcn[ewcNR] =
-{
-    "Run", "Step", "PP during PME", "Domain decomp.", "DD comm. load",
-    "DD comm. bounds", "Vsite constr.", "Send X to PME", "Neighbor search", "Launch GPU ops.",
-    "Comm. coord.", "Force", "Wait + Comm. F", "PME mesh",
-    "PME redist. X/F", "PME spread", "PME gather", "PME 3D-FFT", "PME 3D-FFT Comm.", "PME solve LJ", "PME solve Elec",
-    "PME wait for PP", "Wait + Recv. PME F",
-    "Wait PME GPU spread", "PME 3D-FFT", "PME solve", /* the strings for FFT/solve are repeated here for mixed mode counters */
-    "Wait PME GPU gather", "Wait Bonded GPU", "Reduce GPU PME F",
-    "Wait GPU NB nonloc.", "Wait GPU NB local", "NB X/F buffer ops.",
-    "Vsite spread", "COM pull force", "AWH",
-    "Write traj.", "Update", "Constraints", "Comm. energies",
-    "Enforced rotation", "Add rot. forces", "Position swapping", "IMD", "Test"
-};
+static const char* wcn[ewcNR] = { "Run",
+                                  "Step",
+                                  "PP during PME",
+                                  "Domain decomp.",
+                                  "DD comm. load",
+                                  "DD comm. bounds",
+                                  "Vsite constr.",
+                                  "Send X to PME",
+                                  "Neighbor search",
+                                  "Launch GPU ops.",
+                                  "Comm. coord.",
+                                  "Force",
+                                  "Wait + Comm. F",
+                                  "PME mesh",
+                                  "PME redist. X/F",
+                                  "PME spread",
+                                  "PME gather",
+                                  "PME 3D-FFT",
+                                  "PME 3D-FFT Comm.",
+                                  "PME solve LJ",
+                                  "PME solve Elec",
+                                  "PME wait for PP",
+                                  "Wait + Recv. PME F",
+                                  "Wait PME GPU spread",
+                                  "PME 3D-FFT",
+                                  "PME solve", /* the strings for FFT/solve are repeated here for mixed mode counters */
+                                  "Wait PME GPU gather",
+                                  "Wait Bonded GPU",
+                                  "Reduce GPU PME F",
+                                  "Wait GPU NB nonloc.",
+                                  "Wait GPU NB local",
+                                  "Wait GPU state copy",
+                                  "NB X/F buffer ops.",
+                                  "Vsite spread",
+                                  "COM pull force",
+                                  "AWH",
+                                  "Write traj.",
+                                  "Update",
+                                  "Constraints",
+                                  "Comm. energies",
+                                  "Enforced rotation",
+                                  "Add rot. forces",
+                                  "Position swapping",
+                                  "IMD",
+                                  "Test" };
 
-static const char *wcsn[ewcsNR] =
-{
-    "DD redist.", "DD NS grid + sort", "DD setup comm.",
-    "DD make top.", "DD make constr.", "DD top. other",
-    "NS grid local", "NS grid non-loc.", "NS search local", "NS search non-loc.",
+static const char* wcsn[ewcsNR] = {
+    "DD redist.",
+    "DD NS grid + sort",
+    "DD setup comm.",
+    "DD make top.",
+    "DD make constr.",
+    "DD top. other",
+    "NS grid local",
+    "NS grid non-loc.",
+    "NS search local",
+    "NS search non-loc.",
     "Bonded F",
     "Bonded-FEP F",
     "Restraints F",
     "Listed buffer ops.",
     "Nonbonded pruning",
-    "Nonbonded F",
+    "Nonbonded F kernel",
+    "Nonbonded F clear",
+    "Nonbonded FEP",
     "Launch NB GPU tasks",
     "Launch Bonded GPU tasks",
     "Launch PME GPU tasks",
+    "Launch state copy",
     "Ewald F correction",
     "NB X buffer ops.",
     "NB F buffer ops.",
+    "Clear force buffer",
+    "Test subcounter",
 };
 
 /* PME GPU timing events' names - correspond to the enum in the gpu_timing.h */
-static const char *PMEStageNames[] =
-{
-    "PME spline",
-    "PME spread",
-    "PME spline + spread",
-    "PME 3D-FFT r2c",
-    "PME solve",
-    "PME 3D-FFT c2r",
-    "PME gather",
+static const char* PMEStageNames[] = {
+    "PME spline", "PME spread",     "PME spline + spread", "PME 3D-FFT r2c",
+    "PME solve",  "PME 3D-FFT c2r", "PME gather",
 };
 
 gmx_bool wallcycle_have_counter()
@@ -152,7 +188,7 @@ gmx_bool wallcycle_have_counter()
     return gmx_cycles_have_counter();
 }
 
-gmx_wallcycle_t wallcycle_init(FILE *fplog, int resetstep, t_commrec gmx_unused *cr)
+gmx_wallcycle_t wallcycle_init(FILE* fplog, int resetstep, t_commrec gmx_unused* cr)
 {
     gmx_wallcycle_t wc;
 
@@ -164,12 +200,12 @@ gmx_wallcycle_t wallcycle_init(FILE *fplog, int resetstep, t_commrec gmx_unused
 
     snew(wc, 1);
 
-    wc->haveInvalidCount    = FALSE;
-    wc->wc_barrier          = FALSE;
-    wc->wcc_all             = nullptr;
-    wc->wc_depth            = 0;
-    wc->ewc_prev            = -1;
-    wc->reset_counters      = resetstep;
+    wc->haveInvalidCount = FALSE;
+    wc->wc_barrier       = FALSE;
+    wc->wcc_all          = nullptr;
+    wc->wc_depth         = 0;
+    wc->ewc_prev         = -1;
+    wc->reset_counters   = resetstep;
 
 #if GMX_MPI
     if (PAR(cr) && getenv("GMX_CYCLE_BARRIER") != nullptr)
@@ -190,7 +226,7 @@ gmx_wallcycle_t wallcycle_init(FILE *fplog, int resetstep, t_commrec gmx_unused
         {
             fprintf(fplog, "\nWill time all the code during the run\n\n");
         }
-        snew(wc->wcc_all, ewcNR*ewcNR);
+        snew(wc->wcc_all, ewcNR * ewcNR);
     }
 
     if (useCycleSubcounters)
@@ -205,9 +241,8 @@ gmx_wallcycle_t wallcycle_init(FILE *fplog, int resetstep, t_commrec gmx_unused
     return wc;
 }
 
-/* TODO: Should be called from finish_run() or runner()
-   void wallcycle_destroy(gmx_wallcycle_t wc)
-   {
+void wallcycle_destroy(gmx_wallcycle_t wc)
+{
     if (wc == nullptr)
     {
         return;
@@ -226,8 +261,7 @@ gmx_wallcycle_t wallcycle_init(FILE *fplog, int resetstep, t_commrec gmx_unused
         sfree(wc->wcsc);
     }
     sfree(wc);
-   }
- */
+}
 
 static void wallcycle_all_start(gmx_wallcycle_t wc, int ewc, gmx_cycles_t cycle)
 {
@@ -237,8 +271,8 @@ static void wallcycle_all_start(gmx_wallcycle_t wc, int ewc, gmx_cycles_t cycle)
 
 static void wallcycle_all_stop(gmx_wallcycle_t wc, int ewc, gmx_cycles_t cycle)
 {
-    wc->wcc_all[wc->ewc_prev*ewcNR+ewc].n += 1;
-    wc->wcc_all[wc->ewc_prev*ewcNR+ewc].c += cycle - wc->cycle_prev;
+    wc->wcc_all[wc->ewc_prev * ewcNR + ewc].n += 1;
+    wc->wcc_all[wc->ewc_prev * ewcNR + ewc].c += cycle - wc->cycle_prev;
 }
 
 
@@ -249,8 +283,7 @@ static void debug_start_check(gmx_wallcycle_t wc, int ewc)
 
     if (wc->count_depth < 0 || wc->count_depth >= DEPTH_MAX)
     {
-        gmx_fatal(FARGS, "wallcycle counter depth out of range: %d",
-                  wc->count_depth);
+        gmx_fatal(FARGS, "wallcycle counter depth out of range: %d", wc->count_depth);
     }
     wc->counterlist[wc->count_depth] = ewc;
     wc->count_depth++;
@@ -264,7 +297,8 @@ static void debug_stop_check(gmx_wallcycle_t wc, int ewc)
 
     if (wc->count_depth < 0)
     {
-        gmx_fatal(FARGS, "wallcycle counter depth out of range when stopping %s: %d", wcn[ewc], wc->count_depth);
+        gmx_fatal(FARGS, "wallcycle counter depth out of range when stopping %s: %d", wcn[ewc],
+                  wc->count_depth);
     }
     if (wc->counterlist[wc->count_depth] != ewc)
     {
@@ -310,6 +344,15 @@ void wallcycle_start(gmx_wallcycle_t wc, int ewc)
     }
 }
 
+void wallcycle_increment_event_count(gmx_wallcycle_t wc, int ewc)
+{
+    if (wc == nullptr)
+    {
+        return;
+    }
+    wc->wcc[ewc].n++;
+}
+
 void wallcycle_start_nocount(gmx_wallcycle_t wc, int ewc)
 {
     if (wc == nullptr)
@@ -349,17 +392,17 @@ double wallcycle_stop(gmx_wallcycle_t wc, int ewc)
      * large, especially for ewcRUN. If we detect a negative count,
      * we will not print the cycle accounting table.
      */
-    cycle                    = gmx_cycles_read();
+    cycle = gmx_cycles_read();
     if (cycle >= wc->wcc[ewc].start)
     {
-        last                 = cycle - wc->wcc[ewc].start;
+        last = cycle - wc->wcc[ewc].start;
     }
     else
     {
         last                 = 0;
         wc->haveInvalidCount = TRUE;
     }
-    wc->wcc[ewc].c          += last;
+    wc->wcc[ewc].c += last;
     wc->wcc[ewc].n++;
     if (wc->wcc_all)
     {
@@ -377,7 +420,7 @@ double wallcycle_stop(gmx_wallcycle_t wc, int ewc)
     return last;
 }
 
-void wallcycle_get(gmx_wallcycle_t wc, int ewc, int *n, double *c)
+void wallcycle_get(gmx_wallcycle_t wc, int ewc, int* n, double* c)
 {
     *n = wc->wcc[ewc].n;
     *c = static_cast<double>(wc->wcc[ewc].c);
@@ -401,7 +444,7 @@ void wallcycle_reset_all(gmx_wallcycle_t wc)
 
     if (wc->wcc_all)
     {
-        for (i = 0; i < ewcNR*ewcNR; i++)
+        for (i = 0; i < ewcNR * ewcNR; i++)
         {
             wc->wcc_all[i].n = 0;
             wc->wcc_all[i].c = 0;
@@ -428,7 +471,7 @@ static gmx_bool is_pme_subcounter(int ewc)
 }
 
 /* Subtract counter ewc_sub timed inside a timing block for ewc_main */
-static void subtract_cycles(wallcc_t *wcc, int ewc_main, int ewc_sub)
+static void subtract_cycles(wallcc_t* wcc, int ewc_main, int ewc_sub)
 {
     if (wcc[ewc_sub].n > 0)
     {
@@ -439,7 +482,7 @@ static void subtract_cycles(wallcc_t *wcc, int ewc_main, int ewc_sub)
         else
         {
             /* Something is wrong with the cycle counting */
-            wcc[ewc_main].c  = 0;
+            wcc[ewc_main].c = 0;
         }
     }
 }
@@ -461,7 +504,7 @@ void wallcycle_scale_by_num_threads(gmx_wallcycle_t wc, bool isPmeRank, int nthr
             {
                 for (int j = 0; j < ewcNR; j++)
                 {
-                    wc->wcc_all[i*ewcNR+j].c *= nthreads_pme;
+                    wc->wcc_all[i * ewcNR + j].c *= nthreads_pme;
                 }
             }
         }
@@ -473,7 +516,7 @@ void wallcycle_scale_by_num_threads(gmx_wallcycle_t wc, bool isPmeRank, int nthr
             {
                 for (int j = 0; j < ewcNR; j++)
                 {
-                    wc->wcc_all[i*ewcNR+j].c *= nthreads_pp;
+                    wc->wcc_all[i * ewcNR + j].c *= nthreads_pp;
                 }
             }
         }
@@ -499,16 +542,16 @@ void wallcycle_scale_by_num_threads(gmx_wallcycle_t wc, bool isPmeRank, int nthr
  * wcc_all are unused by the GPU reporting, but it is not satisfactory
  * for the future. Also, there's no need for MPI_Allreduce, since
  * only MASTERRANK uses any of the results. */
-WallcycleCounts wallcycle_sum(const t_commrec *cr, gmx_wallcycle_t wc)
+WallcycleCounts wallcycle_sum(const t_commrec* cr, gmx_wallcycle_t wc)
 {
     WallcycleCounts cycles_sum;
-    wallcc_t       *wcc;
-    double          cycles[ewcNR+ewcsNR];
+    wallcc_t*       wcc;
+    double          cycles[ewcNR + ewcsNR];
 #if GMX_MPI
-    double          cycles_n[ewcNR+ewcsNR+1];
+    double cycles_n[ewcNR + ewcsNR + 1];
 #endif
-    int             i;
-    int             nsum;
+    int i;
+    int nsum;
 
     if (wc == nullptr)
     {
@@ -537,7 +580,8 @@ WallcycleCounts wallcycle_sum(const t_commrec *cr, gmx_wallcycle_t wc)
         if (wcc[ewcPMEMESH].n > 0)
         {
             /* This must be a PME only node, calculate the Wait + Comm. time */
-            GMX_ASSERT(wcc[ewcRUN].c >= wcc[ewcPMEMESH].c, "Total run ticks must be greater than PME-only ticks");
+            GMX_ASSERT(wcc[ewcRUN].c >= wcc[ewcPMEMESH].c,
+                       "Total run ticks must be greater than PME-only ticks");
             wcc[ewcPMEWAITCOMM].c = wcc[ewcRUN].c - wcc[ewcPMEMESH].c;
         }
     }
@@ -548,7 +592,7 @@ WallcycleCounts wallcycle_sum(const t_commrec *cr, gmx_wallcycle_t wc)
 #if GMX_MPI
         cycles_n[i] = static_cast<double>(wcc[i].n);
 #endif
-        cycles[i]   = static_cast<double>(wcc[i].c);
+        cycles[i] = static_cast<double>(wcc[i].c);
     }
     nsum = ewcNR;
     if (wc->wcsc)
@@ -556,9 +600,9 @@ WallcycleCounts wallcycle_sum(const t_commrec *cr, gmx_wallcycle_t wc)
         for (i = 0; i < ewcsNR; i++)
         {
 #if GMX_MPI
-            cycles_n[ewcNR+i] = static_cast<double>(wc->wcsc[i].n);
+            cycles_n[ewcNR + i] = static_cast<double>(wc->wcsc[i].n);
 #endif
-            cycles[ewcNR+i]   = static_cast<double>(wc->wcsc[i].c);
+            cycles[ewcNR + i] = static_cast<double>(wc->wcsc[i].c);
         }
         nsum += ewcsNR;
     }
@@ -566,15 +610,14 @@ WallcycleCounts wallcycle_sum(const t_commrec *cr, gmx_wallcycle_t wc)
 #if GMX_MPI
     if (cr->nnodes > 1)
     {
-        double buf[ewcNR+ewcsNR+1];
+        double buf[ewcNR + ewcsNR + 1];
 
         // TODO this code is used only at the end of the run, so we
         // can just do a simple reduce of haveInvalidCount in
         // wallcycle_print, and avoid bugs
         cycles_n[nsum] = (wc->haveInvalidCount ? 1 : 0);
         // TODO Use MPI_Reduce
-        MPI_Allreduce(cycles_n, buf, nsum + 1, MPI_DOUBLE, MPI_MAX,
-                      cr->mpi_comm_mysim);
+        MPI_Allreduce(cycles_n, buf, nsum + 1, MPI_DOUBLE, MPI_MAX, cr->mpi_comm_mysim);
         for (i = 0; i < ewcNR; i++)
         {
             wcc[i].n = gmx::roundToInt(buf[i]);
@@ -584,28 +627,26 @@ WallcycleCounts wallcycle_sum(const t_commrec *cr, gmx_wallcycle_t wc)
         {
             for (i = 0; i < ewcsNR; i++)
             {
-                wc->wcsc[i].n = gmx::roundToInt(buf[ewcNR+i]);
+                wc->wcsc[i].n = gmx::roundToInt(buf[ewcNR + i]);
             }
         }
 
         // TODO Use MPI_Reduce
-        MPI_Allreduce(cycles, cycles_sum.data(), nsum, MPI_DOUBLE, MPI_SUM,
-                      cr->mpi_comm_mysim);
+        MPI_Allreduce(cycles, cycles_sum.data(), nsum, MPI_DOUBLE, MPI_SUM, cr->mpi_comm_mysim);
 
         if (wc->wcc_all != nullptr)
         {
             double *buf_all, *cyc_all;
 
-            snew(cyc_all, ewcNR*ewcNR);
-            snew(buf_all, ewcNR*ewcNR);
-            for (i = 0; i < ewcNR*ewcNR; i++)
+            snew(cyc_all, ewcNR * ewcNR);
+            snew(buf_all, ewcNR * ewcNR);
+            for (i = 0; i < ewcNR * ewcNR; i++)
             {
                 cyc_all[i] = wc->wcc_all[i].c;
             }
             // TODO Use MPI_Reduce
-            MPI_Allreduce(cyc_all, buf_all, ewcNR*ewcNR, MPI_DOUBLE, MPI_SUM,
-                          cr->mpi_comm_mysim);
-            for (i = 0; i < ewcNR*ewcNR; i++)
+            MPI_Allreduce(cyc_all, buf_all, ewcNR * ewcNR, MPI_DOUBLE, MPI_SUM, cr->mpi_comm_mysim);
+            for (i = 0; i < ewcNR * ewcNR; i++)
             {
                 wc->wcc_all[i].c = static_cast<gmx_cycles_t>(buf_all[i]);
             }
@@ -625,9 +666,8 @@ WallcycleCounts wallcycle_sum(const t_commrec *cr, gmx_wallcycle_t wc)
     return cycles_sum;
 }
 
-static void print_cycles(FILE *fplog, double c2t, const char *name,
-                         int nnodes, int nthreads,
-                         int ncalls, double c_sum, double tot)
+static void
+print_cycles(FILE* fplog, double c2t, const char* name, int nnodes, int nthreads, int ncalls, double c_sum, double tot)
 {
     char   nnodes_str[STRLEN];
     char   nthreads_str[STRLEN];
@@ -664,16 +704,14 @@ static void print_cycles(FILE *fplog, double c2t, const char *name,
             ncalls_str[0]   = 0;
         }
         /* Convert the cycle count to wallclock time for this task */
-        wallt = c_sum*c2t;
+        wallt = c_sum * c2t;
 
-        fprintf(fplog, " %-19.19s %4s %4s %10s  %10.3f %14.3f %5.1f\n",
-                name, nnodes_str, nthreads_str, ncalls_str, wallt,
-                c_sum*1e-9, percentage);
+        fprintf(fplog, " %-19.19s %4s %4s %10s  %10.3f %14.3f %5.1f\n", name, nnodes_str,
+                nthreads_str, ncalls_str, wallt, c_sum * 1e-9, percentage);
     }
 }
 
-static void print_gputimes(FILE *fplog, const char *name,
-                           int n, double t, double tot_t)
+static void print_gputimes(FILE* fplog, const char* name, int n, double t, double tot_t)
 {
     char num[11];
     char avg_perf[11];
@@ -681,7 +719,7 @@ static void print_gputimes(FILE *fplog, const char *name,
     if (n > 0)
     {
         snprintf(num, sizeof(num), "%10d", n);
-        snprintf(avg_perf, sizeof(avg_perf), "%10.3f", t/n);
+        snprintf(avg_perf, sizeof(avg_perf), "%10.3f", t / n);
     }
     else
     {
@@ -690,17 +728,15 @@ static void print_gputimes(FILE *fplog, const char *name,
     }
     if (t != tot_t && tot_t > 0)
     {
-        fprintf(fplog, " %-29s %10s%12.3f   %s   %5.1f\n",
-                name, num, t/1000, avg_perf, 100 * t/tot_t);
+        fprintf(fplog, " %-29s %10s%12.3f   %s   %5.1f\n", name, num, t / 1000, avg_perf, 100 * t / tot_t);
     }
     else
     {
-        fprintf(fplog, " %-29s %10s%12.3f   %s   %5.1f\n",
-                name, "", t/1000, avg_perf, 100.0);
+        fprintf(fplog, " %-29s %10s%12.3f   %s   %5.1f\n", name, "", t / 1000, avg_perf, 100.0);
     }
 }
 
-static void print_header(FILE *fplog, int nrank_pp, int nth_pp, int nrank_pme, int nth_pme)
+static void print_header(FILE* fplog, int nrank_pp, int nth_pp, int nrank_pme, int nth_pme)
 {
     int nrank_tot = nrank_pp + nrank_pme;
     if (0 == nrank_pme)
@@ -733,17 +769,24 @@ static void print_header(FILE *fplog, int nrank_pp, int nth_pp, int nrank_pme, i
 }
 
 
-void wallcycle_print(FILE *fplog, const gmx::MDLogger &mdlog, int nnodes, int npme,
-                     int nth_pp, int nth_pme, double realtime,
-                     gmx_wallcycle_t wc, const WallcycleCounts &cyc_sum,
-                     const gmx_wallclock_gpu_nbnxn_t *gpu_nbnxn_t,
-                     const gmx_wallclock_gpu_pme_t *gpu_pme_t)
+void wallcycle_print(FILE*                            fplog,
+                     const gmx::MDLogger&             mdlog,
+                     int                              nnodes,
+                     int                              npme,
+                     int                              nth_pp,
+                     int                              nth_pme,
+                     double                           realtime,
+                     gmx_wallcycle_t                  wc,
+                     const WallcycleCounts&           cyc_sum,
+                     const gmx_wallclock_gpu_nbnxn_t* gpu_nbnxn_t,
+                     const gmx_wallclock_gpu_pme_t*   gpu_pme_t)
 {
     double      tot, tot_for_pp, tot_for_rest, tot_cpu_overlap, gpu_cpu_ratio;
     double      c2t, c2t_pp, c2t_pme = 0;
     int         i, j, npp, nth_tot;
     char        buf[STRLEN];
-    const char *hline = "-----------------------------------------------------------------------------";
+    const char* hline =
+            "-----------------------------------------------------------------------------";
 
     if (wc == nullptr)
     {
@@ -754,11 +797,11 @@ void wallcycle_print(FILE *fplog, const gmx::MDLogger &mdlog, int nnodes, int np
     GMX_ASSERT(nth_pme > 0, "Number of PME threads must be >0");
     GMX_ASSERT(nnodes > 0, "Number of nodes must be >0");
     GMX_ASSERT(npme >= 0, "Number of PME nodes cannot be negative");
-    npp     = nnodes - npme;
+    npp = nnodes - npme;
     /* npme is the number of PME-only ranks used, and we always do PP work */
     GMX_ASSERT(npp > 0, "Number of particle-particle nodes must be >0");
 
-    nth_tot = npp*nth_pp + npme*nth_pme;
+    nth_tot = npp * nth_pp + npme * nth_pme;
 
     /* When using PME-only nodes, the next line is valid for both
        PP-only and PME-only nodes because they started ewcRUN at the
@@ -775,25 +818,33 @@ void wallcycle_print(FILE *fplog, const gmx::MDLogger &mdlog, int nnodes, int np
            timing data might still be sensible for some non-Jenkins
            run, than is lost from diagnosing Jenkins FP exceptions on
            runs about whose execution time we don't care. */
-        GMX_LOG(mdlog.warning).asParagraph().appendTextFormatted(
-                "WARNING: A total of %f CPU cycles was recorded, so mdrun cannot print a time accounting",
-                tot);
+        GMX_LOG(mdlog.warning)
+                .asParagraph()
+                .appendTextFormatted(
+                        "WARNING: A total of %f CPU cycles was recorded, so mdrun cannot print a "
+                        "time accounting",
+                        tot);
         return;
     }
 
     if (wc->haveInvalidCount)
     {
-        GMX_LOG(mdlog.warning).asParagraph().appendText("NOTE: Detected invalid cycle counts, probably because threads moved between CPU cores that do not have synchronized cycle counters. Will not print the cycle accounting.");
+        GMX_LOG(mdlog.warning)
+                .asParagraph()
+                .appendText(
+                        "NOTE: Detected invalid cycle counts, probably because threads moved "
+                        "between CPU cores that do not have synchronized cycle counters. Will not "
+                        "print the cycle accounting.");
         return;
     }
 
 
     /* Conversion factor from cycles to seconds */
-    c2t     = realtime/tot;
-    c2t_pp  = c2t * nth_tot / static_cast<double>(npp*nth_pp);
+    c2t    = realtime / tot;
+    c2t_pp = c2t * nth_tot / static_cast<double>(npp * nth_pp);
     if (npme > 0)
     {
-        c2t_pme = c2t * nth_tot / static_cast<double>(npme*nth_pme);
+        c2t_pme = c2t * nth_tot / static_cast<double>(npme * nth_pme);
     }
     else
     {
@@ -805,7 +856,7 @@ void wallcycle_print(FILE *fplog, const gmx::MDLogger &mdlog, int nnodes, int np
     print_header(fplog, npp, nth_pp, npme, nth_pme);
 
     fprintf(fplog, "%s\n", hline);
-    for (i = ewcPPDURINGPME+1; i < ewcNR; i++)
+    for (i = ewcPPDURINGPME + 1; i < ewcNR; i++)
     {
         if (is_pme_subcounter(i))
         {
@@ -819,17 +870,13 @@ void wallcycle_print(FILE *fplog, const gmx::MDLogger &mdlog, int nnodes, int np
              * fits in the required maximum of 19 characters. */
             char buffer[STRLEN];
             snprintf(buffer, STRLEN, "%s *", wcn[i]);
-            print_cycles(fplog, c2t_pme, buffer,
-                         npme, nth_pme,
-                         wc->wcc[i].n, cyc_sum[i], tot);
+            print_cycles(fplog, c2t_pme, buffer, npme, nth_pme, wc->wcc[i].n, cyc_sum[i], tot);
         }
         else
         {
             /* Print timing information when it is for a PP or PP+PME
                node */
-            print_cycles(fplog, c2t_pp, wcn[i],
-                         npp, nth_pp,
-                         wc->wcc[i].n, cyc_sum[i], tot);
+            print_cycles(fplog, c2t_pp, wcn[i], npp, nth_pp, wc->wcc[i].n, cyc_sum[i], tot);
             tot_for_pp += cyc_sum[i];
         }
     }
@@ -840,22 +887,15 @@ void wallcycle_print(FILE *fplog, const gmx::MDLogger &mdlog, int nnodes, int np
             for (j = 0; j < ewcNR; j++)
             {
                 snprintf(buf, 20, "%-9.9s %-9.9s", wcn[i], wcn[j]);
-                print_cycles(fplog, c2t_pp, buf,
-                             npp, nth_pp,
-                             wc->wcc_all[i*ewcNR+j].n,
-                             wc->wcc_all[i*ewcNR+j].c,
-                             tot);
+                print_cycles(fplog, c2t_pp, buf, npp, nth_pp, wc->wcc_all[i * ewcNR + j].n,
+                             wc->wcc_all[i * ewcNR + j].c, tot);
             }
         }
     }
     tot_for_rest = tot * npp * nth_pp / static_cast<double>(nth_tot);
-    print_cycles(fplog, c2t_pp, "Rest",
-                 npp, nth_pp,
-                 -1, tot_for_rest - tot_for_pp, tot);
+    print_cycles(fplog, c2t_pp, "Rest", npp, nth_pp, -1, tot_for_rest - tot_for_pp, tot);
     fprintf(fplog, "%s\n", hline);
-    print_cycles(fplog, c2t, "Total",
-                 npp, nth_pp,
-                 -1, tot, tot);
+    print_cycles(fplog, c2t, "Total", npp, nth_pp, -1, tot, tot);
     fprintf(fplog, "%s\n", hline);
 
     if (npme > 0)
@@ -863,7 +903,8 @@ void wallcycle_print(FILE *fplog, const gmx::MDLogger &mdlog, int nnodes, int np
         fprintf(fplog,
                 "(*) Note that with separate PME ranks, the walltime column actually sums to\n"
                 "    twice the total reported, but the cycle count total and %% are correct.\n"
-                "%s\n", hline);
+                "%s\n",
+                hline);
     }
 
     if (wc->wcc[ewcPMEMESH].n > 0)
@@ -871,7 +912,7 @@ void wallcycle_print(FILE *fplog, const gmx::MDLogger &mdlog, int nnodes, int np
         // A workaround to not print breakdown when no subcounters were recorded.
         // TODO: figure out and record PME GPU counters (what to do with the waiting ones?)
         std::vector<int> validPmeSubcounterIndices;
-        for (i = ewcPPDURINGPME+1; i < ewcNR; i++)
+        for (i = ewcPPDURINGPME + 1; i < ewcNR; i++)
         {
             if (is_pme_subcounter(i) && wc->wcc[i].n > 0)
             {
@@ -885,9 +926,8 @@ void wallcycle_print(FILE *fplog, const gmx::MDLogger &mdlog, int nnodes, int np
             fprintf(fplog, "%s\n", hline);
             for (auto i : validPmeSubcounterIndices)
             {
-                print_cycles(fplog, npme > 0 ? c2t_pme : c2t_pp, wcn[i],
-                             npme > 0 ? npme : npp, nth_pme,
-                             wc->wcc[i].n, cyc_sum[i], tot);
+                print_cycles(fplog, npme > 0 ? c2t_pme : c2t_pp, wcn[i], npme > 0 ? npme : npp,
+                             nth_pme, wc->wcc[i].n, cyc_sum[i], tot);
             }
             fprintf(fplog, "%s\n", hline);
         }
@@ -899,9 +939,7 @@ void wallcycle_print(FILE *fplog, const gmx::MDLogger &mdlog, int nnodes, int np
         fprintf(fplog, "%s\n", hline);
         for (i = 0; i < ewcsNR; i++)
         {
-            print_cycles(fplog, c2t_pp, wcsn[i],
-                         npp, nth_pp,
-                         wc->wcsc[i].n, cyc_sum[ewcNR+i], tot);
+            print_cycles(fplog, c2t_pp, wcsn[i], npp, nth_pp, wc->wcsc[i].n, cyc_sum[ewcNR + i], tot);
         }
         fprintf(fplog, "%s\n", hline);
     }
@@ -917,10 +955,8 @@ void wallcycle_print(FILE *fplog, const gmx::MDLogger &mdlog, int nnodes, int np
     }
     if (gpu_nbnxn_t)
     {
-        const char *k_log_str[2][2] = {
-            {"Nonbonded F kernel", "Nonbonded F+ene k."},
-            {"Nonbonded F+prune k.", "Nonbonded F+ene+prune k."}
-        };
+        const char* k_log_str[2][2] = { { "Nonbonded F kernel", "Nonbonded F+ene k." },
+                                        { "Nonbonded F+prune k.", "Nonbonded F+ene+prune k." } };
         tot_gpu += gpu_nbnxn_t->pl_h2d_t + gpu_nbnxn_t->nb_h2d_t + gpu_nbnxn_t->nb_d2h_t;
 
         /* add up the kernel timings */
@@ -938,15 +974,14 @@ void wallcycle_print(FILE *fplog, const gmx::MDLogger &mdlog, int nnodes, int np
         {
             tot_cpu_overlap += wc->wcc[ewcPMEMESH].c;
         }
-        tot_cpu_overlap *= realtime*1000/tot; /* convert s to ms */
+        tot_cpu_overlap *= realtime * 1000 / tot; /* convert s to ms */
 
         fprintf(fplog, "\n GPU timings\n%s\n", hline);
-        fprintf(fplog, " Computing:                         Count  Wall t (s)      ms/step       %c\n", '%');
+        fprintf(fplog,
+                " Computing:                         Count  Wall t (s)      ms/step       %c\n", '%');
         fprintf(fplog, "%s\n", hline);
-        print_gputimes(fplog, "Pair list H2D",
-                       gpu_nbnxn_t->pl_h2d_c, gpu_nbnxn_t->pl_h2d_t, tot_gpu);
-        print_gputimes(fplog, "X / q H2D",
-                       gpu_nbnxn_t->nb_c, gpu_nbnxn_t->nb_h2d_t, tot_gpu);
+        print_gputimes(fplog, "Pair list H2D", gpu_nbnxn_t->pl_h2d_c, gpu_nbnxn_t->pl_h2d_t, tot_gpu);
+        print_gputimes(fplog, "X / q H2D", gpu_nbnxn_t->nb_c, gpu_nbnxn_t->nb_h2d_t, tot_gpu);
 
         for (i = 0; i < 2; i++)
         {
@@ -954,8 +989,8 @@ void wallcycle_print(FILE *fplog, const gmx::MDLogger &mdlog, int nnodes, int np
             {
                 if (gpu_nbnxn_t->ktime[i][j].c)
                 {
-                    print_gputimes(fplog, k_log_str[i][j],
-                                   gpu_nbnxn_t->ktime[i][j].c, gpu_nbnxn_t->ktime[i][j].t, tot_gpu);
+                    print_gputimes(fplog, k_log_str[i][j], gpu_nbnxn_t->ktime[i][j].c,
+                                   gpu_nbnxn_t->ktime[i][j].t, tot_gpu);
                 }
             }
         }
@@ -965,18 +1000,17 @@ void wallcycle_print(FILE *fplog, const gmx::MDLogger &mdlog, int nnodes, int np
             {
                 if (gpu_pme_t->timing[k].c)
                 {
-                    print_gputimes(fplog, PMEStageNames[k],
-                                   gpu_pme_t->timing[k].c,
-                                   gpu_pme_t->timing[k].t,
-                                   tot_gpu);
+                    print_gputimes(fplog, PMEStageNames[k], gpu_pme_t->timing[k].c,
+                                   gpu_pme_t->timing[k].t, tot_gpu);
                 }
             }
         }
         if (gpu_nbnxn_t->pruneTime.c)
         {
-            print_gputimes(fplog, "Pruning kernel", gpu_nbnxn_t->pruneTime.c, gpu_nbnxn_t->pruneTime.t, tot_gpu);
+            print_gputimes(fplog, "Pruning kernel", gpu_nbnxn_t->pruneTime.c,
+                           gpu_nbnxn_t->pruneTime.t, tot_gpu);
         }
-        print_gputimes(fplog, "F D2H",  gpu_nbnxn_t->nb_c, gpu_nbnxn_t->nb_d2h_t, tot_gpu);
+        print_gputimes(fplog, "F D2H", gpu_nbnxn_t->nb_c, gpu_nbnxn_t->nb_d2h_t, tot_gpu);
         fprintf(fplog, "%s\n", hline);
         print_gputimes(fplog, "Total ", gpu_nbnxn_t->nb_c, tot_gpu, tot_gpu);
         fprintf(fplog, "%s\n", hline);
@@ -986,15 +1020,17 @@ void wallcycle_print(FILE *fplog, const gmx::MDLogger &mdlog, int nnodes, int np
              * and avoid adding it to tot_gpu as this is not in the force
              * overlap. We print the fraction as relative to the rest.
              */
-            print_gputimes(fplog, "*Dynamic pruning", gpu_nbnxn_t->dynamicPruneTime.c, gpu_nbnxn_t->dynamicPruneTime.t, tot_gpu);
+            print_gputimes(fplog, "*Dynamic pruning", gpu_nbnxn_t->dynamicPruneTime.c,
+                           gpu_nbnxn_t->dynamicPruneTime.t, tot_gpu);
             fprintf(fplog, "%s\n", hline);
         }
-        gpu_cpu_ratio = tot_gpu/tot_cpu_overlap;
+        gpu_cpu_ratio = tot_gpu / tot_cpu_overlap;
         if (gpu_nbnxn_t->nb_c > 0 && wc->wcc[ewcFORCE].n > 0)
         {
-            fprintf(fplog, "\nAverage per-step force GPU/CPU evaluation time ratio: %.3f ms/%.3f ms = %.3f\n",
-                    tot_gpu/gpu_nbnxn_t->nb_c, tot_cpu_overlap/wc->wcc[ewcFORCE].n,
-                    gpu_cpu_ratio);
+            fprintf(fplog,
+                    "\nAverage per-step force GPU/CPU evaluation time ratio: %.3f ms/%.3f ms = "
+                    "%.3f\n",
+                    tot_gpu / gpu_nbnxn_t->nb_c, tot_cpu_overlap / wc->wcc[ewcFORCE].n, gpu_cpu_ratio);
         }
 
         /* only print notes related to CPU-GPU load balance with PME */
@@ -1014,26 +1050,37 @@ void wallcycle_print(FILE *fplog, const gmx::MDLogger &mdlog, int nnodes, int np
                         /* The user could have used -notunepme,
                          * but we currently can't check that here.
                          */
-                        GMX_LOG(mdlog.warning).asParagraph().appendText(
-                                "NOTE: The CPU has >25% more load than the GPU. This imbalance wastes\n"
-                                "      GPU resources. Maybe the domain decomposition limits the PME tuning.\n"
-                                "      In that case, try setting the DD grid manually (-dd) or lowering -dds.");
+                        GMX_LOG(mdlog.warning)
+                                .asParagraph()
+                                .appendText(
+                                        "NOTE: The CPU has >25% more load than the GPU. This "
+                                        "imbalance wastes\n"
+                                        "      GPU resources. Maybe the domain decomposition "
+                                        "limits the PME tuning.\n"
+                                        "      In that case, try setting the DD grid manually "
+                                        "(-dd) or lowering -dds.");
                     }
                     else
                     {
                         /* We should not end up here, unless the box is
                          * too small for increasing the cut-off for PME tuning.
                          */
-                        GMX_LOG(mdlog.warning).asParagraph().appendText(
-                                "NOTE: The CPU has >25% more load than the GPU. This imbalance wastes\n"
-                                "      GPU resources.");
+                        GMX_LOG(mdlog.warning)
+                                .asParagraph()
+                                .appendText(
+                                        "NOTE: The CPU has >25% more load than the GPU. This "
+                                        "imbalance wastes\n"
+                                        "      GPU resources.");
                     }
                 }
                 if (gpu_cpu_ratio > 1.25)
                 {
-                    GMX_LOG(mdlog.warning).asParagraph().appendText(
-                            "NOTE: The GPU has >25% more load than the CPU. This imbalance wastes\n"
-                            "      CPU resources.");
+                    GMX_LOG(mdlog.warning)
+                            .asParagraph()
+                            .appendText(
+                                    "NOTE: The GPU has >25% more load than the CPU. This imbalance "
+                                    "wastes\n"
+                                    "      CPU resources.");
                 }
             }
         }
@@ -1041,40 +1088,48 @@ void wallcycle_print(FILE *fplog, const gmx::MDLogger &mdlog, int nnodes, int np
 
     if (wc->wc_barrier)
     {
-        GMX_LOG(mdlog.warning).asParagraph().appendText(
-                "MPI_Barrier was called before each cycle start/stop\n"
-                "call, so timings are not those of real runs.");
+        GMX_LOG(mdlog.warning)
+                .asParagraph()
+                .appendText(
+                        "MPI_Barrier was called before each cycle start/stop\n"
+                        "call, so timings are not those of real runs.");
     }
 
-    if (wc->wcc[ewcNB_XF_BUF_OPS].n > 0 &&
-        (cyc_sum[ewcDOMDEC] > tot*0.1 ||
-         cyc_sum[ewcNS] > tot*0.1))
+    if (wc->wcc[ewcNB_XF_BUF_OPS].n > 0 && (cyc_sum[ewcDOMDEC] > tot * 0.1 || cyc_sum[ewcNS] > tot * 0.1))
     {
         /* Only the sim master calls this function, so always print to stderr */
         if (wc->wcc[ewcDOMDEC].n == 0)
         {
-            GMX_LOG(mdlog.warning).asParagraph().appendTextFormatted(
-                    "NOTE: %d %% of the run time was spent in pair search,\n"
-                    "      you might want to increase nstlist (this has no effect on accuracy)\n",
-                    gmx::roundToInt(100*cyc_sum[ewcNS]/tot));
+            GMX_LOG(mdlog.warning)
+                    .asParagraph()
+                    .appendTextFormatted(
+                            "NOTE: %d %% of the run time was spent in pair search,\n"
+                            "      you might want to increase nstlist (this has no effect on "
+                            "accuracy)\n",
+                            gmx::roundToInt(100 * cyc_sum[ewcNS] / tot));
         }
         else
         {
-            GMX_LOG(mdlog.warning).asParagraph().appendTextFormatted(
-                    "NOTE: %d %% of the run time was spent in domain decomposition,\n"
-                    "      %d %% of the run time was spent in pair search,\n"
-                    "      you might want to increase nstlist (this has no effect on accuracy)\n",
-                    gmx::roundToInt(100*cyc_sum[ewcDOMDEC]/tot),
-                    gmx::roundToInt(100*cyc_sum[ewcNS]/tot));
+            GMX_LOG(mdlog.warning)
+                    .asParagraph()
+                    .appendTextFormatted(
+                            "NOTE: %d %% of the run time was spent in domain decomposition,\n"
+                            "      %d %% of the run time was spent in pair search,\n"
+                            "      you might want to increase nstlist (this has no effect on "
+                            "accuracy)\n",
+                            gmx::roundToInt(100 * cyc_sum[ewcDOMDEC] / tot),
+                            gmx::roundToInt(100 * cyc_sum[ewcNS] / tot));
         }
     }
 
-    if (cyc_sum[ewcMoveE] > tot*0.05)
+    if (cyc_sum[ewcMoveE] > tot * 0.05)
     {
-        GMX_LOG(mdlog.warning).asParagraph().appendTextFormatted(
-                "NOTE: %d %% of the run time was spent communicating energies,\n"
-                "      you might want to use the -gcom option of mdrun\n",
-                gmx::roundToInt(100*cyc_sum[ewcMoveE]/tot));
+        GMX_LOG(mdlog.warning)
+                .asParagraph()
+                .appendTextFormatted(
+                        "NOTE: %d %% of the run time was spent communicating energies,\n"
+                        "      you might want to increase some nst* mdp options\n",
+                        gmx::roundToInt(100 * cyc_sum[ewcMoveE] / tot));
     }
 }
 
