@@ -3,7 +3,7 @@
  *
  * Copyright (c) 1991-2000, University of Groningen, The Netherlands.
  * Copyright (c) 2001-2004, The GROMACS development team.
- * Copyright (c) 2013,2014,2015,2016,2017,2018,2019, by the GROMACS development team, led by
+ * Copyright (c) 2013,2014,2015,2016,2017,2018,2019,2020, by the GROMACS development team, led by
  * Mark Abraham, David van der Spoel, Berk Hess, and Erik Lindahl,
  * and including many others, as listed in the AUTHORS file in the
  * top-level source directory and at http://www.gromacs.org.
@@ -596,7 +596,7 @@ int gmx_trjcat(int argc, char* argv[])
             outFilesDemux.resize(nset);
             for (i = 0; (i < nset); i++)
             {
-                outFilesDemux[0] = gmx::formatString("%d_%s", i, name.c_str());
+                outFilesDemux[i] = gmx::formatString("%d_%s", i, name.c_str());
             }
         }
         do_demux(inFiles, outFilesDemux, n, val, t, dt_remd, isize, index, dt, oenv);
