@@ -3,7 +3,7 @@
  *
  * Copyright (c) 1991-2000, University of Groningen, The Netherlands.
  * Copyright (c) 2001-2004, The GROMACS development team.
- * Copyright (c) 2012,2014,2015,2016,2018, by the GROMACS development team, led by
+ * Copyright (c) 2012,2014,2015,2016,2018,2019, by the GROMACS development team, led by
  * Mark Abraham, David van der Spoel, Berk Hess, and Erik Lindahl,
  * and including many others, as listed in the AUTHORS file in the
  * top-level source directory and at http://www.gromacs.org.
@@ -90,34 +90,36 @@ constexpr unsigned int IF_LIMZERO    = 1 << 7;
 
 struct t_interaction_function // NOLINT (clang-analyzer-optin.performance.Padding)
 {
-    const char *name;         /* the name of this function			*/
-    const char *longname;     /* The name for printing etc.                   */
+    const char* name;         /* the name of this function			*/
+    const char* longname;     /* The name for printing etc.                   */
     int         nratoms;      /* nr of atoms needed for this function		*/
     int         nrfpA, nrfpB; /* number of parameters for this function.      */
                               /* this corresponds to the number of params in  */
                               /* iparams struct! (see idef.h)                 */
     /* A and B are for normal and free energy components respectively.    */
-    unsigned int    flags;    /* Flags (see above)                            */
+    unsigned int flags; /* Flags (see above)                            */
 };
 
 #define NRFPA(ftype) (interaction_function[(ftype)].nrfpA)
 #define NRFPB(ftype) (interaction_function[(ftype)].nrfpB)
-#define NRFP(ftype)  (NRFPA(ftype)+NRFPB(ftype))
+#define NRFP(ftype) (NRFPA(ftype) + NRFPB(ftype))
 #define NRAL(ftype) (interaction_function[(ftype)].nratoms)
 
-#define IS_CHEMBOND(ftype) (interaction_function[(ftype)].nratoms == 2 && (interaction_function[(ftype)].flags & IF_CHEMBOND))
+#define IS_CHEMBOND(ftype) \
+    (interaction_function[(ftype)].nratoms == 2 && (interaction_function[(ftype)].flags & IF_CHEMBOND))
 /* IS_CHEMBOND tells if function type ftype represents a chemical bond */
 
 /* IS_ANGLE tells if a function type ftype represents an angle
  * Per Larsson, 2007-11-06
  */
-#define IS_ANGLE(ftype) (interaction_function[(ftype)].nratoms == 3 && (interaction_function[(ftype)].flags & IF_ATYPE))
+#define IS_ANGLE(ftype) \
+    (interaction_function[(ftype)].nratoms == 3 && (interaction_function[(ftype)].flags & IF_ATYPE))
 #define IS_VSITE(ftype) (interaction_function[(ftype)].flags & IF_VSITE)
 
 #define IS_TABULATED(ftype) (interaction_function[(ftype)].flags & IF_TABULATED)
 
 /* this MUST correspond to the
-   t_interaction_function[F_NRE] in gmxlib/ifunc.c */
+   t_interaction_function[F_NRE] in gmxlib/ifunc.cpp */
 enum
 {
     F_BONDS,
@@ -186,6 +188,7 @@ enum
     F_CONSTRNC,
     F_SETTLE,
     F_VSITE2,
+    F_VSITE2FD,
     F_VSITE3,
     F_VSITE3FD,
     F_VSITE3FAD,
@@ -194,6 +197,7 @@ enum
     F_VSITE4FDN,
     F_VSITEN,
     F_COM_PULL,
+    F_DENSITYFITTING,
     F_EQM,
     F_EPOT,
     F_EKIN,
@@ -211,16 +215,14 @@ enum
     F_DVDL_BONDED,
     F_DVDL_RESTRAINT,
     F_DVDL_TEMPERATURE, /* not calculated for now, but should just be the energy (NVT) or enthalpy (NPT), or 0 (NVE) */
-    F_NRE               /* This number is for the total number of energies      */
+    F_NRE /* This number is for the total number of energies      */
 };
 
 static inline bool IS_RESTRAINT_TYPE(int ifunc)
 {
-    return
-        ifunc == F_POSRES || ifunc == F_FBPOSRES ||
-        ifunc == F_DISRES || ifunc == F_RESTRBONDS || ifunc == F_DISRESVIOL ||
-        ifunc == F_ORIRES || ifunc == F_ORIRESDEV ||
-        ifunc == F_ANGRES || ifunc == F_ANGRESZ || ifunc == F_DIHRES;
+    return ifunc == F_POSRES || ifunc == F_FBPOSRES || ifunc == F_DISRES || ifunc == F_RESTRBONDS
+           || ifunc == F_DISRESVIOL || ifunc == F_ORIRES || ifunc == F_ORIRESDEV
+           || ifunc == F_ANGRES || ifunc == F_ANGRESZ || ifunc == F_DIHRES;
 }
 
 /* Maximum allowed number of atoms, parameters and terms in interaction_function.
