@@ -3,7 +3,7 @@
  *
  * Copyright (c) 1991-2000, University of Groningen, The Netherlands.
  * Copyright (c) 2001-2004, The GROMACS development team.
- * Copyright (c) 2013,2014,2015,2016,2017,2018, by the GROMACS development team, led by
+ * Copyright (c) 2013,2014,2015,2016,2017,2018,2019, by the GROMACS development team, led by
  * Mark Abraham, David van der Spoel, Berk Hess, and Erik Lindahl,
  * and including many others, as listed in the AUTHORS file in the
  * top-level source directory and at http://www.gromacs.org.
@@ -52,7 +52,7 @@
 bool gmx_mpi_initialized()
 {
 #if !GMX_MPI
-    return 0;
+    return false;
 #else
     int n;
     MPI_Initialized(&n);
@@ -66,14 +66,14 @@ int gmx_node_num()
 #if !GMX_MPI
     return 1;
 #else
-#if GMX_THREAD_MPI
+#    if GMX_THREAD_MPI
     if (!gmx_mpi_initialized())
     {
         return 1;
     }
-#endif
+#    endif
     int i;
-    (void) MPI_Comm_size(MPI_COMM_WORLD, &i);
+    (void)MPI_Comm_size(MPI_COMM_WORLD, &i);
     return i;
 #endif
 }
@@ -83,14 +83,14 @@ int gmx_node_rank()
 #if !GMX_MPI
     return 0;
 #else
-#if GMX_THREAD_MPI
+#    if GMX_THREAD_MPI
     if (!gmx_mpi_initialized())
     {
         return 0;
     }
-#endif
+#    endif
     int i;
-    (void) MPI_Comm_rank(MPI_COMM_WORLD, &i);
+    (void)MPI_Comm_rank(MPI_COMM_WORLD, &i);
     return i;
 #endif
 }
@@ -149,7 +149,7 @@ int gmx_physicalnode_id_hash()
     return hash;
 }
 
-void gmx_broadcast_world(int size, void *buffer)
+void gmx_broadcast_world(int size, void* buffer)
 {
 #if GMX_MPI
     MPI_Bcast(buffer, size, MPI_BYTE, 0, MPI_COMM_WORLD);
