@@ -3,7 +3,7 @@
  *
  * Copyright (c) 1991-2000, University of Groningen, The Netherlands.
  * Copyright (c) 2001-2004, The GROMACS development team.
- * Copyright (c) 2013,2014,2015,2016,2017,2018, by the GROMACS development team, led by
+ * Copyright (c) 2013,2014,2015,2016,2017,2018,2019, by the GROMACS development team, led by
  * Mark Abraham, David van der Spoel, Berk Hess, and Erik Lindahl,
  * and including many others, as listed in the AUTHORS file in the
  * top-level source directory and at http://www.gromacs.org.
@@ -56,16 +56,16 @@
 //! Comment sign to use.
 #define COMMENTSIGN ';'
 
-int continuing(char *s)
+int continuing(char* s)
 {
     int sl;
     assert(s);
 
     rtrim(s);
     sl = strlen(s);
-    if ((sl > 0) && (s[sl-1] == CONTINUE))
+    if ((sl > 0) && (s[sl - 1] == CONTINUE))
     {
-        s[sl-1] = 0;
+        s[sl - 1] = 0;
         return TRUE;
     }
     else
@@ -75,10 +75,9 @@ int continuing(char *s)
 }
 
 
-
-char *fgets2(char *line, int n, FILE *stream)
+char* fgets2(char* line, int n, FILE* stream)
 {
-    char *c;
+    char* c;
     if (fgets(line, n, stream) == nullptr)
     {
         return nullptr;
@@ -95,7 +94,10 @@ char *fgets2(char *line, int n, FILE *stream)
          */
         if (!feof(stream))
         {
-            gmx_fatal(FARGS, "An input file contains a line longer than %d characters, while the buffer passed to fgets2 has size %d. The line starts with: '%20.20s'", n, n, line);
+            gmx_fatal(FARGS,
+                      "An input file contains a line longer than %d characters, while the buffer "
+                      "passed to fgets2 has size %d. The line starts with: '%20.20s'",
+                      n, n, line);
         }
     }
     if ((c = strchr(line, '\r')) != nullptr)
@@ -106,9 +108,9 @@ char *fgets2(char *line, int n, FILE *stream)
     return line;
 }
 
-void strip_comment (char *line)
+void strip_comment(char* line)
 {
-    char *c;
+    char* c;
 
     if (!line)
     {
@@ -122,7 +124,7 @@ void strip_comment (char *line)
     }
 }
 
-void upstring (char *str)
+void upstring(char* str)
 {
     int i;
 
@@ -132,9 +134,9 @@ void upstring (char *str)
     }
 }
 
-void ltrim (char *str)
+void ltrim(char* str)
 {
-    int   i, c;
+    int i, c;
 
     if (nullptr == str)
     {
@@ -150,13 +152,13 @@ void ltrim (char *str)
     {
         for (i = c; ('\0' != str[i]); i++)
         {
-            str[i-c] = str[i];
+            str[i - c] = str[i];
         }
-        str[i-c] = '\0';
+        str[i - c] = '\0';
     }
 }
 
-void rtrim (char *str)
+void rtrim(char* str)
 {
     int nul;
 
@@ -165,21 +167,21 @@ void rtrim (char *str)
         return;
     }
 
-    nul = strlen(str)-1;
-    while ((nul > 0) && ((str[nul] == ' ') || (str[nul] == '\t')) )
+    nul = strlen(str) - 1;
+    while ((nul > 0) && ((str[nul] == ' ') || (str[nul] == '\t')))
     {
         str[nul] = '\0';
         nul--;
     }
 }
 
-void trim (char *str)
+void trim(char* str)
 {
-    ltrim (str);
-    rtrim (str);
+    ltrim(str);
+    rtrim(str);
 }
 
-int gmx_strcasecmp_min(const char *str1, const char *str2)
+int gmx_strcasecmp_min(const char* str1, const char* str2)
 {
     char ch1, ch2;
 
@@ -188,53 +190,47 @@ int gmx_strcasecmp_min(const char *str1, const char *str2)
         do
         {
             ch1 = toupper(*(str1++));
-        }
-        while ((ch1 == '-') || (ch1 == '_'));
+        } while ((ch1 == '-') || (ch1 == '_'));
         do
         {
             ch2 = toupper(*(str2++));
-        }
-        while ((ch2 == '-') || (ch2 == '_'));
+        } while ((ch2 == '-') || (ch2 == '_'));
 
         if (ch1 != ch2)
         {
-            return (ch1-ch2);
+            return (ch1 - ch2);
         }
-    }
-    while (ch1 != 0);
+    } while (ch1 != 0);
     return 0;
 }
 
-int gmx_strncasecmp_min(const char *str1, const char *str2, int n)
+int gmx_strncasecmp_min(const char* str1, const char* str2, int n)
 {
     char  ch1, ch2;
     char *stri1, *stri2;
 
-    stri1 = const_cast<char *>(str1);
-    stri2 = const_cast<char *>(str2);
+    stri1 = const_cast<char*>(str1);
+    stri2 = const_cast<char*>(str2);
     do
     {
         do
         {
             ch1 = toupper(*(str1++));
-        }
-        while ((ch1 == '-') || (ch1 == '_'));
+        } while ((ch1 == '-') || (ch1 == '_'));
         do
         {
             ch2 = toupper(*(str2++));
-        }
-        while ((ch2 == '-') || (ch2 == '_'));
+        } while ((ch2 == '-') || (ch2 == '_'));
 
         if (ch1 != ch2)
         {
-            return (ch1-ch2);
+            return (ch1 - ch2);
         }
-    }
-    while ((ch1 != 0) && (str1-stri1 < n) && (str2-stri2 < n));
+    } while ((ch1 != 0) && (str1 - stri1 < n) && (str2 - stri2 < n));
     return 0;
 }
 
-int gmx_strcasecmp(const char *str1, const char *str2)
+int gmx_strcasecmp(const char* str1, const char* str2)
 {
     char ch1, ch2;
 
@@ -244,14 +240,13 @@ int gmx_strcasecmp(const char *str1, const char *str2)
         ch2 = toupper(*(str2++));
         if (ch1 != ch2)
         {
-            return (ch1-ch2);
+            return (ch1 - ch2);
         }
-    }
-    while (ch1 != 0);
+    } while (ch1 != 0);
     return 0;
 }
 
-int gmx_strncasecmp(const char *str1, const char *str2, int n)
+int gmx_strncasecmp(const char* str1, const char* str2, int n)
 {
     char ch1, ch2;
 
@@ -266,36 +261,35 @@ int gmx_strncasecmp(const char *str1, const char *str2, int n)
         ch2 = toupper(*(str2++));
         if (ch1 != ch2)
         {
-            return (ch1-ch2);
+            return (ch1 - ch2);
         }
         n--;
-    }
-    while ((ch1 != 0) && (n != 0));
+    } while ((ch1 != 0) && (n != 0));
     return 0;
 }
 
-char *gmx_strdup(const char *src)
+char* gmx_strdup(const char* src)
 {
-    char *dest;
+    char* dest;
 
-    snew(dest, strlen(src)+1);
-    strcpy(dest, src);
+    auto length = strlen(src) + 1;
+    snew(dest, length);
+    std::strncpy(dest, src, length);
 
     return dest;
 }
 
-char *
-gmx_strndup(const char *src, int n)
+char* gmx_strndup(const char* src, int n)
 {
     int   len;
-    char *dest;
+    char* dest;
 
     len = strlen(src);
     if (len > n)
     {
         len = n;
     }
-    snew(dest, len+1);
+    snew(dest, len + 1);
     strncpy(dest, src, len);
     dest[len] = 0;
     return dest;
@@ -304,12 +298,10 @@ gmx_strndup(const char *src, int n)
 /* Magic hash init number for Dan J. Bernsteins algorithm.
  * Do NOT use any other value unless you really know what you are doing.
  */
-const unsigned int
-    gmx_string_hash_init = 5381;
+const unsigned int gmx_string_hash_init = 5381;
 
 
-unsigned int
-gmx_string_fullhash_func(const char *s, unsigned int hash_init)
+unsigned int gmx_string_fullhash_func(const char* s, unsigned int hash_init)
 {
     int c;
 
@@ -320,8 +312,7 @@ gmx_string_fullhash_func(const char *s, unsigned int hash_init)
     return hash_init;
 }
 
-unsigned int
-gmx_string_hash_func(const char *s, unsigned int hash_init)
+unsigned int gmx_string_hash_func(const char* s, unsigned int hash_init)
 {
     int c;
 
@@ -329,14 +320,13 @@ gmx_string_hash_func(const char *s, unsigned int hash_init)
     {
         if (isalnum(c))
         {
-            hash_init = ((hash_init << 5) + hash_init) ^ c;            /* (hash * 33) xor c */
+            hash_init = ((hash_init << 5) + hash_init) ^ c; /* (hash * 33) xor c */
         }
     }
     return hash_init;
 }
 
-int
-gmx_wcmatch(const char *pattern, const char *str)
+int gmx_wcmatch(const char* pattern, const char* str)
 {
     while (*pattern)
     {
@@ -400,9 +390,9 @@ gmx_wcmatch(const char *pattern, const char *str)
     return (*str == 0) ? 0 : GMX_NO_WCMATCH;
 }
 
-char *wrap_lines(const char *buf, int line_width, int indent, gmx_bool bIndentFirst)
+char* wrap_lines(const char* buf, int line_width, int indent, gmx_bool bIndentFirst)
 {
-    char    *b2;
+    char*    b2;
     int      i, i0, i2, j, b2len, lspace = 0, l2space = 0;
     gmx_bool bFirst, bFitsOnLine;
 
@@ -419,7 +409,7 @@ char *wrap_lines(const char *buf, int line_width, int indent, gmx_bool bIndentFi
      */
 
     b2    = nullptr;
-    b2len = strlen(buf)+1+indent;
+    b2len = strlen(buf) + 1 + indent;
     snew(b2, b2len);
     i0 = i2 = 0;
     if (bIndentFirst)
@@ -434,19 +424,19 @@ char *wrap_lines(const char *buf, int line_width, int indent, gmx_bool bIndentFi
     {
         l2space = -1;
         /* find the last space before end of line */
-        for (i = i0; ((i-i0 < line_width) || (l2space == -1)) && (buf[i]); i++)
+        for (i = i0; ((i - i0 < line_width) || (l2space == -1)) && (buf[i]); i++)
         {
             b2[i2++] = buf[i];
             /* remember the position of a space */
             if (buf[i] == ' ')
             {
                 lspace  = i;
-                l2space = i2-1;
+                l2space = i2 - 1;
             }
             /* if we have a newline before the line is full, reset counters */
-            if (buf[i] == '\n' && buf[i+1])
+            if (buf[i] == '\n' && buf[i + 1])
             {
-                i0     = i+1;
+                i0 = i + 1;
                 b2len += indent;
                 srenew(b2, b2len);
                 /* add indentation after the newline */
@@ -457,7 +447,7 @@ char *wrap_lines(const char *buf, int line_width, int indent, gmx_bool bIndentFi
             }
         }
         /* If we are at the last newline, copy it */
-        if (buf[i] == '\n' && !buf[i+1])
+        if (buf[i] == '\n' && !buf[i + 1])
         {
             b2[i2++] = buf[i++];
         }
@@ -465,12 +455,12 @@ char *wrap_lines(const char *buf, int line_width, int indent, gmx_bool bIndentFi
         if (buf[i])
         {
             /* check if one word does not fit on the line */
-            bFitsOnLine = (i-i0 <= line_width);
+            bFitsOnLine = (i - i0 <= line_width);
             /* reset line counters to just after the space */
-            i0 = lspace+1;
-            i2 = l2space+1;
+            i0 = lspace + 1;
+            i2 = l2space + 1;
             /* if the words fit on the line, and we're beyond the indentation part */
-            if ( (bFitsOnLine) && (l2space >= indent) )
+            if ((bFitsOnLine) && (l2space >= indent))
             {
                 /* start a new line */
                 b2[l2space] = '\n';
@@ -480,7 +470,7 @@ char *wrap_lines(const char *buf, int line_width, int indent, gmx_bool bIndentFi
                     if (bFirst)
                     {
                         line_width -= indent;
-                        bFirst      = FALSE;
+                        bFirst = FALSE;
                     }
                     b2len += indent;
                     srenew(b2, b2len);
@@ -496,15 +486,13 @@ char *wrap_lines(const char *buf, int line_width, int indent, gmx_bool bIndentFi
                 }
             }
         }
-    }
-    while (buf[i] != 0);
+    } while (buf[i] != 0);
     b2[i2] = '\0';
 
     return b2;
 }
 
-int64_t
-str_to_int64_t(const char *str, char **endptr)
+int64_t str_to_int64_t(const char* str, char** endptr)
 {
 #ifndef _MSC_VER
     return strtoll(str, endptr, 10);
@@ -513,7 +501,7 @@ str_to_int64_t(const char *str, char **endptr)
 #endif
 }
 
-char *gmx_step_str(int64_t i, char *buf)
+char* gmx_step_str(int64_t i, char* buf)
 {
     sprintf(buf, "%" PRId64, i);
     return buf;
