@@ -1,7 +1,7 @@
 /*
  * This file is part of the GROMACS molecular simulation package.
  *
- * Copyright (c) 2010,2011,2012,2013,2014, by the GROMACS development team, led by
+ * Copyright (c) 2010,2011,2012,2013,2014,2019, by the GROMACS development team, led by
  * Mark Abraham, David van der Spoel, Berk Hess, and Erik Lindahl,
  * and including many others, as listed in the AUTHORS file in the
  * top-level source directory and at http://www.gromacs.org.
@@ -47,10 +47,9 @@
 
 #include "legacymodules.h"
 
-int
-main(int argc, char *argv[])
+int main(int argc, char* argv[])
 {
-    gmx::CommandLineProgramContext &context = gmx::initForCommandLine(&argc, &argv);
+    gmx::CommandLineProgramContext& context = gmx::initForCommandLine(&argc, &argv);
     try
     {
         gmx::CommandLineModuleManager manager("gmx", &context);
@@ -61,7 +60,7 @@ main(int argc, char *argv[])
         gmx::finalizeForCommandLine();
         return rc;
     }
-    catch (const std::exception &ex)
+    catch (const std::exception& ex)
     {
         gmx::printFatalErrorMessage(stderr, ex);
         return gmx::processExceptionAtExitForCommandLine(ex);
