@@ -1,7 +1,7 @@
 /*
  * This file is part of the GROMACS molecular simulation package.
  *
- * Copyright (c) 2018, by the GROMACS development team, led by
+ * Copyright (c) 2018,2019, by the GROMACS development team, led by
  * Mark Abraham, David van der Spoel, Berk Hess, and Erik Lindahl,
  * and including many others, as listed in the AUTHORS file in the
  * top-level source directory and at http://www.gromacs.org.
@@ -47,6 +47,7 @@
 #include <gtest/gtest.h>
 #include <gtest/gtest-spi.h>
 
+#include "gromacs/topology/ifunc.h"
 #include "gromacs/trajectory/energyframe.h"
 #include "gromacs/utility/basenetwork.h"
 #include "gromacs/utility/strconvert.h"
@@ -63,20 +64,47 @@ namespace gmx
 namespace test
 {
 
-void compareEnergyFrames(const EnergyFrame      &reference,
-                         const EnergyFrame      &test,
-                         const EnergyTolerances &tolerances)
+const EnergyTermsToCompare EnergyComparison::s_defaultEnergyTermsToCompare = {
+    { interaction_function[F_EPOT].longname, relativeToleranceAsUlp(10.0, 50) },
+    { interaction_function[F_EKIN].longname, relativeToleranceAsUlp(10.0, 50) },
+    // The pressure is very strongly affected by summation errors,
+    // so we need a large tolerance.
+    // The value of 15000 is calibrated for running a small water box for 16 steps.
+    // For a single frame for a water box a value of 150 could work.
+    { interaction_function[F_PRES].longname, relativeToleranceAsUlp(10.0, 15000) },
+};
+
+EnergyComparison::EnergyComparison(const EnergyTermsToCompare& energyTermsToCompare) :
+    energyTermsToCompare_(energyTermsToCompare)
 {
+}
+
+std::vector<std::string> EnergyComparison::getEnergyNames() const
+{
+    std::vector<std::string> keys;
+    keys.reserve(energyTermsToCompare_.size());
+    for (const auto& it : energyTermsToCompare_)
+    {
+        keys.push_back(it.first);
+    }
+    return keys;
+}
+
+void EnergyComparison::operator()(const EnergyFrame& reference, const EnergyFrame& test) const
+{
+    SCOPED_TRACE("Comparing energy reference frame " + reference.frameName() + " and test frame "
+                 + test.frameName());
     for (auto referenceIt = reference.begin(); referenceIt != reference.end(); ++referenceIt)
     {
-        auto &energyName = referenceIt->first;
-        SCOPED_TRACE("Comparing " +  energyName + " between frames");
-        auto  testIt = test.find(energyName);
+        auto& energyName = referenceIt->first;
+        SCOPED_TRACE("Comparing " + energyName + " between frames");
+        auto testIt = test.find(energyName);
         if (testIt != test.end())
         {
-            auto &energyValueInReference = referenceIt->second;
-            auto &energyValueInTest      = testIt->second;
-            EXPECT_REAL_EQ_TOL(energyValueInReference, energyValueInTest, tolerances.at(energyName));
+            auto& energyValueInReference = referenceIt->second;
+            auto& energyValueInTest      = testIt->second;
+            EXPECT_REAL_EQ_TOL(energyValueInReference, energyValueInTest,
+                               energyTermsToCompare_.at(energyName));
         }
         else
         {
@@ -85,25 +113,23 @@ void compareEnergyFrames(const EnergyFrame      &reference,
     }
 }
 
-void
-checkEnergiesAgainstReferenceData(const std::string      &energyFilename,
-                                  const EnergyTolerances &energiesToMatch,
-                                  TestReferenceChecker   *checker)
+void checkEnergiesAgainstReferenceData(const std::string&          energyFilename,
+                                       const EnergyTermsToCompare& energyTermsToCompare,
+                                       TestReferenceChecker*       checker)
 {
     const bool thisRankChecks = (gmx_node_rank() == 0);
 
     if (thisRankChecks)
     {
-        auto namesOfEnergiesToMatch = getKeys(energiesToMatch);
-        auto energyReader           = openEnergyFileToReadFields(energyFilename,
-                                                                 namesOfEnergiesToMatch);
+        EnergyComparison energyComparison(energyTermsToCompare);
+        auto energyReader = openEnergyFileToReadTerms(energyFilename, energyComparison.getEnergyNames());
 
         std::unordered_map<std::string, TestReferenceChecker> checkers;
-        for (const auto &energyToMatch : energiesToMatch)
+        for (const auto& energyTermToCompare : energyTermsToCompare)
         {
-            const auto &energyName = energyToMatch.first;
-            checkers[energyName] = checker->checkCompound("Energy", energyName.c_str());
-            const auto &energyTolerance = energyToMatch.second;
+            const auto& energyName      = energyTermToCompare.first;
+            checkers[energyName]        = checker->checkCompound("Energy", energyName.c_str());
+            const auto& energyTolerance = energyTermToCompare.second;
             checkers[energyName].setDefaultTolerance(energyTolerance);
         }
 
@@ -115,15 +141,15 @@ checkEnergiesAgainstReferenceData(const std::string      &energyFilename,
         int frameNumber = 0;
         while (energyReader->readNextFrame())
         {
-            const EnergyFrame &frame     = energyReader->frame();
+            const EnergyFrame& frame     = energyReader->frame();
             const std::string  frameName = frame.frameName() + " in frame " + toString(frameNumber);
 
-            for (const auto &energyToMatch : energiesToMatch)
+            for (const auto& energyTermToCompare : energyTermsToCompare)
             {
-                const std::string &energyName  = energyToMatch.first;
+                const std::string& energyName  = energyTermToCompare.first;
                 const real         energyValue = frame.at(energyName);
 
-                SCOPED_TRACE("Comparing " +  energyName + " in " + frameName);
+                SCOPED_TRACE("Comparing " + energyName + " in " + frameName);
                 checkers[energyName].checkReal(energyValue, frameName.c_str());
             }
             ++frameNumber;
@@ -135,5 +161,5 @@ checkEnergiesAgainstReferenceData(const std::string      &energyFilename,
     }
 }
 
-}  // namespace test
-}  // namespace gmx
+} // namespace test
+} // namespace gmx
