@@ -1,7 +1,7 @@
 /*
  * This file is part of the GROMACS molecular simulation package.
  *
- * Copyright (c) 2013,2014,2015,2016,2018, by the GROMACS development team, led by
+ * Copyright (c) 2013,2014,2015,2016,2018,2019, by the GROMACS development team, led by
  * Mark Abraham, David van der Spoel, Berk Hess, and Erik Lindahl,
  * and including many others, as listed in the AUTHORS file in the
  * top-level source directory and at http://www.gromacs.org.
@@ -51,20 +51,15 @@ namespace test
 
 class SwapTestFixture : public MdrunTestFixture
 {
-    protected:
-        SwapTestFixture();
-        ~SwapTestFixture() override;
+protected:
+    SwapTestFixture();
+    ~SwapTestFixture() override;
 };
 
 
-SwapTestFixture::SwapTestFixture()
-{
-}
-
-SwapTestFixture::~SwapTestFixture()
-{
-}
+SwapTestFixture::SwapTestFixture() {}
 
+SwapTestFixture::~SwapTestFixture() {}
 
 
 //! Test fixture for mdrun with "Computational Electrophysiology" settings,
@@ -80,7 +75,6 @@ TEST_F(CompelTest, SwapCanRun)
     const std::string mdpContents = R"(
         dt                       = 0.005
         nsteps                   = 2
-        define                   = -DPOSRES
         tcoupl                   = Berendsen
         tc-grps                  = System
         tau-t                    = 0.5
@@ -135,7 +129,6 @@ TEST_F(CompelTest, SwapCanRun)
 }
 
 
-
 /*! \todo Add other tests for the compel module, e.g.
  *
  *  - a test that checks that actually ion/water swaps have been done, by
