@@ -1,7 +1,7 @@
 /*
  * This file is part of the GROMACS molecular simulation package.
  *
- * Copyright (c) 2012,2013,2014,2015,2016,2017,2018, by the GROMACS development team, led by
+ * Copyright (c) 2012,2013,2014,2015,2016,2017,2018,2019, by the GROMACS development team, led by
  * Mark Abraham, David van der Spoel, Berk Hess, and Erik Lindahl,
  * and including many others, as listed in the AUTHORS file in the
  * top-level source directory and at http://www.gromacs.org.
@@ -67,8 +67,12 @@ namespace test
  *
  * \ingroup module_testutils
  */
-void initTestUtils(const char *dataPath, const char *tempPath, bool usesMpi,
-                   bool usesHardwareDetection, int *argc, char ***argv);
+void initTestUtils(const char* dataPath,
+                   const char* tempPath,
+                   bool        usesMpi,
+                   bool        usesHardwareDetection,
+                   int*        argc,
+                   char***     argv);
 
 /*! \internal
  * \brief
