@@ -1,7 +1,7 @@
 /*
  * This file is part of the GROMACS molecular simulation package.
  *
- * Copyright (c) 2011,2012,2013,2014,2015,2016,2017, by the GROMACS development team, led by
+ * Copyright (c) 2011,2012,2013,2014,2015,2016,2017,2019, by the GROMACS development team, led by
  * Mark Abraham, David van der Spoel, Berk Hess, and Erik Lindahl,
  * and including many others, as listed in the AUTHORS file in the
  * top-level source directory and at http://www.gromacs.org.
@@ -49,9 +49,9 @@
 #include <gtest/gtest.h>
 #include <gtest/gtest-spi.h>
 
+#include "gromacs/utility/any.h"
 #include "gromacs/utility/keyvaluetree.h"
 #include "gromacs/utility/keyvaluetreebuilder.h"
-#include "gromacs/utility/variant.h"
 
 #include "testutils/testasserts.h"
 #include "testutils/testexceptions.h"
@@ -59,8 +59,8 @@
 namespace
 {
 
-using gmx::test::TestReferenceData;
 using gmx::test::TestReferenceChecker;
+using gmx::test::TestReferenceData;
 
 TEST(ReferenceDataTest, HandlesSimpleData)
 {
@@ -69,8 +69,10 @@ TEST(ReferenceDataTest, HandlesSimpleData)
         TestReferenceChecker checker(data.rootChecker());
         checker.checkBoolean(true, "bool");
         checker.checkInteger(1, "int");
-        checker.checkInt64(1ULL<<42, "int64");
-        checker.checkUInt64(1ULL<<42, "uint64");
+        checker.checkInt32(1ULL << 12, "int32");
+        checker.checkUInt32(1ULL << 12, "uint32");
+        checker.checkInt64(1ULL << 42, "int64");
+        checker.checkUInt64(1ULL << 42, "uint64");
         checker.checkDouble(0.5, "real");
         checker.checkString("Test", "string");
     }
@@ -79,8 +81,10 @@ TEST(ReferenceDataTest, HandlesSimpleData)
         TestReferenceChecker checker(data.rootChecker());
         checker.checkBoolean(true, "bool");
         checker.checkInteger(1, "int");
-        checker.checkInt64(1ULL<<42, "int64");
-        checker.checkUInt64(1ULL<<42, "uint64");
+        checker.checkInt32(1ULL << 12, "int32");
+        checker.checkUInt32(1ULL << 12, "uint32");
+        checker.checkInt64(1ULL << 42, "int64");
+        checker.checkUInt64(1ULL << 42, "uint64");
         checker.checkDouble(0.5, "real");
         checker.checkString("Test", "string");
     }
@@ -88,8 +92,8 @@ TEST(ReferenceDataTest, HandlesSimpleData)
 
 TEST(ReferenceDataTest, HandlesFloatingPointData)
 {
-    const float  floatValue  = 4.0f/3.0f;
-    const double doubleValue = 4.0/3.0;
+    const float  floatValue  = 4.0F / 3.0F;
+    const double doubleValue = 4.0 / 3.0;
 
     {
         TestReferenceData    data(gmx::test::erefdataUpdateAll);
@@ -121,7 +125,7 @@ TEST(ReferenceDataTest, HandlesPresenceChecks)
         TestReferenceData    data(gmx::test::erefdataCompare);
         TestReferenceChecker checker(data.rootChecker());
         // Assigned to avoid warnings about potentially uninitialized value.
-        bool                 bRet = true;
+        bool bRet = true;
         EXPECT_TRUE(checker.checkPresent(true, "present"));
         checker.checkInteger(1, "present");
         EXPECT_NONFATAL_FAILURE(bRet = checker.checkPresent(false, "present"), "");
@@ -154,7 +158,7 @@ TEST(ReferenceDataTest, HandlesStringBlockData)
 TEST(ReferenceDataTest, HandlesVectorData)
 {
     int    veci[3] = { -1, 3, 5 };
-    float  vecf[3] = { -2.3f, 1.43f, 2.5f };
+    float  vecf[3] = { -2.3F, 1.43F, 2.5F };
     double vecd[3] = { -2.3, 1.43, 2.5 };
 
     {
@@ -193,14 +197,14 @@ TEST(ReferenceDataTest, HandlesSequenceData)
 //! Helper typedef
 typedef double dvec[3];
 //! Helper function for HandlesSequenceOfCustomData
-void checkCustomVector(TestReferenceChecker *checker, const dvec &value)
+void checkCustomVector(TestReferenceChecker* checker, const dvec& value)
 {
     checker->checkVector(value, nullptr);
 }
 
 TEST(ReferenceDataTest, HandlesSequenceOfCustomData)
 {
-    const dvec seq[] = { {-3, 4, 5}, {-2.3, 5, 0} };
+    const dvec seq[] = { { -3, 4, 5 }, { -2.3, 5, 0 } };
 
     {
         TestReferenceData    data(gmx::test::erefdataUpdateAll);
@@ -344,24 +348,24 @@ TEST(ReferenceDataTest, HandlesUncheckedDataInCompound)
 }
 
 
-TEST(ReferenceDataTest, HandlesVariants)
+TEST(ReferenceDataTest, HandlesAnys)
 {
-    using gmx::Variant;
+    using gmx::Any;
     {
         TestReferenceData    data(gmx::test::erefdataUpdateAll);
         TestReferenceChecker checker(data.rootChecker());
-        checker.checkVariant(Variant::create<bool>(true), "bool");
-        checker.checkVariant(Variant::create<int>(1), "int");
-        checker.checkVariant(Variant::create<double>(3.5), "real");
-        checker.checkVariant(Variant::create<std::string>("foo"), "str");
+        checker.checkAny(Any::create<bool>(true), "bool");
+        checker.checkAny(Any::create<int>(1), "int");
+        checker.checkAny(Any::create<double>(3.5), "real");
+        checker.checkAny(Any::create<std::string>("foo"), "str");
     }
     {
         TestReferenceData    data(gmx::test::erefdataCompare);
         TestReferenceChecker checker(data.rootChecker());
-        checker.checkVariant(Variant::create<bool>(true), "bool");
-        checker.checkVariant(Variant::create<int>(1), "int");
-        checker.checkVariant(Variant::create<double>(3.5), "real");
-        checker.checkVariant(Variant::create<std::string>("foo"), "str");
+        checker.checkAny(Any::create<bool>(true), "bool");
+        checker.checkAny(Any::create<int>(1), "int");
+        checker.checkAny(Any::create<double>(3.5), "real");
+        checker.checkAny(Any::create<std::string>("foo"), "str");
     }
 }
 
@@ -376,7 +380,7 @@ gmx::KeyValueTreeObject buildKeyValueTree(bool full)
     {
         obj.addValue<std::string>("s", "x");
     }
-    auto arr  = root.addUniformArray<int>("a");
+    auto arr = root.addUniformArray<int>("a");
     arr.addValue(2);
     arr.addValue(3);
     root.addValue<std::string>("s", "y");
@@ -410,7 +414,8 @@ TEST(ReferenceDataTest, HandlesKeyValueTreeExtraKey)
     {
         TestReferenceData    data(gmx::test::erefdataCompare);
         TestReferenceChecker checker(data.rootChecker());
-        EXPECT_NONFATAL_FAILURE(checker.checkKeyValueTreeObject(buildKeyValueTree(true), "tree"), "");
+        EXPECT_NONFATAL_FAILURE(checker.checkKeyValueTreeObject(buildKeyValueTree(true), "tree"),
+                                "");
     }
 }
 
@@ -425,49 +430,50 @@ TEST(ReferenceDataTest, HandlesKeyValueTreeMissingKey)
     {
         TestReferenceData    data(gmx::test::erefdataCompare);
         TestReferenceChecker checker(data.rootChecker());
-        EXPECT_NONFATAL_FAILURE(checker.checkKeyValueTreeObject(buildKeyValueTree(false), "tree"), "");
+        EXPECT_NONFATAL_FAILURE(checker.checkKeyValueTreeObject(buildKeyValueTree(false), "tree"),
+                                "");
     }
 }
 
 
-TEST(ReferenceDataTest, HandlesVariantsWithIncorrectValue)
+TEST(ReferenceDataTest, HandlesAnysWithIncorrectValue)
 {
-    using gmx::Variant;
+    using gmx::Any;
     {
         TestReferenceData    data(gmx::test::erefdataUpdateAll);
         TestReferenceChecker checker(data.rootChecker());
-        checker.checkVariant(Variant::create<bool>(true), "bool");
-        checker.checkVariant(Variant::create<int>(1), "int");
-        checker.checkVariant(Variant::create<double>(3.5), "real");
-        checker.checkVariant(Variant::create<std::string>("foo"), "str");
+        checker.checkAny(Any::create<bool>(true), "bool");
+        checker.checkAny(Any::create<int>(1), "int");
+        checker.checkAny(Any::create<double>(3.5), "real");
+        checker.checkAny(Any::create<std::string>("foo"), "str");
     }
     {
         TestReferenceData    data(gmx::test::erefdataCompare);
         TestReferenceChecker checker(data.rootChecker());
-        EXPECT_NONFATAL_FAILURE(checker.checkVariant(Variant::create<bool>(false), "bool"), "");
-        EXPECT_NONFATAL_FAILURE(checker.checkVariant(Variant::create<int>(2), "int"), "");
-        EXPECT_NONFATAL_FAILURE(checker.checkVariant(Variant::create<double>(2.5), "real"), "");
-        EXPECT_NONFATAL_FAILURE(checker.checkVariant(Variant::create<std::string>("bar"), "str"), "");
+        EXPECT_NONFATAL_FAILURE(checker.checkAny(Any::create<bool>(false), "bool"), "");
+        EXPECT_NONFATAL_FAILURE(checker.checkAny(Any::create<int>(2), "int"), "");
+        EXPECT_NONFATAL_FAILURE(checker.checkAny(Any::create<double>(2.5), "real"), "");
+        EXPECT_NONFATAL_FAILURE(checker.checkAny(Any::create<std::string>("bar"), "str"), "");
     }
 }
 
 
-TEST(ReferenceDataTest, HandlesVariantsWithIncorrectType)
+TEST(ReferenceDataTest, HandlesAnysWithIncorrectType)
 {
-    using gmx::Variant;
+    using gmx::Any;
     {
         TestReferenceData    data(gmx::test::erefdataUpdateAll);
         TestReferenceChecker checker(data.rootChecker());
-        checker.checkVariant(Variant::create<bool>(true), "bool");
-        checker.checkVariant(Variant::create<int>(1), "int");
-        checker.checkVariant(Variant::create<double>(3.5), "real");
+        checker.checkAny(Any::create<bool>(true), "bool");
+        checker.checkAny(Any::create<int>(1), "int");
+        checker.checkAny(Any::create<double>(3.5), "real");
     }
     {
         TestReferenceData    data(gmx::test::erefdataCompare);
         TestReferenceChecker checker(data.rootChecker());
-        EXPECT_NONFATAL_FAILURE(checker.checkVariant(Variant::create<int>(1), "bool"), "");
-        EXPECT_NONFATAL_FAILURE(checker.checkVariant(Variant::create<bool>(true), "int"), "");
-        EXPECT_NONFATAL_FAILURE(checker.checkVariant(Variant::create<int>(2), "real"), "");
+        EXPECT_NONFATAL_FAILURE(checker.checkAny(Any::create<int>(1), "bool"), "");
+        EXPECT_NONFATAL_FAILURE(checker.checkAny(Any::create<bool>(true), "int"), "");
+        EXPECT_NONFATAL_FAILURE(checker.checkAny(Any::create<int>(2), "real"), "");
     }
 }
 
@@ -476,14 +482,16 @@ TEST(ReferenceDataTest, HandlesMissingReferenceDataFile)
 {
     const int seq[5] = { -1, 3, 5, 2, 4 };
 
-    EXPECT_NONFATAL_FAILURE({
-                                TestReferenceData data(gmx::test::erefdataCompare);
-                                TestReferenceChecker checker(data.rootChecker());
-                                checker.checkInteger(1, "int");
-                                checker.checkDouble(0.5, "real");
-                                checker.checkString("Test", "string");
-                                checker.checkSequenceArray(5, seq, "seq");
-                            }, "");
+    EXPECT_NONFATAL_FAILURE(
+            {
+                TestReferenceData    data(gmx::test::erefdataCompare);
+                TestReferenceChecker checker(data.rootChecker());
+                checker.checkInteger(1, "int");
+                checker.checkDouble(0.5, "real");
+                checker.checkString("Test", "string");
+                checker.checkSequenceArray(5, seq, "seq");
+            },
+            "");
 }
 
 
@@ -508,11 +516,12 @@ TEST(ReferenceDataTest, HandlesSpecialCharactersInStrings)
 
 TEST(ReferenceDataTest, HandlesStringsWithTextAndWhitespace)
 {
-    const char *strings[] = { "  test", "test  ", "  test  ", "the test", "\ntest", "\n\ntest", "test\n", "test\n\n" };
+    const char* strings[] = { "  test", "test  ",   "  test  ", "the test",
+                              "\ntest", "\n\ntest", "test\n",   "test\n\n" };
     {
         TestReferenceData    data(gmx::test::erefdataUpdateAll);
         TestReferenceChecker checker(data.rootChecker());
-        for (const auto &s : strings)
+        for (const auto& s : strings)
         {
             checker.checkString(s, nullptr);
             checker.checkTextBlock(s, nullptr);
@@ -521,7 +530,7 @@ TEST(ReferenceDataTest, HandlesStringsWithTextAndWhitespace)
     {
         TestReferenceData    data(gmx::test::erefdataCompare);
         TestReferenceChecker checker(data.rootChecker());
-        for (const auto &s : strings)
+        for (const auto& s : strings)
         {
             checker.checkString(s, nullptr);
             checker.checkTextBlock(s, nullptr);
