@@ -1,7 +1,7 @@
 /*
  * This file is part of the GROMACS molecular simulation package.
  *
- * Copyright (c) 2015,2016, by the GROMACS development team, led by
+ * Copyright (c) 2015,2016,2019, by the GROMACS development team, led by
  * Mark Abraham, David van der Spoel, Berk Hess, and Erik Lindahl,
  * and including many others, as listed in the AUTHORS file in the
  * top-level source directory and at http://www.gromacs.org.
@@ -61,14 +61,9 @@ using gmx::test::checkXvgFile;
 using gmx::test::XvgMatchSettings;
 
 //! Input testing data - an inline xvg file.
-const char * const input[] = {
-    "0     2905.86    -410.199",
-    "0.2     6656.67    -430.437",
-    "0.4     5262.44    -409.399",
-    "0.6     5994.69    -405.763",
-    "0.8     5941.37    -408.337",
-    "1     5869.87    -411.124"
-};
+const char* const input[] = { "0     2905.86    -410.199",   "0.2     6656.67    -430.437",
+                              "0.4     5262.44    -409.399", "0.6     5994.69    -405.763",
+                              "0.8     5941.37    -408.337", "1     5869.87    -411.124" };
 
 TEST(XvgTests, CreateFile)
 {
@@ -77,7 +72,7 @@ TEST(XvgTests, CreateFile)
         gmx::test::TestReferenceData    data(gmx::test::erefdataUpdateAll);
         gmx::test::TestReferenceChecker checker(data.rootChecker());
         // Convert char array to a stream and add it to the checker
-        gmx::StringInputStream          sis(input);
+        gmx::StringInputStream sis(input);
         checkXvgFile(&sis, &checker, XvgMatchSettings());
     }
     {
@@ -85,7 +80,7 @@ TEST(XvgTests, CreateFile)
         gmx::test::TestReferenceData    data(gmx::test::erefdataCompare);
         gmx::test::TestReferenceChecker checker(data.rootChecker());
         // Convert char array to a stream and add it to the checker
-        gmx::StringInputStream          sis(input);
+        gmx::StringInputStream sis(input);
         checkXvgFile(&sis, &checker, XvgMatchSettings());
     }
 }
@@ -97,20 +92,18 @@ TEST(XvgTests, CheckMissing)
         gmx::test::TestReferenceData    data(gmx::test::erefdataUpdateAll);
         gmx::test::TestReferenceChecker checker(data.rootChecker());
         // Convert char array to a stream and add it to the checker
-        gmx::StringInputStream          sis(input);
+        gmx::StringInputStream sis(input);
         checkXvgFile(&sis, &checker, XvgMatchSettings());
     }
     {
-        const char * const              input[] = {
-            "0     2905.86    -410.199",
-            "0.2     6656.67    -430.437",
-            "0.4     5262.44    -409.399"
-        };
+        const char* const input[] = { "0     2905.86    -410.199", "0.2     6656.67    -430.437",
+                                      "0.4     5262.44    -409.399" };
         // Now check with missing data
         gmx::test::TestReferenceData    data(gmx::test::erefdataCompare);
         gmx::test::TestReferenceChecker checker(data.rootChecker());
         gmx::StringInputStream          sis(input);
-        EXPECT_NONFATAL_FAILURE(checkXvgFile(&sis, &checker, XvgMatchSettings()), "not used in test");
+        EXPECT_NONFATAL_FAILURE(checkXvgFile(&sis, &checker, XvgMatchSettings()),
+                                "not used in test");
     }
 }
 
@@ -121,19 +114,14 @@ TEST(XvgTests, CheckExtra)
         gmx::test::TestReferenceData    data(gmx::test::erefdataUpdateAll);
         gmx::test::TestReferenceChecker checker(data.rootChecker());
         // Convert char array to a stream and add it to the checker
-        gmx::StringInputStream          sis(input);
+        gmx::StringInputStream sis(input);
         checkXvgFile(&sis, &checker, XvgMatchSettings());
     }
     {
-        const char * const              input[] = {
-            "0     2905.86    -410.199",
-            "0.2     6656.67    -430.437",
-            "0.4     5262.44    -409.399",
-            "0.6     5994.69    -405.763",
-            "0.8     5941.37    -408.337",
-            "1     5869.87    -411.124",
-            "1.2     5889.87    -413.124"
-        };
+        const char* const input[] = { "0     2905.86    -410.199",   "0.2     6656.67    -430.437",
+                                      "0.4     5262.44    -409.399", "0.6     5994.69    -405.763",
+                                      "0.8     5941.37    -408.337", "1     5869.87    -411.124",
+                                      "1.2     5889.87    -413.124" };
         // Now check with missing data
         gmx::test::TestReferenceData    data(gmx::test::erefdataCompare);
         gmx::test::TestReferenceChecker checker(data.rootChecker());
@@ -149,18 +137,13 @@ TEST(XvgTests, ReadIncorrect)
         gmx::test::TestReferenceData    data(gmx::test::erefdataUpdateAll);
         gmx::test::TestReferenceChecker checker(data.rootChecker());
         // Convert char array to a stream and add it to the checker
-        gmx::StringInputStream          sis(input);
+        gmx::StringInputStream sis(input);
         checkXvgFile(&sis, &checker, XvgMatchSettings());
     }
     {
-        const char * const              input[] = {
-            "0     2905.86    -410.199",
-            "0.2     6656.67    -430.437",
-            "0.4     5262.44    -409.399",
-            "0.6     5994.69    -405.763",
-            "0.8     5941.37    -408.337",
-            "1     5869.87    -421.124"
-        };
+        const char* const input[] = { "0     2905.86    -410.199",   "0.2     6656.67    -430.437",
+                                      "0.4     5262.44    -409.399", "0.6     5994.69    -405.763",
+                                      "0.8     5941.37    -408.337", "1     5869.87    -421.124" };
         // Now check with incorrect data
         gmx::test::TestReferenceData    data(gmx::test::erefdataCompare);
         gmx::test::TestReferenceChecker checker(data.rootChecker());
